@@ -5,17 +5,17 @@
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  * Copyright (C) 2012 Intel Corporation
  *
- * This library is free software; you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  * Authors: Nat Friedman <nat@novell.com>
  *          Chris Toshok <toshok@ximian.com>
@@ -39,10 +39,7 @@
 #include <glib/gi18n-lib.h>
 
 #include "e-book-backend-file.h"
-
-#ifdef HAVE_LIBDB
 #include "e-book-backend-file-migrate-bdb.h"
-#endif
 
 #define E_BOOK_BACKEND_FILE_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
@@ -381,27 +378,7 @@ hard_link_photo (EBookBackendFile *bf,
 
 		i++;
 
-		#ifdef G_OS_WIN32
-		{
-		GFile *src_file = g_file_new_for_path (src_filename);
-		GFile *dst_file = g_file_new_for_path (fullname);
-		GError *copy_error = NULL;
-
-		g_file_copy (src_file, dst_file, G_FILE_COPY_NONE,
-		             NULL, NULL, NULL, &copy_error);
-
-		if (copy_error != NULL) {
-			g_error_free (copy_error);
-			ret = -1;
-		} else
-			ret = 0;
-
-		g_object_unref (src_file);
-		g_object_unref (dst_file);
-		}
-		#else
 		ret = link (src_filename, fullname);
-		#endif
 
 	} while (ret < 0 && errno == EEXIST);
 
@@ -1985,10 +1962,8 @@ book_backend_file_initable_init (GInitable *initable,
 	ESourceRegistry *registry;
 	ESource *source;
 	const gchar *extension_name;
-#ifdef HAVE_LIBDB
-	gchar *backup, *filename;
-#endif /* HAVE_LIBDB */
-	gchar *dirname, *fullpath;
+	gchar *backup, *dirname;
+	gchar *filename, *fullpath;
 	gboolean success = TRUE;
 
 	priv = E_BOOK_BACKEND_FILE_GET_PRIVATE (initable);
@@ -2006,11 +1981,9 @@ book_backend_file_initable_init (GInitable *initable,
 		dirname = e_book_backend_file_extract_path_from_source (
 			registry, source, GET_PATH_DB_DIR);
 
-	fullpath = g_build_filename (dirname, "contacts.db", NULL);
-
-#ifdef HAVE_LIBDB
 	filename = g_build_filename (dirname, "addressbook.db", NULL);
 	backup = g_build_filename (dirname, "addressbook.db.old", NULL);
+	fullpath = g_build_filename (dirname, "contacts.db", NULL);
 
 	/* The old BDB exists, lets migrate that to sqlite right away. */
 	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
@@ -2045,7 +2018,6 @@ book_backend_file_initable_init (GInitable *initable,
 			goto exit;
 		}
 	}
-#endif /* HAVE_LIBDB */
 
 	/* If we already have a handle on this, it means there
 	 * was an old BDB migrated and no need to reopen it. */
@@ -2109,10 +2081,8 @@ book_backend_file_initable_init (GInitable *initable,
 exit:
 	g_free (dirname);
 	g_free (fullpath);
-#ifdef HAVE_LIBDB
 	g_free (filename);
 	g_free (backup);
-#endif /* HAVE_LIBDB */
 
 	return success;
 }
