@@ -3,20 +3,20 @@
  * Copyright (C) 2008 Joergen Scheibengruber
  * Copyright (C) 2010, 2011 Philip Withnall
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
- * Author: Joergen Scheibengruber <joergen.scheibengruber AT googlemail.com>
- *         Philip Withnall <philip@tecnocode.co.uk>
+ * Authors: Joergen Scheibengruber <joergen.scheibengruber AT googlemail.com>
+ *          Philip Withnall <philip@tecnocode.co.uk>
  */
 
 #include <config.h>
@@ -57,11 +57,11 @@ G_DEFINE_TYPE_WITH_CODE (
 		e_book_backend_google_source_authenticator_init))
 
 struct _EBookBackendGooglePrivate {
+	GList *bookviews;
+
 	EBookBackendCache *cache;
 	GMutex cache_lock;
 
-	/* For all the group-related members */
-	GRecMutex groups_lock;
 	/* Mapping from group ID to (human readable) group name */
 	GHashTable *groups_by_id;
 	/* Mapping from (human readable) group name to group ID */
@@ -71,7 +71,7 @@ struct _EBookBackendGooglePrivate {
 	/* Mapping entry ID to system_group_id */
 	GHashTable *system_groups_by_entry_id;
 	/* Time when the groups were last queried */
-	GTimeVal groups_last_update;
+	GTimeVal last_groups_update;
 
 	GDataAuthorizer *authorizer;
 	GDataService *service;
@@ -246,13 +246,7 @@ cache_add_contact (EBookBackend *backend,
 
 	priv = E_BOOK_BACKEND_GOOGLE_GET_PRIVATE (backend);
 
-	g_rec_mutex_lock (&priv->groups_lock);
 	contact = e_contact_new_from_gdata_entry (entry, priv->groups_by_id, priv->system_groups_by_entry_id);
-	g_rec_mutex_unlock (&priv->groups_lock);
-
-	if (!contact)
-		return NULL;
-
 	e_contact_add_gdata_entry_xml (contact, entry);
 	g_mutex_lock (&priv->cache_lock);
 	e_book_backend_cache_add_contact (priv->cache, contact);
@@ -478,6 +472,45 @@ backend_is_authorized (EBookBackend *backend)
 	return gdata_service_is_authorized (priv->service);
 }
 
+static void
+on_contact_added (EBookBackend *backend,
+                  EContact *contact)
+{
+	EBookBackendGooglePrivate *priv;
+	GList *iter;
+
+	priv = E_BOOK_BACKEND_GOOGLE_GET_PRIVATE (backend);
+
+	for (iter = priv->bookviews; iter; iter = iter->next)
+		e_data_book_view_notify_update (E_DATA_BOOK_VIEW (iter->data), g_object_ref (contact));
+}
+
+static void
+on_contact_removed (EBookBackend *backend,
+                    const gchar *uid)
+{
+	EBookBackendGooglePrivate *priv;
+	GList *iter;
+
+	priv = E_BOOK_BACKEND_GOOGLE_GET_PRIVATE (backend);
+
+	for (iter = priv->bookviews; iter; iter = iter->next)
+		e_data_book_view_notify_remove (E_DATA_BOOK_VIEW (iter->data), g_strdup (uid));
+}
+
+static void
+on_contact_changed (EBookBackend *backend,
+                    EContact *contact)
+{
+	EBookBackendGooglePrivate *priv;
+	GList *iter;
+
+	priv = E_BOOK_BACKEND_GOOGLE_GET_PRIVATE (backend);
+
+	for (iter = priv->bookviews; iter; iter = iter->next)
+		e_data_book_view_notify_update (E_DATA_BOOK_VIEW (iter->data), g_object_ref (contact));
+}
+
 static GCancellable *
 start_operation (EBookBackend *backend,
                  guint32 opid,
@@ -485,7 +518,7 @@ start_operation (EBookBackend *backend,
                  const gchar *message)
 {
 	EBookBackendGooglePrivate *priv;
-	GList *list, *link;
+	GList *iter;
 
 	priv = E_BOOK_BACKEND_GOOGLE_GET_PRIVATE (backend);
 
@@ -497,14 +530,8 @@ start_operation (EBookBackend *backend,
 	g_hash_table_insert (priv->cancellables, GUINT_TO_POINTER (opid), g_object_ref (cancellable));
 
 	/* Send out a status message to each view */
-	list = e_book_backend_list_views (backend);
-
-	for (link = list; link != NULL; link = g_list_next (link)) {
-		EDataBookView *view = E_DATA_BOOK_VIEW (link->data);
-		e_data_book_view_notify_progress (view, -1, message);
-	}
-
-	g_list_free_full (list, (GDestroyNotify) g_object_unref);
+	for (iter = priv->bookviews; iter; iter = iter->next)
+		e_data_book_view_notify_progress (E_DATA_BOOK_VIEW (iter->data), -1, message);
 
 	return cancellable;
 }
@@ -525,16 +552,11 @@ finish_operation (EBookBackend *backend,
 	}
 
 	if (g_hash_table_remove (priv->cancellables, GUINT_TO_POINTER (opid))) {
-		GList *list, *link;
+		GList *iter;
 
-		list = e_book_backend_list_views (backend);
-
-		for (link = list; link != NULL; link = g_list_next (link)) {
-			EDataBookView *view = E_DATA_BOOK_VIEW (link->data);
-			e_data_book_view_notify_complete (view, book_error);
-		}
-
-		g_list_free_full (list, (GDestroyNotify) g_object_unref);
+		/* Send out a status message to each view */
+		for (iter = priv->bookviews; iter; iter = iter->next)
+			e_data_book_view_notify_complete (E_DATA_BOOK_VIEW (iter->data), book_error);
 	}
 
 	g_clear_error (&book_error);
@@ -552,13 +574,10 @@ process_contact_finish (EBookBackend *backend,
 	was_cached = cache_has_contact (backend, gdata_entry_get_id (entry));
 	new_contact = cache_add_contact (backend, entry);
 
-	if (!new_contact)
-		return;
-
 	if (was_cached == TRUE) {
-		e_book_backend_notify_update (backend, new_contact);
+		on_contact_changed (backend, new_contact);
 	} else {
-		e_book_backend_notify_update (backend, new_contact);
+		on_contact_added (backend, new_contact);
 	}
 
 	g_object_unref (new_contact);
@@ -688,7 +707,7 @@ process_contact_cb (GDataEntry *entry,
 		/* Do we have this item in our cache? */
 		if (is_cached) {
 			cache_remove_contact (backend, uid);
-			e_book_backend_notify_remove (backend, uid);
+			on_contact_removed (backend, uid);
 		}
 	} else {
 		gchar *old_photo_etag = NULL;
@@ -868,8 +887,6 @@ process_group (GDataEntry *entry,
 	system_group_id = gdata_contacts_group_get_system_group_id (GDATA_CONTACTS_GROUP (entry));
 	is_deleted = gdata_contacts_group_is_deleted (GDATA_CONTACTS_GROUP (entry));
 
-	g_rec_mutex_lock (&priv->groups_lock);
-
 	if (system_group_id) {
 		g_debug ("Processing %ssystem group %s, %s", is_deleted ? "(deleted) " : "", system_group_id, uid);
 
@@ -911,8 +928,6 @@ process_group (GDataEntry *entry,
 		priv->groups_changed = cache_update_group (backend, uid, name) || priv->groups_changed;
 	}
 
-	g_rec_mutex_unlock (&priv->groups_lock);
-
 	g_free (name);
 }
 
@@ -939,25 +954,17 @@ get_groups_cb (GDataService *service,
 
 	if (!gdata_error) {
 		/* Update the update time */
-		g_rec_mutex_lock (&priv->groups_lock);
-		g_get_current_time (&(priv->groups_last_update));
-		g_rec_mutex_unlock (&priv->groups_lock);
+		g_get_current_time (&(priv->last_groups_update));
 	}
 
 	finish_operation (backend, -2, gdata_error);
 
-	g_rec_mutex_lock (&priv->groups_lock);
-
 	if (priv->groups_changed) {
 		priv->groups_changed = FALSE;
 
-		g_rec_mutex_unlock (&priv->groups_lock);
-
 		/* do the update for all contacts, like with an empty cache */
 		cache_set_last_update (backend, NULL);
 		get_new_contacts (backend);
-	} else {
-		g_rec_mutex_unlock (&priv->groups_lock);
 	}
 
 	g_object_unref (backend);
@@ -966,21 +973,7 @@ get_groups_cb (GDataService *service,
 }
 
 static void
-get_groups_and_update_cache_cb (GDataService *service,
-				GAsyncResult *result,
-				EBookBackend *backend)
-{
-	g_object_ref (backend);
-
-	get_groups_cb (service, result, backend);
-	get_new_contacts (backend);
-
-	g_object_unref (backend);
-}
-
-static void
-get_groups (EBookBackend *backend,
-	    gboolean and_update_cache)
+get_groups (EBookBackend *backend)
 {
 	EBookBackendGooglePrivate *priv;
 	GDataQuery *query;
@@ -991,21 +984,17 @@ get_groups (EBookBackend *backend,
 	g_debug (G_STRFUNC);
 	g_return_if_fail (backend_is_authorized (backend));
 
-	g_rec_mutex_lock (&priv->groups_lock);
-
 	/* Build our query */
 	query = GDATA_QUERY (gdata_contacts_query_new_with_limits (NULL, 0, G_MAXINT));
-	if (priv->groups_last_update.tv_sec != 0 || priv->groups_last_update.tv_usec != 0) {
-		gdata_query_set_updated_min (query, priv->groups_last_update.tv_sec);
+	if (priv->last_groups_update.tv_sec != 0 || priv->last_groups_update.tv_usec != 0) {
+		gdata_query_set_updated_min (query, priv->last_groups_update.tv_sec);
 		gdata_contacts_query_set_show_deleted (GDATA_CONTACTS_QUERY (query), TRUE);
 	}
 
-	priv->groups_changed = FALSE;
-
-	g_rec_mutex_unlock (&priv->groups_lock);
-
 	g_object_ref (backend);
 
+	priv->groups_changed = FALSE;
+
 	/* Run the query asynchronously */
 	cancellable = start_operation (backend, -2, NULL, _("Querying for updated groups…"));
 	gdata_contacts_service_query_groups_async (
@@ -1015,7 +1004,7 @@ get_groups (EBookBackend *backend,
 		(GDataQueryProgressCallback) process_group,
 		backend,
 		(GDestroyNotify) NULL,
-		(GAsyncReadyCallback) (and_update_cache ? get_groups_and_update_cache_cb : get_groups_cb),
+		(GAsyncReadyCallback) get_groups_cb,
 		backend);
 
 	g_object_unref (cancellable);
@@ -1067,15 +1056,11 @@ create_group (EBookBackend *backend,
 
 	system_group_id = e_contact_map_google_with_evo_group (category_name, FALSE);
 	if (system_group_id) {
-		gchar *group_entry_id;
-
-		g_rec_mutex_lock (&priv->groups_lock);
-		group_entry_id = g_strdup (g_hash_table_lookup (priv->system_groups_by_id, system_group_id));
-		g_rec_mutex_unlock (&priv->groups_lock);
+		const gchar *group_entry_id = g_hash_table_lookup (priv->system_groups_by_id, system_group_id);
 
 		g_return_val_if_fail (group_entry_id != NULL, NULL);
 
-		return group_entry_id;
+		return g_strdup (group_entry_id);
 	}
 
 	group = GDATA_ENTRY (gdata_contacts_group_new (NULL));
@@ -1096,12 +1081,8 @@ create_group (EBookBackend *backend,
 
 	/* Add the new group to the group mappings */
 	uid = g_strdup (gdata_entry_get_id (new_group));
-
-	g_rec_mutex_lock (&priv->groups_lock);
 	g_hash_table_replace (priv->groups_by_id, e_contact_sanitise_google_group_id (uid), g_strdup (category_name));
 	g_hash_table_replace (priv->groups_by_name, g_strdup (category_name), e_contact_sanitise_google_group_id (uid));
-	g_rec_mutex_unlock (&priv->groups_lock);
-
 	g_object_unref (new_group);
 
 	/* Update the cache. */
@@ -1128,9 +1109,8 @@ refresh_local_cache_cb (ESource *source,
 
 	g_debug ("Invoking cache refresh");
 
-	/* The TRUE means the cache update will be run immediately
-	   after groups are updated */
-	get_groups (backend, TRUE);
+	get_groups (backend);
+	get_new_contacts (backend);
 }
 
 static void
@@ -1160,14 +1140,8 @@ cache_refresh_if_needed (EBookBackend *backend)
 			refresh_local_cache_cb,
 			backend,
 			NULL);
-	} else {
-		g_rec_mutex_lock (&priv->groups_lock);
-		if (g_hash_table_size (priv->system_groups_by_id) == 0) {
-			g_rec_mutex_unlock (&priv->groups_lock);
-			get_groups (backend, FALSE);
-		} else {
-			g_rec_mutex_unlock (&priv->groups_lock);
-		}
+	} else if (g_hash_table_size (priv->system_groups_by_id) == 0) {
+		get_groups (backend);
 	}
 
 	return;
@@ -1460,6 +1434,9 @@ book_backend_google_dispose (GObject *object)
 	/* Cancel all outstanding operations */
 	google_cancel_all_operations (E_BOOK_BACKEND (object));
 
+	g_list_free_full (priv->bookviews, (GDestroyNotify) g_object_unref);
+	priv->bookviews = NULL;
+
 	if (priv->refresh_id > 0) {
 		e_source_refresh_remove_timeout (
 			e_backend_get_source (E_BACKEND (object)),
@@ -1493,7 +1470,6 @@ book_backend_google_finalize (GObject *object)
 	}
 
 	g_mutex_clear (&priv->cache_lock);
-	g_rec_mutex_clear (&priv->groups_lock);
 
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (e_book_backend_google_parent_class)->finalize (object);
@@ -1517,17 +1493,19 @@ book_backend_google_get_backend_property (EBookBackend *backend,
 		return g_strjoin (
 			",",
 			e_contact_field_name (E_CONTACT_FULL_NAME),
-
 			e_contact_field_name (E_CONTACT_EMAIL_1),
 			e_contact_field_name (E_CONTACT_EMAIL_2),
 			e_contact_field_name (E_CONTACT_EMAIL_3),
 			e_contact_field_name (E_CONTACT_EMAIL_4),
-			e_contact_field_name (E_CONTACT_EMAIL),
-
 			e_contact_field_name (E_CONTACT_ADDRESS_LABEL_HOME),
 			e_contact_field_name (E_CONTACT_ADDRESS_LABEL_WORK),
 			e_contact_field_name (E_CONTACT_ADDRESS_LABEL_OTHER),
-
+			e_contact_field_name (E_CONTACT_PHONE_HOME),
+			e_contact_field_name (E_CONTACT_PHONE_HOME_FAX),
+			e_contact_field_name (E_CONTACT_PHONE_BUSINESS),
+			e_contact_field_name (E_CONTACT_PHONE_BUSINESS_FAX),
+			e_contact_field_name (E_CONTACT_PHONE_MOBILE),
+			e_contact_field_name (E_CONTACT_PHONE_PAGER),
 			e_contact_field_name (E_CONTACT_IM_AIM),
 			e_contact_field_name (E_CONTACT_IM_JABBER),
 			e_contact_field_name (E_CONTACT_IM_YAHOO),
@@ -1535,17 +1513,8 @@ book_backend_google_get_backend_property (EBookBackend *backend,
 			e_contact_field_name (E_CONTACT_IM_ICQ),
 			e_contact_field_name (E_CONTACT_IM_SKYPE),
 			e_contact_field_name (E_CONTACT_IM_GOOGLE_TALK),
-			/* current implementation uses http://schemas.google.com/g/2005# namespace
-			 * see google-utils:gdata_gd_im_address_from_attribute
-			 *
-			 * google namespace does not support:
-			 * e_contact_field_name (E_CONTACT_IM_TWITTER),
-			 * e_contact_field_name (E_CONTACT_IM_GADUGADU),
-			 * e_contact_field_name (E_CONTACT_IM_GROUPWISE),
-			 * see https://developers.google.com/gdata/docs/2.0/elements#gdIm
-			 * see google-utils:is_known_google_im_protocol
-			*/
-
+			e_contact_field_name (E_CONTACT_IM_GADUGADU),
+			e_contact_field_name (E_CONTACT_IM_GROUPWISE),
 			e_contact_field_name (E_CONTACT_ADDRESS),
 			e_contact_field_name (E_CONTACT_ADDRESS_HOME),
 			e_contact_field_name (E_CONTACT_ADDRESS_WORK),
@@ -1553,12 +1522,6 @@ book_backend_google_get_backend_property (EBookBackend *backend,
 			e_contact_field_name (E_CONTACT_NAME),
 			e_contact_field_name (E_CONTACT_GIVEN_NAME),
 			e_contact_field_name (E_CONTACT_FAMILY_NAME),
-			e_contact_field_name (E_CONTACT_PHONE_HOME),
-			e_contact_field_name (E_CONTACT_PHONE_HOME_FAX),
-			e_contact_field_name (E_CONTACT_PHONE_BUSINESS),
-			e_contact_field_name (E_CONTACT_PHONE_BUSINESS_FAX),
-			e_contact_field_name (E_CONTACT_PHONE_MOBILE),
-			e_contact_field_name (E_CONTACT_PHONE_PAGER),
 			e_contact_field_name (E_CONTACT_PHONE_ASSISTANT),
 			e_contact_field_name (E_CONTACT_PHONE_BUSINESS_2),
 			e_contact_field_name (E_CONTACT_PHONE_CALLBACK),
@@ -1572,8 +1535,6 @@ book_backend_google_get_backend_property (EBookBackend *backend,
 			e_contact_field_name (E_CONTACT_PHONE_RADIO),
 			e_contact_field_name (E_CONTACT_PHONE_TELEX),
 			e_contact_field_name (E_CONTACT_PHONE_TTYTDD),
-			e_contact_field_name (E_CONTACT_TEL),
-
 			e_contact_field_name (E_CONTACT_IM_AIM_HOME_1),
 			e_contact_field_name (E_CONTACT_IM_AIM_HOME_2),
 			e_contact_field_name (E_CONTACT_IM_AIM_HOME_3),
@@ -1610,12 +1571,14 @@ book_backend_google_get_backend_property (EBookBackend *backend,
 			e_contact_field_name (E_CONTACT_IM_ICQ_WORK_1),
 			e_contact_field_name (E_CONTACT_IM_ICQ_WORK_2),
 			e_contact_field_name (E_CONTACT_IM_ICQ_WORK_3),
+			e_contact_field_name (E_CONTACT_EMAIL),
 			e_contact_field_name (E_CONTACT_IM_GADUGADU_HOME_1),
 			e_contact_field_name (E_CONTACT_IM_GADUGADU_HOME_2),
 			e_contact_field_name (E_CONTACT_IM_GADUGADU_HOME_3),
 			e_contact_field_name (E_CONTACT_IM_GADUGADU_WORK_1),
 			e_contact_field_name (E_CONTACT_IM_GADUGADU_WORK_2),
 			e_contact_field_name (E_CONTACT_IM_GADUGADU_WORK_3),
+			e_contact_field_name (E_CONTACT_TEL),
 			e_contact_field_name (E_CONTACT_IM_SKYPE_HOME_1),
 			e_contact_field_name (E_CONTACT_IM_SKYPE_HOME_2),
 			e_contact_field_name (E_CONTACT_IM_SKYPE_HOME_3),
@@ -1628,7 +1591,6 @@ book_backend_google_get_backend_property (EBookBackend *backend,
 			e_contact_field_name (E_CONTACT_IM_GOOGLE_TALK_WORK_1),
 			e_contact_field_name (E_CONTACT_IM_GOOGLE_TALK_WORK_2),
 			e_contact_field_name (E_CONTACT_IM_GOOGLE_TALK_WORK_3),
-
 			e_contact_field_name (E_CONTACT_SIP),
 			e_contact_field_name (E_CONTACT_ORG),
 			e_contact_field_name (E_CONTACT_ORG_UNIT),
@@ -1773,8 +1735,6 @@ book_backend_google_create_contacts_sync (EBookBackend *backend,
 
 	g_warn_if_fail (backend_is_authorized (backend));
 
-	g_rec_mutex_lock (&priv->groups_lock);
-
 	/* Ensure the system groups have been fetched. */
 	if (g_hash_table_size (priv->system_groups_by_id) == 0)
 		get_groups_sync (backend, cancellable);
@@ -1788,8 +1748,6 @@ book_backend_google_create_contacts_sync (EBookBackend *backend,
 		_create_group, backend);
 	g_object_unref (contact);
 
-	g_rec_mutex_unlock (&priv->groups_lock);
-
 	/* Debug XML output */
 	xml = gdata_parsable_get_xml (GDATA_PARSABLE (entry));
 	g_debug ("new entry with xml: %s", xml);
@@ -1852,10 +1810,8 @@ book_backend_google_create_contacts_sync (EBookBackend *backend,
 	}
 
 	contact = cache_add_contact (backend, GDATA_ENTRY (new_contact));
-	if (contact) {
-		g_queue_push_tail (out_contacts, g_object_ref (contact));
-		g_object_unref (contact);
-	}
+	g_queue_push_tail (out_contacts, g_object_ref (contact));
+	g_object_unref (contact);
 
 exit:
 	g_clear_object (&entry);
@@ -1946,8 +1902,6 @@ book_backend_google_modify_contacts_sync (EBookBackend *backend,
 		return FALSE;
 	}
 
-	g_rec_mutex_lock (&priv->groups_lock);
-
 	/* Ensure the system groups have been fetched. */
 	if (g_hash_table_size (priv->system_groups_by_id) == 0)
 		get_groups_sync (backend, cancellable);
@@ -1959,8 +1913,6 @@ book_backend_google_modify_contacts_sync (EBookBackend *backend,
 		priv->system_groups_by_id,
 		_create_group, backend);
 
-	g_rec_mutex_unlock (&priv->groups_lock);
-
 	/* Output debug XML */
 	xml = gdata_parsable_get_xml (GDATA_PARSABLE (entry));
 	g_debug ("Before:\n%s", xml);
@@ -2061,17 +2013,14 @@ book_backend_google_modify_contacts_sync (EBookBackend *backend,
 		g_object_set_data_full (
 			G_OBJECT (new_contact), "photo", photo,
 			(GDestroyNotify) e_contact_photo_free);
-		photo = NULL;
 	} else {
 		g_object_set_data (
 			G_OBJECT (new_contact), "photo", NULL);
 	}
 
 	contact = cache_add_contact (backend, new_contact);
-	if (contact) {
-		g_queue_push_tail (out_contacts, g_object_ref (contact));
-		g_object_unref (contact);
-	}
+	g_queue_push_tail (out_contacts, g_object_ref (contact));
+	g_object_unref (contact);
 
 exit:
 	g_clear_object (&entry);
@@ -2228,14 +2177,20 @@ static void
 book_backend_google_start_view (EBookBackend *backend,
                                 EDataBookView *bookview)
 {
+	EBookBackendGooglePrivate *priv;
 	GQueue queue = G_QUEUE_INIT;
 	GError *error = NULL;
 
 	g_return_if_fail (E_IS_BOOK_BACKEND_GOOGLE (backend));
 	g_return_if_fail (E_IS_DATA_BOOK_VIEW (bookview));
 
+	priv = E_BOOK_BACKEND_GOOGLE_GET_PRIVATE (backend);
+
 	g_debug (G_STRFUNC);
 
+	priv->bookviews = g_list_append (priv->bookviews, bookview);
+
+	g_object_ref (bookview);
 	e_data_book_view_notify_progress (bookview, -1, _("Loading…"));
 
 	/* Ensure that we're ready to support a view */
@@ -2264,7 +2219,18 @@ static void
 book_backend_google_stop_view (EBookBackend *backend,
                                EDataBookView *bookview)
 {
+	EBookBackendGooglePrivate *priv;
+	GList *view;
+
+	priv = E_BOOK_BACKEND_GOOGLE_GET_PRIVATE (backend);
+
 	g_debug (G_STRFUNC);
+
+	/* Remove the view from the list of active views */
+	if ((view = g_list_find (priv->bookviews, bookview)) != NULL) {
+		priv->bookviews = g_list_delete_link (priv->bookviews, view);
+		g_object_unref (bookview);
+	}
 }
 
 static void
@@ -2378,7 +2344,6 @@ e_book_backend_google_init (EBookBackendGoogle *backend)
 	backend->priv = E_BOOK_BACKEND_GOOGLE_GET_PRIVATE (backend);
 
 	g_mutex_init (&backend->priv->cache_lock);
-	g_rec_mutex_init (&backend->priv->groups_lock);
 
 	g_signal_connect (
 		backend, "notify::online",
