@@ -3,20 +3,20 @@
  * Copyright (C) 2008 Joergen Scheibengruber
  * Copyright (C) 2010, 2011, 2012 Philip Withnall
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
- * Author: Joergen Scheibengruber <joergen.scheibengruber AT googlemail.com>
- *         Philip Withnall <philip@tecnocode.co.uk>
+ * Authors: Joergen Scheibengruber <joergen.scheibengruber AT googlemail.com>
+ *          Philip Withnall <philip@tecnocode.co.uk>
  */
 
 #include <config.h>
@@ -1087,7 +1087,7 @@ is_known_google_im_protocol (const gchar *protocol)
 {
 	const gchar *known_protocols[] = {
 		"AIM", "MSN", "YAHOO", "SKYPE", "QQ",
-		"GOOGLE-TALK", "ICQ", "JABBER"
+		"GOOGLE_TALK", "ICQ", "JABBER"
 	};
 	guint i;
 
@@ -1113,10 +1113,7 @@ field_name_from_google_im_protocol (const gchar *google_protocol)
 	if (!protocol)
 		return NULL;
 
-	if (strcmp ("#GOOGLE_TALK", protocol) == 0)
-		return g_strdup (EVC_X_GOOGLE_TALK);
-	else
-		return g_strdup_printf ("X-%s", protocol + 1);
+	return g_strdup_printf ("X-%s", protocol + 1);
 }
 
 static gchar *
@@ -1127,10 +1124,7 @@ google_im_protocol_from_field_name (const gchar *field_name)
 	if (!field_name || strlen (field_name) < 3)
 		return NULL;
 
-	if (strcmp (field_name, EVC_X_GOOGLE_TALK) == 0)
-		return g_strdup_printf (format, "GOOGLE_TALK");
-	else
-		return g_strdup_printf (format, field_name + 2);
+	return g_strdup_printf (format, field_name + 2);
 }
 
 static void
