@@ -4,22 +4,21 @@
  *
  * Copyright (C) 2012 Intel Corporation
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
- * Authors:
- *    Chris Toshok  <toshok@ximian.com>
- *    Mathias Hasselmann <mathias@openismus.com>
- *    Tristan Van Berkom <tristanvb@openismus.com>
+ * Authors: Chris Toshok  <toshok@ximian.com>
+ *          Mathias Hasselmann <mathias@openismus.com>
+ *          Tristan Van Berkom <tristanvb@openismus.com>
  */
 
 /**
@@ -42,12 +41,6 @@
 
 #include <libedataserver/libedataserver.h>
 
-#ifdef G_OS_WIN32
-#ifndef LC_MESSAGES
-#define LC_MESSAGES LC_CTYPE
-#endif
-#endif
-
 typedef enum {
 	E_BOOK_QUERY_TYPE_AND,
 	E_BOOK_QUERY_TYPE_OR,
