@@ -4,21 +4,20 @@
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  * Copyright (C) 2012 Intel Corporation
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
- * Authors:
- *   Chris Toshok (toshok@ximian.com)
- *   Tristan Van Berkom <tristanvb@openismus.com>
+ * Authors: Chris Toshok (toshok@ximian.com)
+ *          Tristan Van Berkom <tristanvb@openismus.com>
  */
 
 /**
@@ -44,7 +43,7 @@
 #include "e-name-western.h"
 
 #ifdef G_OS_WIN32
-#include "libedataserver/libedataserver.h"
+#include "libedataserver/e-data-server-util.h"
 #undef LOCALEDIR
 #define LOCALEDIR e_util_get_localedir ()
 #endif
@@ -863,10 +862,6 @@ e_contact_find_attribute_with_types (EContact *contact,
 {
 	GList *l, *attrs;
 	gboolean found_needed1, found_needed2;
-	gboolean can_empty_needed2;
-
-	can_empty_needed2 = g_ascii_strcasecmp (attr_name, "TEL") == 0 && type_needed2 &&
-			    g_ascii_strcasecmp (type_needed2, "VOICE") == 0;
 
 	attrs = e_vcard_get_attributes (E_VCARD (contact));
 
@@ -885,7 +880,6 @@ e_contact_find_attribute_with_types (EContact *contact,
 			for (params = e_vcard_attribute_get_params (attr); params; params = params->next) {
 				EVCardAttributeParam *param = params->data;
 				const gchar *param_name = e_vcard_attribute_param_get_name (param);
-				gint n_types = 0;
 
 				if (!g_ascii_strcasecmp (param_name, EVC_TYPE)) {
 					gboolean matches = FALSE;
@@ -897,12 +891,11 @@ e_contact_find_attribute_with_types (EContact *contact,
 						found_needed2 = values && !values->next;
 
 					while (values && values->data) {
-						n_types++;
-
 						if (!found_needed1 && !g_ascii_strcasecmp ((gchar *) values->data, type_needed1)) {
 							found_needed1 = TRUE;
 							matches = TRUE;
-						} else if (!found_needed2 && !g_ascii_strcasecmp ((gchar *) values->data, type_needed2)) {
+						}
+						else if (!found_needed2 && !g_ascii_strcasecmp ((gchar *) values->data, type_needed2)) {
 							found_needed2 = TRUE;
 							matches = TRUE;
 						} else if (found_needed1) {
@@ -913,7 +906,7 @@ e_contact_find_attribute_with_types (EContact *contact,
 						values = values->next;
 					}
 
-					if (!matches && (!can_empty_needed2 || n_types != 1)) {
+					if (!matches) {
 						/* this is to enforce that we find an attribute
 						 * with *only* the TYPE='s we need.  This may seem like
 						 * an odd restriction but it's the only way at present to
@@ -923,7 +916,7 @@ e_contact_find_attribute_with_types (EContact *contact,
 					}
 				}
 
-				if (found_needed1 && (found_needed2 || (n_types == 1 && can_empty_needed2))) {
+				if (found_needed1 && found_needed2) {
 					if (nth-- == 0)
 						return attr;
 					else
@@ -1462,25 +1455,6 @@ e_contact_vcard_attribute (EContactField field_id)
 	return field_info[field_id].vcard_field_name;
 }
 
-/**
- * e_contact_field_is_string:
- * @field_id: an #EContactField
- *
- * Returns whether the @field_id is of a string type,
- * thus it can be used with e_contact_get_const().
- *
- * Returns: Whether the @field_id is of a string type.
- *
- * Since: 3.14
- **/
-gboolean
-e_contact_field_is_string (EContactField field_id)
-{
-	g_return_val_if_fail (field_id >= 1 && field_id < E_CONTACT_FIELD_LAST, FALSE);
-
-	return (field_info[field_id].t & E_CONTACT_FIELD_TYPE_STRING) != 0;
-}
-
 /**
  * e_contact_field_id:
  * @field_name: a string representing a contact field
@@ -1736,8 +1710,7 @@ e_contact_get (EContact *contact,
  * @field_id: an #EContactField
  *
  * Gets the value of @contact's field specified by @field_id, caching
- * the result so it can be freed later. Use e_contact_field_is_string()
- * to check whether the field can be used here.
+ * the result so it can be freed later.
  *
  * Returns: (transfer none): Depends on the field's type, owned by the
  * #EContact.
@@ -1805,15 +1778,44 @@ e_contact_set (EContact *contact,
 GList *
 e_contact_get_attributes (EContact *contact,
                           EContactField field_id)
+{
+	EContactField set[1];
+	set[0] = field_id;
+	return e_contact_get_attributes_set (contact, set, 1);
+}
+
+/**
+ * e_contact_get_attributes_set:
+ * @contact: an #EContact
+ * @field_ids: an array of #EContactField
+ * @size: number of elements in field_ids
+ *
+ * Gets a list of the vcard attributes for @contact's @field_ids.
+ *
+ * Returns: (transfer full) (element-type EVCardAttribute): A #GList of pointers
+ * to #EVCardAttribute, owned by the caller.
+ *
+ * Since: 3.14
+ **/
+GList *
+e_contact_get_attributes_set (EContact *contact,
+                              const EContactField field_ids[],
+                              gint size)
 {
 	GList *l = NULL;
 	GList *attrs, *a;
-	const EContactFieldInfo *info = NULL;
+	gint ii;
+	EContactFieldInfo **infos;
 
 	g_return_val_if_fail (contact && E_IS_CONTACT (contact), NULL);
-	g_return_val_if_fail (field_id >= 1 && field_id < E_CONTACT_FIELD_LAST, NULL);
+	g_return_val_if_fail (size > 0, NULL);
+	g_return_val_if_fail (size < E_CONTACT_FIELD_LAST, NULL);
 
-	info = &field_info[field_id];
+	infos = g_new0 (EContactFieldInfo *, size);
+	for (ii = 0; ii < size; ii++) {
+		g_return_val_if_fail (field_ids[ii] >= 1 && field_ids[ii] < E_CONTACT_FIELD_LAST, NULL);
+		infos[ii] = (EContactFieldInfo *) &field_info[field_ids[ii]];
+	}
 
 	attrs = e_vcard_get_attributes (E_VCARD (contact));
 
@@ -1823,11 +1825,16 @@ e_contact_get_attributes (EContact *contact,
 
 		name = e_vcard_attribute_get_name (attr);
 
-		if (!g_ascii_strcasecmp (name, info->vcard_field_name)) {
-			l = g_list_prepend (l, e_vcard_attribute_copy (attr));
+		for (ii = 0; ii < size; ii++) {
+			if (!g_ascii_strcasecmp (name, infos[ii]->vcard_field_name)) {
+				l = g_list_prepend (l, e_vcard_attribute_copy (attr));
+				break;
+			}
 		}
 	}
 
+	g_free (infos);
+
 	return g_list_reverse (l);
 }
 
