@@ -4,19 +4,19 @@
  * Copyright (C) 2006 OpenedHand Ltd
  * Copyright (C) 2009 Intel Corporation
  *
- * This library is free software; you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
- * Author: Ross Burton <ross@linux.intel.com>
+ * Authors: Ross Burton <ross@linux.intel.com>
  */
 
 /**
@@ -116,7 +116,7 @@ typedef struct {
 static void
 signal_closure_free (SignalClosure *signal_closure)
 {
-	g_weak_ref_clear (&signal_closure->client_view);
+	g_weak_ref_set (&signal_closure->client_view, NULL);
 
 	g_slist_free_full (
 		signal_closure->object_list,
@@ -271,7 +271,7 @@ book_client_view_emit_objects_added (EBookClientView *client_view,
 	SignalClosure *signal_closure;
 
 	signal_closure = g_slice_new0 (SignalClosure);
-	g_weak_ref_init (&signal_closure->client_view, client_view);
+	g_weak_ref_set (&signal_closure->client_view, client_view);
 	signal_closure->object_list = object_list;  /* takes ownership */
 
 	main_context = book_client_view_ref_main_context (client_view);
@@ -297,7 +297,7 @@ book_client_view_emit_objects_modified (EBookClientView *client_view,
 	SignalClosure *signal_closure;
 
 	signal_closure = g_slice_new0 (SignalClosure);
-	g_weak_ref_init (&signal_closure->client_view, client_view);
+	g_weak_ref_set (&signal_closure->client_view, client_view);
 	signal_closure->object_list = object_list;  /* takes ownership */
 
 	main_context = book_client_view_ref_main_context (client_view);
@@ -562,7 +562,7 @@ book_client_view_objects_removed_cb (EGdbusBookView *object,
 			list = g_slist_prepend (list, g_strdup (ids[ii]));
 
 		signal_closure = g_slice_new0 (SignalClosure);
-		g_weak_ref_init (&signal_closure->client_view, client_view);
+		g_weak_ref_set (&signal_closure->client_view, client_view);
 		signal_closure->string_list = g_slist_reverse (list);
 
 		main_context = book_client_view_ref_main_context (client_view);
@@ -603,7 +603,7 @@ book_client_view_progress_cb (EGdbusBookView *object,
 		}
 
 		signal_closure = g_slice_new0 (SignalClosure);
-		g_weak_ref_init (&signal_closure->client_view, client_view);
+		g_weak_ref_set (&signal_closure->client_view, client_view);
 		signal_closure->message = g_strdup (message);
 		signal_closure->percent = percent;
 
@@ -644,7 +644,7 @@ book_client_view_complete_cb (EGdbusBookView *object,
 		}
 
 		signal_closure = g_slice_new0 (SignalClosure);
-		g_weak_ref_init (&signal_closure->client_view, client_view);
+		g_weak_ref_set (&signal_closure->client_view, client_view);
 		e_gdbus_templates_decode_error (
 			in_error_strv, &signal_closure->error);
 
@@ -677,11 +677,17 @@ book_client_view_dispose_cb (GObject *source_object,
 	e_gdbus_book_view_call_dispose_finish (
 		G_DBUS_PROXY (source_object), result, &local_error);
 
-	if (local_error != NULL) {
+	/* Ignore closed errors, since this callback can be called after the
+	 * EBookClientView has been disposed, and hence after the calling code
+	 * has dropped its final reference and gone on to clean up other things
+	 * (like the dbus-daemon, if it’s a test harness). */
+	if (local_error != NULL &&
+	    !g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_CLOSED)) {
 		g_dbus_error_strip_remote_error (local_error);
 		g_warning ("%s: %s", G_STRFUNC, local_error->message);
-		g_error_free (local_error);
 	}
+
+	g_clear_error (&local_error);
 }
 
 static void
@@ -857,7 +863,6 @@ book_client_view_finalize (GObject *object)
 	g_free (priv->object_path);
 
 	g_mutex_clear (&priv->main_context_lock);
-	g_weak_ref_clear (&priv->client);
 
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (e_book_client_view_parent_class)->finalize (object);
@@ -1054,7 +1059,6 @@ e_book_client_view_init (EBookClientView *client_view)
 	client_view->priv = E_BOOK_CLIENT_VIEW_GET_PRIVATE (client_view);
 
 	g_mutex_init (&client_view->priv->main_context_lock);
-	g_weak_ref_init (&client_view->priv->client, NULL);
 }
 
 /**
