@@ -2,20 +2,19 @@
 /*
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Authors:
- *   Chris Toshok <toshok@ximian.com>
- *
- * This library is free software; you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Chris Toshok <toshok@ximian.com>
  */
 
 /**
@@ -272,15 +271,11 @@ e_book_backend_summary_load_header (EBookBackendSummary *summary,
 
 static gchar *
 read_string (FILE *fp,
-             gsize len)
+             gint len)
 {
 	gchar *buf;
 	gint rv;
 
-	/* Avoid overflow for the nul byte. */
-	if (len == G_MAXSIZE)
-		return NULL;
-
 	buf = g_new0 (char, len + 1);
 
 	rv = fread (buf, len, 1, fp);
