@@ -3,21 +3,19 @@
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Authors: Hans Petter Jansson <hpj@ximian.com>
- *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- *for more details.
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
- * Based in part on the file backend.
+ * Authors: Hans Petter Jansson <hpj@ximian.com>
  */
 
 #include <config.h>
@@ -91,6 +89,10 @@ soup_authenticate (SoupSession *session,
 	ESourceAuthentication *auth_extension;
 	ESource *source;
 	const gchar *extension_name;
+	gchar *user;
+
+	if (retrying)
+		return;
 
 	cbhttp = E_CAL_BACKEND_HTTP (data);
 
@@ -98,13 +100,14 @@ soup_authenticate (SoupSession *session,
 	extension_name = E_SOURCE_EXTENSION_AUTHENTICATION;
 	auth_extension = e_source_get_extension (source, extension_name);
 
-	if (!retrying && cbhttp->priv->password != NULL) {
-		gchar *user;
+	user = e_source_authentication_dup_user (auth_extension);
 
-		user = e_source_authentication_dup_user (auth_extension);
+	if (!user || !*user)
+		soup_message_set_status (msg, SOUP_STATUS_FORBIDDEN);
+	else if (cbhttp->priv->password != NULL)
 		soup_auth_authenticate (auth, user, cbhttp->priv->password);
-		g_free (user);
-	}
+
+	g_free (user);
 }
 
 /* Dispose handler for the file backend */
@@ -497,37 +500,12 @@ cal_backend_http_load (ECalBackendHttp *backend,
 			&cancel_data, (GDestroyNotify) NULL);
 	}
 
+	e_soup_ssl_trust_connect (
+		soup_message, e_backend_get_source (E_BACKEND (backend)),
+		e_cal_backend_get_registry (E_CAL_BACKEND (backend)),
+		cancellable);
+
 	status_code = soup_session_send_message (soup_session, soup_message);
-	if (status_code == SOUP_STATUS_SSL_FAILED) {
-		ESource *source;
-		ESourceWebdav *extension;
-		ESourceRegistry *registry;
-		EBackend *ebackend;
-		ETrustPromptResponse response;
-		ENamedParameters *parameters;
-
-		ebackend = E_BACKEND (backend);
-		source = e_backend_get_source (ebackend);
-		registry = e_cal_backend_get_registry (E_CAL_BACKEND (backend));
-		extension = e_source_get_extension (source, E_SOURCE_EXTENSION_WEBDAV_BACKEND);
-
-		parameters = e_named_parameters_new ();
-
-		response = e_source_webdav_prepare_ssl_trust_prompt (extension, soup_message, registry, parameters);
-		if (response == E_TRUST_PROMPT_RESPONSE_UNKNOWN) {
-			response = e_backend_trust_prompt_sync (ebackend, parameters, cancellable, NULL);
-			if (response != E_TRUST_PROMPT_RESPONSE_UNKNOWN)
-				e_source_webdav_store_ssl_trust_prompt (extension, soup_message, response);
-		}
-
-		e_named_parameters_free (parameters);
-
-		if (response == E_TRUST_PROMPT_RESPONSE_ACCEPT ||
-		    response == E_TRUST_PROMPT_RESPONSE_ACCEPT_TEMPORARILY) {
-			g_object_set (soup_session, SOUP_SESSION_SSL_STRICT, FALSE, NULL);
-			status_code = soup_session_send_message (soup_session, soup_message);
-		}
-	}
 
 	if (G_IS_CANCELLABLE (cancellable))
 		g_cancellable_disconnect (cancellable, cancel_id);
@@ -782,6 +760,9 @@ begin_retrieval_cb (GIOSchedulerJob *job,
 			E_BACKEND (backend),
 			E_SOURCE_AUTHENTICATOR (backend),
 			cancellable, &error);
+	} else if (g_error_matches (error, SOUP_HTTP_ERROR, SOUP_STATUS_FORBIDDEN)) {
+		g_clear_error (&error);
+		error = EDC_ERROR (AuthenticationRequired);
 	}
 
 	backend->priv->is_loading = FALSE;
@@ -890,7 +871,6 @@ e_cal_backend_http_open (ECalBackendSync *backend,
 	extension_name = E_SOURCE_EXTENSION_WEBDAV_BACKEND;
 	webdav_extension = e_source_get_extension (source, extension_name);
 
-	g_object_set (cbhttp->priv->soup_session, SOUP_SESSION_SSL_STRICT, TRUE, NULL);
 	e_source_webdav_unset_temporary_ssl_trust (webdav_extension);
 
 	if (priv->source_changed_id == 0) {
@@ -936,8 +916,12 @@ e_cal_backend_http_open (ECalBackendSync *backend,
 				registry, source,
 				E_SOURCE_AUTHENTICATOR (backend),
 				cancellable, &local_error);
+		} else if (g_error_matches (local_error, SOUP_HTTP_ERROR, SOUP_STATUS_FORBIDDEN)) {
+			g_clear_error (&local_error);
+			local_error = EDC_ERROR (AuthenticationRequired);
 		}
 
+
 		if (local_error != NULL)
 			g_propagate_error (perror, g_error_copy (local_error));
 	}
