@@ -2,17 +2,17 @@
 /*
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software; you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -45,7 +45,6 @@ struct _ECalBackendSExpPrivate {
 	ESExp *search_sexp;
 	gchar *text;
 	SearchContext *search_context;
-	GMutex search_context_lock;
 };
 
 struct _SearchContext {
@@ -1105,7 +1104,6 @@ cal_backend_sexp_finalize (GObject *object)
 	e_sexp_unref (priv->search_sexp);
 	g_free (priv->text);
 	g_free (priv->search_context);
-	g_mutex_clear (&priv->search_context_lock);
 
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (e_cal_backend_sexp_parent_class)->finalize (object);
@@ -1127,8 +1125,6 @@ e_cal_backend_sexp_init (ECalBackendSExp *sexp)
 {
 	sexp->priv = E_CAL_BACKEND_SEXP_GET_PRIVATE (sexp);
 	sexp->priv->search_context = g_new (SearchContext, 1);
-
-	g_mutex_init (&sexp->priv->search_context_lock);
 }
 
 /* 'builtin' functions */
@@ -1258,8 +1254,6 @@ e_cal_backend_sexp_match_comp (ECalBackendSExp *sexp,
 	g_return_val_if_fail (E_IS_CAL_COMPONENT (comp), FALSE);
 	g_return_val_if_fail (E_IS_TIMEZONE_CACHE (cache), FALSE);
 
-	g_mutex_lock (&sexp->priv->search_context_lock);
-
 	sexp->priv->search_context->comp = g_object_ref (comp);
 	sexp->priv->search_context->cache = g_object_ref (cache);
 
@@ -1272,8 +1266,6 @@ e_cal_backend_sexp_match_comp (ECalBackendSExp *sexp,
 
 	e_sexp_result_free (sexp->priv->search_sexp, r);
 
-	g_mutex_unlock (&sexp->priv->search_context_lock);
-
 	return retval;
 }
 
