@@ -1,17 +1,17 @@
 /*
  * e-data-cal.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -218,6 +218,14 @@ data_cal_convert_to_client_error (GError *error)
 {
 	g_return_if_fail (error != NULL);
 
+	/* Data-Factory returns common error for unknown/broken ESource-s */
+	if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND)) {
+		error->domain = E_CAL_CLIENT_ERROR;
+		error->code = E_CAL_CLIENT_ERROR_NO_SUCH_CALENDAR;
+
+		return;
+	}
+
 	if (error->domain != E_DATA_CAL_ERROR)
 		return;
 
@@ -1542,7 +1550,7 @@ e_data_cal_respond_refresh (EDataCal *cal,
 	if (error != NULL)
 		g_simple_async_result_take_error (simple, error);
 
-	g_simple_async_result_complete_in_idle (simple);
+	g_simple_async_result_complete (simple);
 
 	g_object_unref (simple);
 	g_object_unref (backend);
@@ -2402,7 +2410,6 @@ data_cal_finalize (GObject *object)
 	g_free (priv->object_path);
 
 	g_mutex_clear (&priv->sender_lock);
-	g_weak_ref_clear (&priv->backend);
 	g_hash_table_destroy (priv->sender_table);
 
 	if (priv->dbus_interface) {
@@ -2567,7 +2574,6 @@ e_data_cal_init (EDataCal *data_cal)
 	data_cal->priv->dbus_interface = dbus_interface;
 
 	g_mutex_init (&data_cal->priv->sender_lock);
-	g_weak_ref_init (&data_cal->priv->backend, NULL);
 
 	data_cal->priv->sender_table = g_hash_table_new_full (
 		(GHashFunc) g_str_hash,
