@@ -1,24 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* camel-imap-folder.c: class for an imap folder */
-
 /*
- * Authors:
- *   Sankar P <psankar@novell.com>
- *   Srinivasa Ragavan <sragavan@novell.com>
- *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- *for more details.
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Sankar P <psankar@novell.com>
+ *          Srinivasa Ragavan <sragavan@novell.com>
  */
 
 #include "camel-db.h"
@@ -53,12 +50,6 @@ typedef struct {
 	GRecMutex sync_mutex;
 	guint timeout_id;
 	gint flags;
-
-	/* Do know how many syncs are pending, to not close
-	   the file before the last sync is over */
-	guint pending_syncs;
-	GMutex pending_syncs_lock;
-	GCond pending_syncs_cond;
 } CamelSqlite3File;
 
 static gint
@@ -97,13 +88,6 @@ sync_request_thread_cb (gpointer task_data,
 
 	call_old_file_Sync (sync_data->cFile, sync_data->flags);
 
-	g_mutex_lock (&sync_data->cFile->pending_syncs_lock);
-	g_warn_if_fail (sync_data->cFile->pending_syncs > 0);
-	sync_data->cFile->pending_syncs--;
-	if (!sync_data->cFile->pending_syncs)
-		g_cond_signal (&sync_data->cFile->pending_syncs_cond);
-	g_mutex_unlock (&sync_data->cFile->pending_syncs_lock);
-
 	done = sync_data->done;
 	g_free (sync_data);
 
@@ -149,10 +133,6 @@ sync_push_request (CamelSqlite3File *cFile,
 
 	cFile->flags = 0;
 
-	g_mutex_lock (&cFile->pending_syncs_lock);
-	cFile->pending_syncs++;
-	g_mutex_unlock (&cFile->pending_syncs_lock);
-
 	g_rec_mutex_unlock (&cFile->sync_mutex);
 
 	g_thread_pool_push (sync_pool, data, &error);
@@ -211,20 +191,6 @@ camel_sqlite3_file_ ## _nm _params \
 	return cFile->old_vfs_file->pMethods->_nm _call; \
 }
 
-#define def_subclassed_void(_nm, _params, _call) \
-static void \
-camel_sqlite3_file_ ## _nm _params \
-{ \
-	CamelSqlite3File *cFile; \
- \
-	g_return_if_fail (old_vfs != NULL); \
-	g_return_if_fail (pFile != NULL); \
- \
-	cFile = (CamelSqlite3File *) pFile; \
-	g_return_if_fail (cFile->old_vfs_file->pMethods != NULL); \
-	cFile->old_vfs_file->pMethods->_nm _call; \
-}
-
 def_subclassed (xRead, (sqlite3_file *pFile, gpointer pBuf, gint iAmt, sqlite3_int64 iOfst), (cFile->old_vfs_file, pBuf, iAmt, iOfst))
 def_subclassed (xWrite, (sqlite3_file *pFile, gconstpointer pBuf, gint iAmt, sqlite3_int64 iOfst), (cFile->old_vfs_file, pBuf, iAmt, iOfst))
 def_subclassed (xTruncate, (sqlite3_file *pFile, sqlite3_int64 size), (cFile->old_vfs_file, size))
@@ -234,12 +200,6 @@ def_subclassed (xUnlock, (sqlite3_file *pFile, gint lockType), (cFile->old_vfs_f
 def_subclassed (xFileControl, (sqlite3_file *pFile, gint op, gpointer pArg), (cFile->old_vfs_file, op, pArg))
 def_subclassed (xSectorSize, (sqlite3_file *pFile), (cFile->old_vfs_file))
 def_subclassed (xDeviceCharacteristics, (sqlite3_file *pFile), (cFile->old_vfs_file))
-def_subclassed (xShmMap, (sqlite3_file *pFile, gint iPg, gint pgsz, gint n, void volatile **arr), (cFile->old_vfs_file, iPg, pgsz, n, arr))
-def_subclassed (xShmLock, (sqlite3_file *pFile, gint offset, gint n, gint flags), (cFile->old_vfs_file, offset, n, flags))
-def_subclassed_void (xShmBarrier, (sqlite3_file *pFile), (cFile->old_vfs_file))
-def_subclassed (xShmUnmap, (sqlite3_file *pFile, gint deleteFlag), (cFile->old_vfs_file, deleteFlag))
-def_subclassed (xFetch, (sqlite3_file *pFile, sqlite3_int64 iOfst, int iAmt, void **pp), (cFile->old_vfs_file, iOfst, iAmt, pp))
-def_subclassed (xUnfetch, (sqlite3_file *pFile, sqlite3_int64 iOfst, void *p), (cFile->old_vfs_file, iOfst, p))
 
 #undef def_subclassed
 
@@ -286,12 +246,6 @@ camel_sqlite3_file_xClose (sqlite3_file *pFile)
 	/* Make the last sync. */
 	sync_push_request (cFile, TRUE);
 
-	g_mutex_lock (&cFile->pending_syncs_lock);
-	while (cFile->pending_syncs > 0) {
-		g_cond_wait (&cFile->pending_syncs_cond, &cFile->pending_syncs_lock);
-	}
-	g_mutex_unlock (&cFile->pending_syncs_lock);
-
 	if (cFile->old_vfs_file->pMethods)
 		res = cFile->old_vfs_file->pMethods->xClose (cFile->old_vfs_file);
 	else
@@ -301,8 +255,6 @@ camel_sqlite3_file_xClose (sqlite3_file *pFile)
 	cFile->old_vfs_file = NULL;
 
 	g_rec_mutex_clear (&cFile->sync_mutex);
-	g_mutex_clear (&cFile->pending_syncs_lock);
-	g_cond_clear (&cFile->pending_syncs_cond);
 
 	return res;
 }
@@ -365,10 +317,6 @@ camel_sqlite3_vfs_xOpen (sqlite3_vfs *pVfs,
 	}
 
 	g_rec_mutex_init (&cFile->sync_mutex);
-	g_mutex_init (&cFile->pending_syncs_lock);
-	g_cond_init (&cFile->pending_syncs_cond);
-
-	cFile->pending_syncs = 0;
 
 	g_rec_mutex_lock (&only_once_lock);
 
@@ -400,23 +348,6 @@ camel_sqlite3_vfs_xOpen (sqlite3_vfs *pVfs,
 		use_subclassed (xFileControl);
 		use_subclassed (xSectorSize);
 		use_subclassed (xDeviceCharacteristics);
-
-		if (io_methods.iVersion > 1) {
-			use_subclassed (xShmMap);
-			use_subclassed (xShmLock);
-			use_subclassed (xShmBarrier);
-			use_subclassed (xShmUnmap);
-		}
-
-		if (io_methods.iVersion > 2) {
-			use_subclassed (xFetch);
-			use_subclassed (xUnfetch);
-		}
-
-		if (io_methods.iVersion > 3) {
-			g_warning ("%s: Unchecked IOMethods version %d, downgrading to version 3", G_STRFUNC, io_methods.iVersion);
-			io_methods.iVersion = 3;
-		}
 		#undef use_subclassed
 	}
 
@@ -509,24 +440,16 @@ cdb_sql_exec (sqlite3 *db,
               GError **error)
 {
 	gchar *errmsg = NULL;
-	gint   ret = -1, retries = 0;
+	gint   ret = -1;
 
 	d (g_print ("Camel SQL Exec:\n%s\n", stmt));
 
 	ret = sqlite3_exec (db, stmt, callback, data, &errmsg);
 	while (ret == SQLITE_BUSY || ret == SQLITE_LOCKED || ret == -1) {
-		/* try for ~15 seconds, then give up */
-		if (retries > 150)
-			break;
-		retries++;
-
 		if (errmsg) {
 			sqlite3_free (errmsg);
 			errmsg = NULL;
 		}
-		g_thread_yield ();
-		g_usleep (100 * 1000); /* Sleep for 100 ms */
-
 		ret = sqlite3_exec (db, stmt, NULL, NULL, &errmsg);
 	}
 
