@@ -1,22 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Authors: Jeffrey Stedfast <fejj@ximian.com>
- *	     Michael Zucchi <NotZed@Ximian.com>
- *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
+ * Authors: Jeffrey Stedfast <fejj@ximian.com>
+ *	    Michael Zucchi <NotZed@Ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -874,17 +873,20 @@ junk_test (struct _CamelSExp *f,
 	gboolean message_is_junk = FALSE;
 	GError *error = NULL;
 
+	junk_filter = camel_session_get_junk_filter (fms->session);
+	if (junk_filter == NULL)
+		goto exit;
+
 	/* Check if the message is already classified. */
 
 	flags = camel_message_info_flags (info);
 
 	if (flags & CAMEL_MESSAGE_JUNK) {
-		message_is_junk = TRUE;
 		if (camel_debug ("junk"))
 			printf (
 				"Message has a Junk flag set already, "
 				"skipping junk test...\n");
-		goto done;
+		goto exit;
 	}
 
 	if (flags & CAMEL_MESSAGE_NOTJUNK) {
@@ -892,22 +894,9 @@ junk_test (struct _CamelSExp *f,
 			printf (
 				"Message has a NotJunk flag set already, "
 				"skipping junk test...\n");
-		goto done;
+		goto exit;
 	}
 
-	/* If the sender is known, the message is not junk.
-	   Do this before header test, to be able to override server-side set headers. */
-
-	sender_is_known = camel_session_lookup_addressbook (
-		fms->session, camel_message_info_from (info));
-	if (camel_debug ("junk"))
-		printf (
-			"Sender '%s' in book? %d\n",
-			camel_message_info_from (info),
-			sender_is_known);
-	if (sender_is_known)
-		goto done;
-
 	/* Check the headers for a junk designation. */
 
 	ht = camel_session_get_junk_headers (fms->session);
@@ -935,41 +924,21 @@ junk_test (struct _CamelSExp *f,
 		node = node->next;
 	}
 
-	/* Not every message info has headers available, thus try headers of the message itself */
-	message = camel_filter_search_get_message (fms, f);
-	if (message) {
-		struct _camel_header_raw *h;
+	/* If the sender is known, the message is not junk. */
 
-		for (h = CAMEL_MIME_PART (message)->headers; h; h = h->next) {
-			const gchar *value;
-
-			if (!h->name)
-				continue;
-
-			value = g_hash_table_lookup ((GHashTable *) ht, h->name);
-			if (!value)
-				continue;
-
-			message_is_junk = camel_strstrcase (h->value, value) != NULL;
-
-			if (message_is_junk) {
-				if (camel_debug ("junk"))
-					printf (
-						"Message contains \"%s: %s\"",
-						h->name, value);
-				goto done;
-			}
-		}
-	} else {
+	sender_is_known = camel_session_lookup_addressbook (
+		fms->session, camel_message_info_from (info));
+	if (camel_debug ("junk"))
+		printf (
+			"Sender '%s' in book? %d\n",
+			camel_message_info_from (info),
+			sender_is_known);
+	if (sender_is_known)
 		goto done;
-	}
 
 	/* Consult 3rd party junk filtering software. */
 
-	junk_filter = camel_session_get_junk_filter (fms->session);
-	if (junk_filter == NULL)
-		goto done;
-
+	message = camel_filter_search_get_message (fms, f);
 	status = camel_junk_filter_classify (
 		junk_filter, message, NULL, &error);
 
@@ -997,7 +966,7 @@ junk_test (struct _CamelSExp *f,
 		}
 
 		if (camel_debug ("junk"))
-			printf (
+			g_print (
 				"Junk filter classification: %s\n",
 				status_desc);
 	} else {
@@ -1007,12 +976,13 @@ junk_test (struct _CamelSExp *f,
 		message_is_junk = FALSE;
 	}
 
- done:
+done:
 	if (camel_debug ("junk"))
 		printf (
 			"Message is determined to be %s\n",
 			message_is_junk ? "*JUNK*" : "clean");
 
+exit:
 	r = camel_sexp_result_new (f, CAMEL_SEXP_RES_BOOL);
 	r->value.number = message_is_junk;
 
@@ -1045,7 +1015,6 @@ camel_filter_search_match (CamelSession *session,
 	CamelSExp *sexp;
 	CamelSExpResult *result;
 	gboolean retval;
-	GError *local_error = NULL;
 	gint i;
 
 	fms.session = session;
@@ -1054,7 +1023,7 @@ camel_filter_search_match (CamelSession *session,
 	fms.message = NULL;
 	fms.info = info;
 	fms.source = source;
-	fms.error = &local_error;
+	fms.error = error;
 
 	sexp = camel_sexp_new ();
 
@@ -1067,29 +1036,21 @@ camel_filter_search_match (CamelSession *session,
 
 	camel_sexp_input_text (sexp, expression, strlen (expression));
 	if (camel_sexp_parse (sexp) == -1) {
-		if (!local_error) {
-			/* A filter search is a search through your filters,
-			 * ie. your filters is the corpus being searched thru. */
-			g_set_error (
-				&local_error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-				_("Error executing filter search: %s: %s"),
-				camel_sexp_error (sexp), expression);
-		}
+		/* A filter search is a search through your filters,
+		 * ie. your filters is the corpus being searched thru. */
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+			_("Error executing filter search: %s: %s"),
+			camel_sexp_error (sexp), expression);
 		goto error;
 	}
 
 	result = camel_sexp_eval (sexp);
 	if (result == NULL) {
-		if (!local_error)
-			g_set_error (
-				&local_error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-				_("Error executing filter search: %s: %s"),
-				camel_sexp_error (sexp), expression);
-		goto error;
-	}
-
-	if (local_error) {
-		camel_sexp_result_free (sexp, result);
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+			_("Error executing filter search: %s: %s"),
+			camel_sexp_error (sexp), expression);
 		goto error;
 	}
 
@@ -1112,8 +1073,5 @@ camel_filter_search_match (CamelSession *session,
 
 	g_object_unref (sexp);
 
-	if (local_error)
-		g_propagate_error (error, local_error);
-
 	return CAMEL_SEARCH_ERROR;
 }
