@@ -2,19 +2,19 @@
 /*
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Authors: Michael Zucchi <notzed@ximian.com>
- *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Michael Zucchi <notzed@ximian.com>
  */
 
 /* This is a helper class for folders to implement the search function.
@@ -712,15 +712,6 @@ folder_search_dummy (CamelSExp *sexp,
 	return r;
 }
 
-static CamelSExpResult *
-folder_search_header_has_words (CamelSExp *sexp,
-				gint argc,
-				CamelSExpResult **argv,
-				CamelFolderSearch *search)
-{
-	return check_header (sexp, argc, argv, search, CAMEL_SEARCH_MATCH_WORD);
-}
-
 static void
 folder_search_dispose (GObject *object)
 {
@@ -754,7 +745,8 @@ folder_search_constructed (GObject *object)
 	gint ii;
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (camel_folder_search_parent_class)->constructed (object);
+	G_OBJECT_CLASS (camel_folder_search_parent_class)->
+		constructed (object);
 
 	search = CAMEL_FOLDER_SEARCH (object);
 	class = CAMEL_FOLDER_SEARCH_GET_CLASS (search);
@@ -791,10 +783,6 @@ folder_search_constructed (GObject *object)
 			}
 		}
 	}
-
-	camel_sexp_add_function (
-		search->sexp, 0, "header-has-words",
-		(CamelSExpFunc) folder_search_header_has_words, search);
 }
 
 /* implement an 'array not', i.e. everything in the summary, not in the supplied array */
