@@ -1,21 +1,20 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
+ * Authors: Jeffrey Stedfast <fejj@ximian.com>
  */
 
 /* Debug states:
@@ -648,12 +647,8 @@ gpg_ctx_op_start (struct _GpgCtx *gpg,
 		/* Loop over all fds. */
 		for (i = 3; i < maxfd; i++) {
 			/* don't close the status-fd or passwd-fd */
-			if (i != fds[7] && i != fds[8]) {
-				if (fcntl (i, F_SETFD, FD_CLOEXEC) == -1) {
-					/* Do nothing here. Cannot use CHECK_CALL() macro here, because
-					   it makes the process stuck, possibly due to the debug print. */
-				}
-			}
+			if (i != fds[7] && i != fds[8])
+				CHECK_CALL (fcntl (i, F_SETFD, FD_CLOEXEC));
 		}
 
 		/* run gpg */
@@ -1884,16 +1879,16 @@ gpg_verify_sync (CamelCipherContext *context,
 	canon_stream = camel_stream_mem_new ();
 
 	/* strip trailing white-spaces */
-	filter = camel_stream_filter_new (istream);
+	filter = camel_stream_filter_new (canon_stream);
 	canon = camel_mime_filter_canon_new (CAMEL_MIME_FILTER_CANON_CRLF | CAMEL_MIME_FILTER_CANON_STRIP);
 	camel_stream_filter_add (CAMEL_STREAM_FILTER (filter), canon);
 	g_object_unref (canon);
 
-	camel_stream_write_to_stream (filter, canon_stream, NULL, NULL);
+	camel_stream_write_to_stream (istream, filter, NULL, NULL);
 
 	g_object_unref (filter);
-	g_object_unref (istream);
-	istream = NULL;
+
+	g_seekable_seek (G_SEEKABLE (istream), 0, G_SEEK_SET, NULL, NULL);
 
 	g_seekable_seek (G_SEEKABLE (canon_stream), 0, G_SEEK_SET, NULL, NULL);
 
@@ -1949,7 +1944,7 @@ gpg_verify_sync (CamelCipherContext *context,
 		g_unlink (sigfile);
 		g_free (sigfile);
 	}
-
+	g_object_unref (istream);
 	g_object_unref (canon_stream);
 
 	return validity;
