@@ -1,24 +1,23 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; fill-column: 160 -*- */
-/* camelMimePart.c : Abstract class for a mime_part */
-
-/*
- * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
- *	    Michael Zucchi <notzed@ximian.com>
- *          Jeffrey Stedfast <fejj@ximian.com>
+/* camelMimePart.c : Abstract class for a mime_part
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- *for more details.
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
+ *	    Michael Zucchi <notzed@ximian.com>
+ *          Jeffrey Stedfast <fejj@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -684,6 +683,17 @@ mime_part_write_to_stream_sync (CamelDataWrapper *dw,
 				g_object_unref (charenc);
 			}
 
+			/* we only re-do crlf on encoded blocks */
+			if (filter && camel_content_type_is (dw->mime_type, "text", "*")) {
+				CamelMimeFilter *crlf = camel_mime_filter_crlf_new (
+					CAMEL_MIME_FILTER_CRLF_ENCODE,
+					CAMEL_MIME_FILTER_CRLF_MODE_CRLF_ONLY);
+
+				camel_stream_filter_add (
+					CAMEL_STREAM_FILTER (filter_stream), crlf);
+				g_object_unref (crlf);
+			}
+
 			if (filter) {
 				camel_stream_filter_add (
 					CAMEL_STREAM_FILTER (filter_stream), filter);
@@ -898,6 +908,25 @@ mime_part_write_to_output_stream_sync (CamelDataWrapper *dw,
 			reencode = TRUE;
 		}
 
+		if (filter != NULL && content_type_is_text) {
+			CamelMimeFilter *crlf;
+			GOutputStream *temp_stream;
+
+			crlf = camel_mime_filter_crlf_new (
+				CAMEL_MIME_FILTER_CRLF_ENCODE,
+				CAMEL_MIME_FILTER_CRLF_MODE_CRLF_ONLY);
+			temp_stream = camel_filter_output_stream_new (
+				filter_stream, crlf);
+			g_filter_output_stream_set_close_base_stream (
+				G_FILTER_OUTPUT_STREAM (temp_stream), FALSE);
+			g_object_unref (crlf);
+
+			g_object_unref (filter_stream);
+			filter_stream = temp_stream;
+
+			reencode = TRUE;
+		}
+
 		if (filter != NULL) {
 			GOutputStream *temp_stream;
 
