@@ -1,17 +1,17 @@
 /*
  * camel-network-service.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #if HAVE_CONFIG_H
@@ -460,25 +460,19 @@ network_service_set_host_reachable (CamelNetworkService *service,
 		camel_service_disconnect_sync (
 			CAMEL_SERVICE (service), FALSE, NULL, &local_error);
 		if (local_error != NULL) {
-			if (!G_IS_IO_ERROR (local_error, G_IO_ERROR_CANCELLED))
-				g_warning ("%s: %s", G_STRFUNC, local_error->message);
+			g_warning ("%s: %s", G_STRFUNC, local_error->message);
 			g_error_free (local_error);
 		}
 	}
 }
 
 static gboolean
-network_service_update_host_reachable_timeout_cb (gpointer user_data)
+network_service_update_host_reachable_idle_cb (gpointer user_data)
 {
 	CamelNetworkService *service;
 	CamelNetworkServicePrivate *priv;
 	GCancellable *old_cancellable;
 	GCancellable *new_cancellable;
-	GSource *current_source;
-
-	current_source = g_main_current_source ();
-	if (current_source && g_source_is_destroyed (current_source))
-		return FALSE;
 
 	service = CAMEL_NETWORK_SERVICE (user_data);
 	priv = CAMEL_NETWORK_SERVICE_GET_PRIVATE (service);
@@ -514,8 +508,6 @@ network_service_update_host_reachable (CamelNetworkService *service)
 {
 	CamelNetworkServicePrivate *priv;
 	CamelSession *session;
-	GMainContext *main_context;
-	GSource *timeout_source;
 
 	priv = CAMEL_NETWORK_SERVICE_GET_PRIVATE (service);
 
@@ -527,30 +519,26 @@ network_service_update_host_reachable (CamelNetworkService *service)
 
 	g_mutex_lock (&priv->update_host_reachable_lock);
 
-	/* Reference the service before destroying any already scheduled GSource,
-	   in case the service's last reference is held by that GSource. */
-	g_object_ref (service);
+	if (priv->update_host_reachable == NULL) {
+		GMainContext *main_context;
+		GSource *idle_source;
 
-	if (priv->update_host_reachable) {
-		g_source_destroy (priv->update_host_reachable);
-		g_source_unref (priv->update_host_reachable);
-		priv->update_host_reachable = NULL;
+		main_context = camel_session_ref_main_context (session);
+
+		idle_source = g_idle_source_new ();
+		g_source_set_priority (idle_source, G_PRIORITY_LOW);
+		g_source_set_callback (
+			idle_source,
+			network_service_update_host_reachable_idle_cb,
+			g_object_ref (service),
+			(GDestroyNotify) g_object_unref);
+		g_source_attach (idle_source, main_context);
+		priv->update_host_reachable = g_source_ref (idle_source);
+		g_source_unref (idle_source);
+
+		g_main_context_unref (main_context);
 	}
 
-	main_context = camel_session_ref_main_context (session);
-
-	timeout_source = g_timeout_source_new_seconds (5);
-	g_source_set_priority (timeout_source, G_PRIORITY_LOW);
-	g_source_set_callback (
-		timeout_source,
-		network_service_update_host_reachable_timeout_cb,
-		service, (GDestroyNotify) g_object_unref);
-	g_source_attach (timeout_source, main_context);
-	priv->update_host_reachable = g_source_ref (timeout_source);
-	g_source_unref (timeout_source);
-
-	g_main_context_unref (main_context);
-
 	g_mutex_unlock (&priv->update_host_reachable_lock);
 
 	g_object_unref (session);
@@ -655,14 +643,6 @@ network_service_connect_sync (CamelNetworkService *service,
 
 	g_object_unref (settings);
 
-	if (connection) {
-		GSocket *socket;
-
-		socket = g_socket_connection_get_socket (connection);
-		if (socket)
-			g_socket_set_timeout (socket, 90);
-	}
-
 	return (connection != NULL) ? G_IO_STREAM (connection) : NULL;
 }
 
@@ -682,10 +662,10 @@ network_service_new_connectable (CamelNetworkService *service)
 	g_return_val_if_fail (CAMEL_IS_NETWORK_SETTINGS (settings), NULL);
 
 	network_settings = CAMEL_NETWORK_SETTINGS (settings);
-	host = camel_network_settings_dup_host_ensure_ascii (network_settings);
+	host = camel_network_settings_dup_host (network_settings);
 	port = camel_network_settings_get_port (network_settings);
 
-	if (host && *host)
+	if (host != NULL)
 		connectable = g_network_address_new (host, port);
 
 	g_free (host);
@@ -1028,8 +1008,10 @@ camel_network_service_can_reach_sync (CamelNetworkService *service,
 			priv->network_monitor, connectable,
 			cancellable, &local_error);
 	} else {
-		/* No host information available, assume reachable */
-		can_reach = TRUE;
+		local_error = g_error_new_literal (
+			G_IO_ERROR,
+			G_IO_ERROR_HOST_UNREACHABLE,
+			_("No host information available"));
 	}
 
 	update_property =
@@ -1037,19 +1019,8 @@ camel_network_service_can_reach_sync (CamelNetworkService *service,
 		G_IS_IO_ERROR (local_error, G_IO_ERROR_HOST_UNREACHABLE) ||
 		G_IS_RESOLVER_ERROR (local_error, G_RESOLVER_ERROR_NOT_FOUND);
 
-	if (update_property) {
-		g_mutex_lock (&priv->update_host_reachable_lock);
-
-		if (priv->update_host_reachable) {
-			g_source_destroy (priv->update_host_reachable);
-			g_source_unref (priv->update_host_reachable);
-			priv->update_host_reachable = NULL;
-		}
-
-		g_mutex_unlock (&priv->update_host_reachable_lock);
-
+	if (update_property)
 		network_service_set_host_reachable (service, can_reach);
-	}
 
 	g_clear_object (&connectable);
 
