@@ -1,21 +1,20 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Authors: Jeffrey Stedfast <fejj@novell.com>
- *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
+ * Authors: Jeffrey Stedfast <fejj@novell.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -61,7 +60,8 @@ offline_store_constructed (GObject *object)
 	priv = CAMEL_OFFLINE_STORE_GET_PRIVATE (object);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (camel_offline_store_parent_class)->constructed (object);
+	G_OBJECT_CLASS (camel_offline_store_parent_class)->
+		constructed (object);
 
 	session = camel_service_ref_session (CAMEL_SERVICE (object));
 	priv->online = camel_session_get_online (session);
@@ -188,18 +188,9 @@ camel_offline_store_set_online_sync (CamelOfflineStore *store,
 	status = camel_service_get_connection_status (service);
 
 	if (CAMEL_IS_NETWORK_SERVICE (store)) {
-		/* When going to set the 'online' state, then check with up-to-date
-		   value, otherwise use the cached value. The cached value is
-		   updated with few seconds timeout, thus it can be stale here. */
-		if (online)
-			host_reachable =
-				camel_network_service_can_reach_sync (
-				CAMEL_NETWORK_SERVICE (store),
-				cancellable, NULL);
-		else
-			host_reachable =
-				camel_network_service_get_host_reachable (
-				CAMEL_NETWORK_SERVICE (store));
+		host_reachable =
+			camel_network_service_get_host_reachable (
+			CAMEL_NETWORK_SERVICE (store));
 	}
 
 	store_is_online = camel_offline_store_get_online (store);
@@ -297,12 +288,9 @@ camel_offline_store_prepare_for_offline_sync (CamelOfflineStore *store,
 	session = camel_service_ref_session (service);
 
 	if (CAMEL_IS_NETWORK_SERVICE (store)) {
-		/* Check with up-to-date value. The cached value is updated with
-		   few seconds timeout, thus it can be stale here. */
 		host_reachable =
-			camel_network_service_can_reach_sync (
-			CAMEL_NETWORK_SERVICE (store),
-			cancellable, NULL);
+			camel_network_service_get_host_reachable (
+			CAMEL_NETWORK_SERVICE (store));
 	}
 
 	store_is_online = camel_offline_store_get_online (store);
