@@ -1,24 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* camel-service.c : Abstract class for an email service */
-
-/*
- *
- * Author :
- *  Bertrand Guiheneuf <bertrand@helixcode.com>
+/* camel-service.c : Abstract class for an email service
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- *for more details.
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -261,7 +258,7 @@ connection_op_complete_pending (ConnectionOp *op,
 static void
 dispatch_data_free (DispatchData *dispatch_data)
 {
-	g_weak_ref_clear (&dispatch_data->service);
+	g_weak_ref_set (&dispatch_data->service, NULL);
 
 	g_slice_free (DispatchData, dispatch_data);
 }
@@ -872,8 +869,6 @@ service_finalize (GObject *object)
 	g_hash_table_destroy (priv->task_table);
 	g_mutex_clear (&priv->task_table_lock);
 
-	g_weak_ref_clear (&priv->session);
-
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (camel_service_parent_class)->finalize (object);
 }
@@ -1094,7 +1089,6 @@ camel_service_init (CamelService *service)
 
 	g_mutex_init (&service->priv->property_lock);
 	g_mutex_init (&service->priv->connection_lock);
-	g_weak_ref_init (&service->priv->session, NULL);
 	service->priv->status = CAMEL_SERVICE_DISCONNECTED;
 
 	service->priv->proxy_resolver = g_proxy_resolver_get_default ();
@@ -1717,7 +1711,7 @@ camel_service_queue_task (CamelService *service,
 	return_on_cancel = g_task_get_return_on_cancel (task);
 
 	dispatch_data = g_slice_new0 (DispatchData);
-	g_weak_ref_init (&dispatch_data->service, service);
+	g_weak_ref_set (&dispatch_data->service, service);
 	dispatch_data->return_on_cancel = return_on_cancel;
 	dispatch_data->task_func = task_func;
 
@@ -1809,11 +1803,6 @@ camel_service_connect (CamelService *service,
 
 	g_return_if_fail (CAMEL_IS_SERVICE (service));
 
-	if (cancellable)
-		g_object_ref (cancellable);
-	else
-		cancellable = g_cancellable_new ();
-
 	task = g_task_new (service, cancellable, callback, user_data);
 	g_task_set_source_tag (task, camel_service_connect);
 	g_task_set_priority (task, io_priority);
@@ -1869,7 +1858,6 @@ camel_service_connect (CamelService *service,
 
 	g_mutex_unlock (&service->priv->connection_lock);
 
-	g_object_unref (cancellable);
 	g_object_unref (task);
 }
 
@@ -1981,11 +1969,6 @@ camel_service_disconnect (CamelService *service,
 
 	g_return_if_fail (CAMEL_IS_SERVICE (service));
 
-	if (cancellable)
-		g_object_ref (cancellable);
-	else
-		cancellable = g_cancellable_new ();
-
 	task = g_task_new (service, cancellable, callback, user_data);
 	g_task_set_source_tag (task, camel_service_disconnect);
 	g_task_set_priority (task, io_priority);
@@ -2049,7 +2032,6 @@ camel_service_disconnect (CamelService *service,
 
 	g_mutex_unlock (&service->priv->connection_lock);
 
-	g_object_unref (cancellable);
 	g_object_unref (task);
 }
 
