@@ -1,25 +1,23 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* camel-session.c : Abstract class for an email session */
-
-/*
- * Authors:
- *  Dan Winship <danw@ximian.com>
- *  Jeffrey Stedfast <fejj@ximian.com>
- *  Bertrand Guiheneuf <bertrand@helixcode.com>
+/* camel-session.c : Abstract class for an email session
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- *for more details.
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Dan Winship <danw@ximian.com>
+ *          Jeffrey Stedfast <fejj@ximian.com>
+ *          Bertrand Guiheneuf <bertrand@helixcode.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -139,7 +137,7 @@ async_context_free (AsyncContext *async_context)
 static void
 signal_closure_free (SignalClosure *signal_closure)
 {
-	g_weak_ref_clear (&signal_closure->session);
+	g_weak_ref_set (&signal_closure->session, NULL);
 
 	if (signal_closure->service != NULL)
 		g_object_unref (signal_closure->service);
@@ -1200,7 +1198,7 @@ camel_session_user_alert (CamelSession *session,
 	g_return_if_fail (message != NULL);
 
 	signal_closure = g_slice_new0 (SignalClosure);
-	g_weak_ref_init (&signal_closure->session, session);
+	g_weak_ref_set (&signal_closure->session, session);
 	signal_closure->service = g_object_ref (service);
 	signal_closure->alert_type = type;
 	signal_closure->alert_message = g_strdup (message);
