@@ -1,24 +1,22 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* camel-store.c : Abstract class for an email store */
-
-/*
- * Authors:
- *  Bertrand Guiheneuf <bertrand@helixcode.com>
- *  Dan Winship <danw@ximian.com>
+/* camel-store.c : Abstract class for an email store
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- *for more details.
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
+ *          Dan Winship <danw@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -105,7 +103,7 @@ async_context_free (AsyncContext *async_context)
 static void
 signal_closure_free (SignalClosure *signal_closure)
 {
-	g_weak_ref_clear (&signal_closure->store);
+	g_weak_ref_set (&signal_closure->store, NULL);
 
 	if (signal_closure->folder != NULL)
 		g_object_unref (signal_closure->folder);
@@ -296,7 +294,6 @@ store_maybe_connect_sync (CamelStore *store,
 {
 	CamelService *service;
 	CamelServiceConnectionStatus status;
-	CamelSession *session;
 	gboolean connect = FALSE;
 	gboolean success = TRUE;
 
@@ -304,10 +301,8 @@ store_maybe_connect_sync (CamelStore *store,
 	 * when the CamelService is online but disconnected. */
 
 	service = CAMEL_SERVICE (store);
-	session = camel_service_ref_session (service);
 	status = camel_service_get_connection_status (service);
-	connect = camel_session_get_online (session) && (status != CAMEL_SERVICE_CONNECTED);
-	g_clear_object (&session);
+	connect = (status != CAMEL_SERVICE_CONNECTED);
 
 	if (connect && CAMEL_IS_NETWORK_SERVICE (store)) {
 		/* Disregard errors here.  Just want to
@@ -479,9 +474,6 @@ store_synchronize_sync (CamelStore *store,
 	for (ii = 0; ii < folders->len; ii++) {
 		CamelFolder *folder = folders->pdata[ii];
 
-		if (folder->summary)
-			camel_folder_summary_save_to_db (folder->summary, NULL);
-
 		if (!CAMEL_IS_VEE_FOLDER (folder) && local_error == NULL) {
 			camel_folder_synchronize_sync (
 				folder, expunge, cancellable, &local_error);
@@ -689,7 +681,7 @@ camel_store_folder_created (CamelStore *store,
 	session = camel_service_ref_session (CAMEL_SERVICE (store));
 
 	signal_closure = g_slice_new0 (SignalClosure);
-	g_weak_ref_init (&signal_closure->store, store);
+	g_weak_ref_set (&signal_closure->store, store);
 	signal_closure->folder_info = camel_folder_info_clone (folder_info);
 
 	/* Prioritize ahead of GTK+ redraws. */
@@ -727,7 +719,7 @@ camel_store_folder_deleted (CamelStore *store,
 	session = camel_service_ref_session (CAMEL_SERVICE (store));
 
 	signal_closure = g_slice_new0 (SignalClosure);
-	g_weak_ref_init (&signal_closure->store, store);
+	g_weak_ref_set (&signal_closure->store, store);
 	signal_closure->folder_info = camel_folder_info_clone (folder_info);
 
 	/* Prioritize ahead of GTK+ redraws. */
@@ -765,7 +757,7 @@ camel_store_folder_opened (CamelStore *store,
 	session = camel_service_ref_session (CAMEL_SERVICE (store));
 
 	signal_closure = g_slice_new0 (SignalClosure);
-	g_weak_ref_init (&signal_closure->store, store);
+	g_weak_ref_set (&signal_closure->store, store);
 	signal_closure->folder = g_object_ref (folder);
 
 	/* Prioritize ahead of GTK+ redraws. */
@@ -806,7 +798,7 @@ camel_store_folder_renamed (CamelStore *store,
 	session = camel_service_ref_session (CAMEL_SERVICE (store));
 
 	signal_closure = g_slice_new0 (SignalClosure);
-	g_weak_ref_init (&signal_closure->store, store);
+	g_weak_ref_set (&signal_closure->store, store);
 	signal_closure->folder_info = camel_folder_info_clone (folder_info);
 	signal_closure->folder_name = g_strdup (old_name);
 
@@ -852,7 +844,7 @@ camel_store_folder_info_stale (CamelStore *store)
 		SignalClosure *signal_closure;
 
 		signal_closure = g_slice_new0 (SignalClosure);
-		g_weak_ref_init (&signal_closure->store, store);
+		g_weak_ref_set (&signal_closure->store, store);
 
 		camel_session_idle_add (
 			session, G_PRIORITY_LOW,
