@@ -1,23 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* camel-stream.c : abstract class for a stream */
-
-/*
- * Author:
- *  Bertrand Guiheneuf <bertrand@helixcode.com>
+/* camel-stream.c : abstract class for a stream
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- *for more details.
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
  */
 
 #include "camel-stream.h"
@@ -42,7 +40,7 @@ enum {
 };
 
 /* Forward Declarations */
-static void	camel_stream_seekable_init	(GSeekableIface *interface);
+static void	camel_stream_seekable_init	(GSeekableIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (
 	CamelStream,
@@ -376,13 +374,13 @@ camel_stream_class_init (CamelStreamClass *class)
 }
 
 static void
-camel_stream_seekable_init (GSeekableIface *interface)
+camel_stream_seekable_init (GSeekableIface *iface)
 {
-	interface->tell = stream_tell;
-	interface->can_seek = stream_can_seek;
-	interface->seek = stream_seek;
-	interface->can_truncate = stream_can_truncate;
-	interface->truncate_fn = stream_truncate;
+	iface->tell = stream_tell;
+	iface->can_seek = stream_can_seek;
+	iface->seek = stream_seek;
+	iface->can_truncate = stream_can_truncate;
+	iface->truncate_fn = stream_truncate;
 }
 
 static void
