@@ -1,17 +1,17 @@
 /*
  * camel-imapx-command.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -74,7 +74,7 @@ camel_imapx_command_new (CamelIMAPXServer *is,
 	/* Initialize private bits. */
 	real_ic->ref_count = 1;
 	real_ic->buffer = g_string_sized_new (512);
-	g_weak_ref_init (&real_ic->mailbox, mailbox);
+	g_weak_ref_set (&real_ic->mailbox, mailbox);
 	g_cond_init (&real_ic->done_sync_cond);
 	g_mutex_init (&real_ic->done_sync_mutex);
 
@@ -146,7 +146,7 @@ camel_imapx_command_unref (CamelIMAPXCommand *ic)
 
 		g_string_free (real_ic->buffer, TRUE);
 
-		g_weak_ref_clear (&real_ic->mailbox);
+		g_weak_ref_set (&real_ic->mailbox, NULL);
 
 		g_clear_error (&real_ic->error);
 
