@@ -47,9 +47,6 @@ struct _CamelIMAPXConnManagerPrivate {
 	GWeakRef store;
 	GRWLock rw_lock;
 	guint limit_max_connections;
-
-	GMutex pending_connections_lock;
-	GSList *pending_connections; /* GCancellable * */
 };
 
 struct _ConnectionInfo {
@@ -57,7 +54,6 @@ struct _ConnectionInfo {
 	CamelIMAPXServer *is;
 	GHashTable *folder_names;
 	gchar *selected_folder;
-	GError *shutdown_error;
 	volatile gint ref_count;
 };
 
@@ -72,9 +68,7 @@ G_DEFINE_TYPE (
 	G_TYPE_OBJECT)
 
 static void
-imapx_conn_shutdown (CamelIMAPXServer *is,
-		     const GError *error,
-		     CamelIMAPXConnManager *con_man);
+imapx_conn_shutdown (CamelIMAPXServer *is, CamelIMAPXConnManager *con_man);
 
 static void
 imapx_conn_update_select (CamelIMAPXServer *is,
@@ -101,7 +95,6 @@ connection_info_new (CamelIMAPXServer *is)
 	g_mutex_init (&cinfo->lock);
 	cinfo->is = g_object_ref (is);
 	cinfo->folder_names = folder_names;
-	cinfo->shutdown_error = NULL;
 	cinfo->ref_count = 1;
 
 	return cinfo;
@@ -125,7 +118,7 @@ connection_info_unref (ConnectionInfo *cinfo)
 	g_return_if_fail (cinfo->ref_count > 0);
 
 	if (g_atomic_int_dec_and_test (&cinfo->ref_count)) {
-		camel_imapx_server_shutdown (cinfo->is, cinfo->shutdown_error);
+		camel_imapx_server_shutdown (cinfo->is);
 		g_signal_handlers_disconnect_matched (cinfo->is, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, imapx_conn_shutdown, NULL);
 		g_signal_handlers_disconnect_matched (cinfo->is, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, imapx_conn_update_select, NULL);
 		g_signal_handlers_disconnect_matched (cinfo->is, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, imapx_conn_mailbox_closed, NULL);
@@ -134,7 +127,6 @@ connection_info_unref (ConnectionInfo *cinfo)
 		g_object_unref (cinfo->is);
 		g_hash_table_destroy (cinfo->folder_names);
 		g_free (cinfo->selected_folder);
-		g_clear_error (&cinfo->shutdown_error);
 
 		g_slice_free (ConnectionInfo, cinfo);
 	}
@@ -149,7 +141,7 @@ connection_info_cancel_and_unref (ConnectionInfo *cinfo)
 	g_signal_handlers_disconnect_matched (cinfo->is, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, imapx_conn_shutdown, NULL);
 	g_signal_handlers_disconnect_matched (cinfo->is, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, imapx_conn_update_select, NULL);
 	g_signal_handlers_disconnect_matched (cinfo->is, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, imapx_conn_mailbox_closed, NULL);
-	camel_imapx_server_shutdown (cinfo->is, cinfo->shutdown_error);
+	camel_imapx_server_shutdown (cinfo->is);
 	connection_info_unref (cinfo);
 }
 
@@ -252,23 +244,6 @@ connection_info_set_selected_folder (ConnectionInfo *cinfo,
 	g_mutex_unlock (&cinfo->lock);
 }
 
-static void
-connection_info_set_shutdown_error (ConnectionInfo *cinfo,
-                                    const GError *shutdown_error)
-{
-	g_return_if_fail (cinfo != NULL);
-
-	g_mutex_lock (&cinfo->lock);
-
-	if (cinfo->shutdown_error != shutdown_error) {
-		g_clear_error (&cinfo->shutdown_error);
-		if (shutdown_error)
-			cinfo->shutdown_error = g_error_copy (shutdown_error);
-	}
-
-	g_mutex_unlock (&cinfo->lock);
-}
-
 static GList *
 imapx_conn_manager_list_info (CamelIMAPXConnManager *con_man)
 {
@@ -342,23 +317,6 @@ imapx_conn_manager_remove_info (CamelIMAPXConnManager *con_man,
 	return removed;
 }
 
-static void
-imax_conn_manager_cancel_pending_connections (CamelIMAPXConnManager *con_man)
-{
-	GSList *link;
-
-	g_return_if_fail (CAMEL_IS_IMAPX_CONN_MANAGER (con_man));
-
-	g_mutex_lock (&con_man->priv->pending_connections_lock);
-	for (link = con_man->priv->pending_connections; link; link = g_slist_next (link)) {
-		GCancellable *cancellable = link->data;
-
-		if (cancellable)
-			g_cancellable_cancel (cancellable);
-	}
-	g_mutex_unlock (&con_man->priv->pending_connections_lock);
-}
-
 static void
 imapx_conn_manager_set_store (CamelIMAPXConnManager *con_man,
                               CamelStore *store)
@@ -415,8 +373,6 @@ imapx_conn_manager_dispose (GObject *object)
 		(GDestroyNotify) connection_info_unref);
 	priv->connections = NULL;
 
-	imax_conn_manager_cancel_pending_connections (CAMEL_IMAPX_CONN_MANAGER (object));
-
 	g_weak_ref_set (&priv->store, NULL);
 
 	/* Chain up to parent's dispose() method. */
@@ -430,11 +386,7 @@ imapx_conn_manager_finalize (GObject *object)
 
 	priv = CAMEL_IMAPX_CONN_MANAGER_GET_PRIVATE (object);
 
-	g_warn_if_fail (priv->pending_connections == NULL);
-
 	g_rw_lock_clear (&priv->rw_lock);
-	g_mutex_clear (&priv->pending_connections_lock);
-	g_weak_ref_clear (&priv->store);
 
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (camel_imapx_conn_manager_parent_class)->finalize (object);
@@ -472,13 +424,13 @@ camel_imapx_conn_manager_init (CamelIMAPXConnManager *con_man)
 	con_man->priv = CAMEL_IMAPX_CONN_MANAGER_GET_PRIVATE (con_man);
 
 	g_rw_lock_init (&con_man->priv->rw_lock);
-	g_mutex_init (&con_man->priv->pending_connections_lock);
-	g_weak_ref_init (&con_man->priv->store, NULL);
 }
 
+/* Static functions go here */
+
+/* TODO destroy unused connections in a time-out loop */
 static void
 imapx_conn_shutdown (CamelIMAPXServer *is,
-		     const GError *error,
                      CamelIMAPXConnManager *con_man)
 {
 	ConnectionInfo *cinfo;
@@ -490,14 +442,6 @@ imapx_conn_shutdown (CamelIMAPXServer *is,
 		imapx_conn_manager_remove_info (con_man, cinfo);
 		connection_info_unref (cinfo);
 	}
-
-	/* If one connection ends with this error, then it means all
-	   other opened connections also may end with the same error,
-	   thus better to kill them all from the list of connections.
-	*/
-	if (g_error_matches (error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		camel_imapx_conn_manager_close_connections (con_man, error);
-	}
 }
 
 static void
@@ -589,7 +533,7 @@ imapx_find_connection_unlocked (CamelIMAPXConnManager *con_man,
 		if (camel_imapx_server_has_expensive_command (candidate->is))
 			expensive_connections++;
 
-		if (connection_info_has_folder_name (candidate, folder_name) && camel_imapx_server_is_connected (candidate->is) &&
+		if (connection_info_has_folder_name (candidate, folder_name) &&
 		    (opened_connections >= concurrent_connections || for_expensive_job || !camel_imapx_server_has_expensive_command (candidate->is))) {
 			if (cinfo) {
 				/* group expensive jobs into one connection */
@@ -627,8 +571,7 @@ imapx_find_connection_unlocked (CamelIMAPXConnManager *con_man,
 			ConnectionInfo *candidate = link->data;
 			guint jobs;
 
-			if (!camel_imapx_server_is_connected (candidate->is) ||
-			    !camel_imapx_server_has_expensive_command (candidate->is))
+			if (!camel_imapx_server_has_expensive_command (candidate->is))
 				continue;
 
 			jobs = camel_imapx_server_get_command_count (candidate->is);
@@ -652,8 +595,7 @@ imapx_find_connection_unlocked (CamelIMAPXConnManager *con_man,
 	for (link = list; link != NULL; link = g_list_next (link)) {
 		ConnectionInfo *candidate = link->data;
 
-		if (camel_imapx_server_is_connected (candidate->is) &&
-		    connection_info_is_available (candidate)) {
+		if (connection_info_is_available (candidate)) {
 			if (cinfo)
 				connection_info_unref (cinfo);
 			cinfo = connection_info_ref (candidate);
@@ -676,12 +618,7 @@ imapx_find_connection_unlocked (CamelIMAPXConnManager *con_man,
 	/* Pick the connection with the least number of jobs in progress. */
 	for (link = list; link != NULL; link = g_list_next (link)) {
 		ConnectionInfo *candidate = link->data;
-		gint n_commands;
-
-		if (!camel_imapx_server_is_connected (candidate->is))
-			continue;
-
-		n_commands = camel_imapx_server_get_command_count (candidate->is);
+		gint n_commands = camel_imapx_server_get_command_count (candidate->is);
 
 		if (cinfo == NULL) {
 			cinfo = connection_info_ref (candidate);
@@ -703,7 +640,7 @@ exit:
 		for (link = list; link != NULL; link = g_list_next (link)) {
 			ConnectionInfo *candidate = link->data;
 
-			printf ("   cmds:%d has-expensive:%d avail:%d cinfo:%p server:%p\n", camel_imapx_server_get_command_count (candidate->is), camel_imapx_server_has_expensive_command (candidate->is), connection_info_is_available (candidate), candidate, candidate->is);
+			printf ("   cmds:%d has-expensive:%d avail:%d cinfo:%p\n", camel_imapx_server_get_command_count (candidate->is), camel_imapx_server_has_expensive_command (candidate->is), connection_info_is_available (candidate), candidate);
 		}
 	}
 
@@ -717,37 +654,6 @@ exit:
 	return is;
 }
 
-static gchar
-imapx_conn_manager_get_next_free_tagprefix_unlocked (CamelIMAPXConnManager *con_man)
-{
-	gchar adept;
-	GList *iter;
-
-	/* the 'Z' is dedicated to auth types query */
-	adept = 'A';
-	while (adept < 'Z') {
-		for (iter = con_man->priv->connections; iter; iter = g_list_next (iter)) {
-			ConnectionInfo *cinfo = iter->data;
-
-			if (!cinfo || !cinfo->is)
-				continue;
-
-			if (cinfo->is->tagprefix == adept)
-				break;
-		}
-
-		/* Read all current active connections and none has the same tag prefix */
-		if (!iter)
-			break;
-
-		adept++;
-	}
-
-	g_return_val_if_fail (adept >= 'A' && adept < 'Z', 'Z');
-
-	return adept;
-}
-
 static CamelIMAPXServer *
 imapx_create_new_connection_unlocked (CamelIMAPXConnManager *con_man,
                                       const gchar *folder_name,
@@ -772,7 +678,6 @@ imapx_create_new_connection_unlocked (CamelIMAPXConnManager *con_man,
 	imapx_store = CAMEL_IMAPX_STORE (store);
 
 	is = camel_imapx_server_new (imapx_store);
-	is->tagprefix = imapx_conn_manager_get_next_free_tagprefix_unlocked (con_man);
 
 	/* XXX As part of the connect operation the CamelIMAPXServer will
 	 *     have to call camel_session_authenticate_sync(), but it has
@@ -818,7 +723,7 @@ imapx_create_new_connection_unlocked (CamelIMAPXConnManager *con_man,
 	con_man->priv->connections = g_list_prepend (
 		con_man->priv->connections, cinfo);
 
-	c (is->tagprefix, "Created new connection %p (server:%p) for %s; total connections %d\n", cinfo, cinfo->is, folder_name, g_list_length (con_man->priv->connections));
+	c (is->tagprefix, "Created new connection for %s and total connections %d \n", folder_name, g_list_length (con_man->priv->connections));
 
 exit:
 	g_object_unref (store);
@@ -856,20 +761,11 @@ camel_imapx_conn_manager_get_connection (CamelIMAPXConnManager *con_man,
 
 	g_return_val_if_fail (CAMEL_IS_IMAPX_CONN_MANAGER (con_man), NULL);
 
-	g_mutex_lock (&con_man->priv->pending_connections_lock);
-	if (cancellable) {
-		g_object_ref (cancellable);
-	} else {
-		cancellable = g_cancellable_new ();
-	}
-	con_man->priv->pending_connections = g_slist_prepend (con_man->priv->pending_connections, cancellable);
-	g_mutex_unlock (&con_man->priv->pending_connections_lock);
-
 	/* Hold the writer lock while we requisition a CamelIMAPXServer
 	 * to prevent other threads from adding or removing connections. */
 	CON_WRITE_LOCK (con_man);
 
-	/* Check if we've got cancelled while waiting for the lock. */
+	/* Check if we got cancelled while waiting for the lock. */
 	if (!g_cancellable_set_error_if_cancelled (cancellable, error)) {
 		is = imapx_find_connection_unlocked (con_man, folder_name, for_expensive_job);
 		if (is == NULL) {
@@ -896,7 +792,7 @@ camel_imapx_conn_manager_get_connection (CamelIMAPXConnManager *con_man,
 
 					g_clear_error (&local_error);
 					is = imapx_find_connection_unlocked (con_man, folder_name, for_expensive_job);
-				} else if (local_error) {
+				} else {
 					g_propagate_error (error, local_error);
 				}
 			}
@@ -905,11 +801,6 @@ camel_imapx_conn_manager_get_connection (CamelIMAPXConnManager *con_man,
 
 	CON_WRITE_UNLOCK (con_man);
 
-	g_mutex_lock (&con_man->priv->pending_connections_lock);
-	con_man->priv->pending_connections = g_slist_remove (con_man->priv->pending_connections, cancellable);
-	g_object_unref (cancellable);
-	g_mutex_unlock (&con_man->priv->pending_connections_lock);
-
 	return is;
 }
 
@@ -957,48 +848,19 @@ camel_imapx_conn_manager_update_con_info (CamelIMAPXConnManager *con_man,
 }
 
 void
-camel_imapx_conn_manager_close_connections (CamelIMAPXConnManager *con_man,
-					    const GError *error)
+camel_imapx_conn_manager_close_connections (CamelIMAPXConnManager *con_man)
 {
-	GList *iter, *connections;
-
 	g_return_if_fail (CAMEL_IS_IMAPX_CONN_MANAGER (con_man));
 
-	/* Do this before acquiring the write lock, because any pending
-	   connection holds the write lock, thus makes this request starve. */
-	imax_conn_manager_cancel_pending_connections (con_man);
-
 	CON_WRITE_LOCK (con_man);
 
-	c('*', "Closing all %d connections, with propagated error: %s\n", g_list_length (con_man->priv->connections), error ? error->message : "none");
+	c('*', "Closing all %d connections\n", g_list_length (con_man->priv->connections));
 
-	connections = con_man->priv->connections;
+	g_list_free_full (
+		con_man->priv->connections,
+		(GDestroyNotify) connection_info_cancel_and_unref);
 	con_man->priv->connections = NULL;
 
 	CON_WRITE_UNLOCK (con_man);
-
-	for (iter = connections; iter; iter = g_list_next (iter)) {
-		connection_info_set_shutdown_error (iter->data, error);
-	}
-
-	g_list_free_full (connections, (GDestroyNotify) connection_info_cancel_and_unref);
 }
 
-/* for debugging purposes only */
-void
-camel_imapx_conn_manager_dump_queue_status (CamelIMAPXConnManager *con_man)
-{
-	GList *list, *link;
-
-	g_return_if_fail (CAMEL_IS_IMAPX_CONN_MANAGER (con_man));
-
-	list = imapx_conn_manager_list_info (con_man);
-
-	for (link = list; link != NULL; link = g_list_next (link)) {
-		ConnectionInfo *cinfo = link->data;
-		camel_imapx_server_dump_queue_status (cinfo->is);
-		connection_info_unref (cinfo);
-	}
-
-	g_list_free (list);
-}
