@@ -1,21 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* camel-imap-folder.c : class for a imap folder */
-/*
- * Authors: Michael Zucchi <notzed@ximian.com>
+/* camel-imap-folder.c : class for a imap folder
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software; you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Michael Zucchi <notzed@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -216,8 +216,6 @@ imapx_folder_finalize (GObject *object)
 	g_hash_table_destroy (folder->priv->move_to_real_junk_uids);
 	g_hash_table_destroy (folder->priv->move_to_real_trash_uids);
 
-	g_weak_ref_clear (&folder->priv->mailbox);
-
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (camel_imapx_folder_parent_class)->finalize (object);
 }
@@ -302,29 +300,44 @@ imapx_search_by_uids (CamelFolder *folder,
                       GCancellable *cancellable,
                       GError **error)
 {
+	CamelIMAPXStore *imapx_store;
 	CamelIMAPXFolder *imapx_folder;
 	CamelIMAPXSearch *imapx_search;
+	CamelIMAPXServer *imapx_server = NULL;
+	const gchar *folder_name;
+	CamelStore *store;
 	GPtrArray *matches;
 
 	if (uids->len == 0)
 		return g_ptr_array_new ();
 
 	imapx_folder = CAMEL_IMAPX_FOLDER (folder);
+	store = camel_folder_get_parent_store (folder);
+	folder_name = camel_folder_get_full_name (folder);
+
+	imapx_store = CAMEL_IMAPX_STORE (store);
+	if (camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store)))
+		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, FALSE, cancellable, NULL);
 
 	g_mutex_lock (&imapx_folder->search_lock);
 
 	imapx_search = CAMEL_IMAPX_SEARCH (imapx_folder->search);
+	camel_imapx_search_set_server (imapx_search, imapx_server);
 
 	camel_folder_search_set_folder (imapx_folder->search, folder);
-	camel_imapx_search_set_cancellable_and_error (imapx_search, cancellable, error);
 
 	matches = camel_folder_search_search (
 		imapx_folder->search, expression, uids, cancellable, error);
 
-	camel_imapx_search_set_cancellable_and_error (imapx_search, NULL, NULL);
+	camel_imapx_search_set_server (imapx_search, NULL);
+
+	if (imapx_server)
+		camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
 
 	g_mutex_unlock (&imapx_folder->search_lock);
 
+	g_clear_object (&imapx_server);
+
 	return matches;
 }
 
@@ -334,26 +347,41 @@ imapx_count_by_expression (CamelFolder *folder,
                            GCancellable *cancellable,
                            GError **error)
 {
+	CamelIMAPXStore *imapx_store;
 	CamelIMAPXFolder *imapx_folder;
 	CamelIMAPXSearch *imapx_search;
+	CamelIMAPXServer *imapx_server = NULL;
+	const gchar *folder_name;
+	CamelStore *store;
 	guint32 matches;
 
 	imapx_folder = CAMEL_IMAPX_FOLDER (folder);
+	store = camel_folder_get_parent_store (folder);
+	folder_name = camel_folder_get_full_name (folder);
+
+	imapx_store = CAMEL_IMAPX_STORE (store);
+	if (camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store)))
+		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, FALSE, cancellable, NULL);
 
 	g_mutex_lock (&imapx_folder->search_lock);
 
 	imapx_search = CAMEL_IMAPX_SEARCH (imapx_folder->search);
+	camel_imapx_search_set_server (imapx_search, imapx_server);
 
 	camel_folder_search_set_folder (imapx_folder->search, folder);
-	camel_imapx_search_set_cancellable_and_error (imapx_search, cancellable, error);
 
 	matches = camel_folder_search_count (
 		imapx_folder->search, expression, cancellable, error);
 
-	camel_imapx_search_set_cancellable_and_error (imapx_search, NULL, NULL);
+	camel_imapx_search_set_server (imapx_search, NULL);
+
+	if (imapx_server)
+		camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
 
 	g_mutex_unlock (&imapx_folder->search_lock);
 
+	g_clear_object (&imapx_server);
+
 	return matches;
 }
 
@@ -363,26 +391,41 @@ imapx_search_by_expression (CamelFolder *folder,
                             GCancellable *cancellable,
                             GError **error)
 {
+	CamelIMAPXStore *imapx_store;
 	CamelIMAPXFolder *imapx_folder;
 	CamelIMAPXSearch *imapx_search;
+	CamelIMAPXServer *imapx_server = NULL;
+	const gchar *folder_name;
+	CamelStore *store;
 	GPtrArray *matches;
 
 	imapx_folder = CAMEL_IMAPX_FOLDER (folder);
+	store = camel_folder_get_parent_store (folder);
+	folder_name = camel_folder_get_full_name (folder);
+
+	imapx_store = CAMEL_IMAPX_STORE (store);
+	if (camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store)))
+		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, FALSE, cancellable, NULL);
 
 	g_mutex_lock (&imapx_folder->search_lock);
 
 	imapx_search = CAMEL_IMAPX_SEARCH (imapx_folder->search);
+	camel_imapx_search_set_server (imapx_search, imapx_server);
 
 	camel_folder_search_set_folder (imapx_folder->search, folder);
-	camel_imapx_search_set_cancellable_and_error (imapx_search, cancellable, error);
 
 	matches = camel_folder_search_search (
 		imapx_folder->search, expression, NULL, cancellable, error);
 
-	camel_imapx_search_set_cancellable_and_error (imapx_search, NULL, NULL);
+	camel_imapx_search_set_server (imapx_search, NULL);
+
+	if (imapx_server)
+		camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
 
 	g_mutex_unlock (&imapx_folder->search_lock);
 
+	g_clear_object (&imapx_server);
+
 	return matches;
 }
 
@@ -412,7 +455,6 @@ imapx_append_message_sync (CamelFolder *folder,
 	CamelIMAPXServer *imapx_server;
 	CamelIMAPXMailbox *mailbox = NULL;
 	const gchar *folder_name;
-	GError *local_error = NULL;
 	gboolean success = FALSE;
 
 	if (appended_uid != NULL)
@@ -438,28 +480,10 @@ imapx_append_message_sync (CamelFolder *folder,
 	success = camel_imapx_server_append_message (
 		imapx_server, mailbox, folder->summary,
 		CAMEL_IMAPX_FOLDER (folder)->cache, message,
-		info, appended_uid, cancellable, &local_error);
+		info, appended_uid, cancellable, error);
 
 	camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
 
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, FALSE, cancellable, &local_error);
-		if (imapx_server) {
-			success = camel_imapx_server_append_message (
-				imapx_server, mailbox, folder->summary,
-				CAMEL_IMAPX_FOLDER (folder)->cache, message,
-				info, appended_uid, cancellable, &local_error);
-
-			camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
-		}
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
-
 exit:
 	g_clear_object (&mailbox);
 	g_clear_object (&imapx_server);
@@ -476,7 +500,6 @@ imapx_expunge_sync (CamelFolder *folder,
 	CamelIMAPXStore *imapx_store;
 	CamelIMAPXServer *imapx_server;
 	CamelIMAPXMailbox *mailbox = NULL;
-	GError *local_error = NULL;
 	const gchar *folder_name;
 	gboolean success = FALSE;
 
@@ -500,6 +523,7 @@ imapx_expunge_sync (CamelFolder *folder,
 	if ((store->flags & CAMEL_STORE_VTRASH) == 0) {
 		CamelFolder *trash;
 		const gchar *full_name;
+		GError *local_error = NULL;
 
 		full_name = camel_folder_get_full_name (folder);
 
@@ -510,8 +534,6 @@ imapx_expunge_sync (CamelFolder *folder,
 			GPtrArray *known_uids;
 			gint ii;
 
-			camel_folder_summary_lock (folder->summary);
-
 			camel_folder_summary_prepare_fetch_all (folder->summary, NULL);
 			known_uids = camel_folder_summary_get_array (folder->summary);
 
@@ -524,8 +546,6 @@ imapx_expunge_sync (CamelFolder *folder,
 				}
 			}
 
-			camel_folder_summary_unlock (folder->summary);
-
 			camel_folder_summary_free_array (known_uids);
 		}
 
@@ -533,25 +553,11 @@ imapx_expunge_sync (CamelFolder *folder,
 		g_clear_error (&local_error);
 	}
 
-	success = camel_imapx_server_expunge (imapx_server, mailbox, cancellable, &local_error);
+	success = camel_imapx_server_expunge (
+		imapx_server, mailbox, cancellable, error);
 
 	camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
 
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, FALSE, cancellable, &local_error);
-		if (imapx_server) {
-			success = camel_imapx_server_expunge (imapx_server, mailbox, cancellable, &local_error);
-
-			camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
-		}
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
-
 exit:
 	g_clear_object (&mailbox);
 	g_clear_object (&imapx_server);
@@ -612,7 +618,6 @@ imapx_get_message_sync (CamelFolder *folder,
 	GIOStream *base_stream;
 	const gchar *path = NULL;
 	gboolean offline_message = FALSE;
-	GError *local_error = NULL;
 
 	imapx_folder = CAMEL_IMAPX_FOLDER (folder);
 	store = camel_folder_get_parent_store (folder);
@@ -661,28 +666,10 @@ imapx_get_message_sync (CamelFolder *folder,
 		stream = camel_imapx_server_get_message (
 			imapx_server, mailbox, folder->summary,
 			CAMEL_IMAPX_FOLDER (folder)->cache, uid,
-			cancellable, &local_error);
+			cancellable, error);
 
 		camel_imapx_store_folder_op_done (CAMEL_IMAPX_STORE (store), imapx_server, folder_name);
 
-		while (!stream && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-			g_clear_error (&local_error);
-			g_clear_object (&imapx_server);
-
-			imapx_server = camel_imapx_store_ref_server (CAMEL_IMAPX_STORE (store), folder_name, FALSE, cancellable, &local_error);
-			if (imapx_server) {
-				stream = camel_imapx_server_get_message (
-					imapx_server, mailbox, folder->summary,
-					CAMEL_IMAPX_FOLDER (folder)->cache, uid,
-					cancellable, &local_error);
-
-				camel_imapx_store_folder_op_done (CAMEL_IMAPX_STORE (store), imapx_server, folder_name);
-			}
-		}
-
-		if (local_error)
-			g_propagate_error (error, local_error);
-
 		g_clear_object (&mailbox);
 		g_clear_object (&imapx_server);
 	}
@@ -740,7 +727,6 @@ imapx_get_quota_info_sync (CamelFolder *folder,
 	const gchar *folder_name;
 	gchar **quota_roots;
 	gboolean success = FALSE;
-	GError *local_error = NULL;
 
 	store = camel_folder_get_parent_store (folder);
 	folder_name = camel_folder_get_full_name (folder);
@@ -758,25 +744,11 @@ imapx_get_quota_info_sync (CamelFolder *folder,
 		goto exit;
 	}
 
-	success = camel_imapx_server_update_quota_info (imapx_server, mailbox, cancellable, &local_error);
+	success = camel_imapx_server_update_quota_info (
+		imapx_server, mailbox, cancellable, error);
 
 	camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
 
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, FALSE, cancellable, &local_error);
-		if (imapx_server) {
-			success = camel_imapx_server_update_quota_info (imapx_server, mailbox, cancellable, &local_error);
-
-			camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
-		}
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
-
 	if (!success)
 		goto exit;
 
@@ -824,17 +796,12 @@ imapx_refresh_info_sync (CamelFolder *folder,
 	CamelIMAPXServer *imapx_server;
 	CamelIMAPXMailbox *mailbox = NULL;
 	CamelFolderChangeInfo *changes;
-	gchar *folder_name;
+	const gchar *folder_name;
 	gboolean success = FALSE;
-	GError *local_error = NULL;
 
 	store = camel_folder_get_parent_store (folder);
+	folder_name = camel_folder_get_full_name (folder);
 
-	/* Not connected, thus skip the operation */
-	if (!camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store)))
-		return TRUE;
-
-	folder_name = g_strdup (camel_folder_get_full_name (folder));
 	imapx_store = CAMEL_IMAPX_STORE (store);
 	imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, TRUE, cancellable, error);
 
@@ -849,25 +816,11 @@ imapx_refresh_info_sync (CamelFolder *folder,
 		goto exit;
 	}
 
-	changes = camel_imapx_server_refresh_info (imapx_server, mailbox, cancellable, &local_error);
+	changes = camel_imapx_server_refresh_info (
+		imapx_server, mailbox, cancellable, error);
 
 	camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
 
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, TRUE, cancellable, &local_error);
-		if (imapx_server) {
-			changes = camel_imapx_server_refresh_info (imapx_server, mailbox, cancellable, &local_error);
-
-			camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
-		}
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
-
 	if (changes != NULL) {
 		if (camel_folder_change_info_changed (changes))
 			camel_folder_changed (folder, changes);
@@ -878,7 +831,6 @@ imapx_refresh_info_sync (CamelFolder *folder,
 exit:
 	g_clear_object (&mailbox);
 	g_clear_object (&imapx_server);
-	g_free (folder_name);
 
 	return success;
 }
@@ -1082,15 +1034,10 @@ imapx_synchronize_sync (CamelFolder *folder,
 	const gchar *folder_name;
 	gboolean need_to_expunge;
 	gboolean success = FALSE;
-	GError *local_error = NULL;
 
 	store = camel_folder_get_parent_store (folder);
 	folder_name = camel_folder_get_full_name (folder);
 
-	/* Not connected, thus skip the operation */
-	if (!camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store)))
-		return TRUE;
-
 	imapx_store = CAMEL_IMAPX_STORE (store);
 	/* while it can be expensive job, do not treat it as such, to avoid a blockage
 	   by really expensive jobs */
@@ -1106,19 +1053,8 @@ imapx_synchronize_sync (CamelFolder *folder,
 		goto exit;
 	}
 
-	success = camel_imapx_server_sync_changes (imapx_server, mailbox, cancellable, &local_error);
-
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
-
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, FALSE, cancellable, &local_error);
-		if (imapx_server) {
-			success = camel_imapx_server_sync_changes (imapx_server, mailbox, cancellable, &local_error);
-		}
-	}
+	success = camel_imapx_server_sync_changes (
+		imapx_server, mailbox, cancellable, error);
 
 	if (success) {
 		success = imapx_move_to_real_junk (
@@ -1138,26 +1074,11 @@ imapx_synchronize_sync (CamelFolder *folder,
 	 * then sync again incase expunge changed anything */
 
 	if (success && expunge) {
-		success = camel_imapx_server_expunge (imapx_server, mailbox, cancellable, &local_error);
-
-		while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-			camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
-
-			g_clear_error (&local_error);
-			g_clear_object (&imapx_server);
-
-			imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, FALSE, cancellable, &local_error);
-			if (imapx_server) {
-				success = camel_imapx_server_expunge (imapx_server, mailbox, cancellable, &local_error);
-			}
-		}
+		success = camel_imapx_server_expunge (
+			imapx_server, mailbox, cancellable, error);
 	}
 
-	if (local_error)
-		g_propagate_error (error, local_error);
-
-	if (imapx_server)
-		camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
+	camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
 
 exit:
 	g_clear_object (&mailbox);
@@ -1178,7 +1099,6 @@ imapx_synchronize_message_sync (CamelFolder *folder,
 	CamelIMAPXMailbox *mailbox = NULL;
 	const gchar *folder_name;
 	gboolean success = FALSE;
-	GError *local_error = NULL;
 
 	store = camel_folder_get_parent_store (folder);
 	folder_name = camel_folder_get_full_name (folder);
@@ -1200,28 +1120,10 @@ imapx_synchronize_message_sync (CamelFolder *folder,
 	success = camel_imapx_server_sync_message (
 		imapx_server, mailbox, folder->summary,
 		CAMEL_IMAPX_FOLDER (folder)->cache, uid,
-		cancellable, &local_error);
+		cancellable, error);
 
 	camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
 
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, FALSE, cancellable, &local_error);
-		if (imapx_server) {
-			success = camel_imapx_server_sync_message (
-				imapx_server, mailbox, folder->summary,
-				CAMEL_IMAPX_FOLDER (folder)->cache, uid,
-				cancellable, &local_error);
-
-			camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
-		}
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
-
 exit:
 	g_clear_object (&mailbox);
 	g_clear_object (&imapx_server);
@@ -1245,7 +1147,6 @@ imapx_transfer_messages_to_sync (CamelFolder *source,
 	CamelIMAPXMailbox *dst_mailbox = NULL;
 	const gchar *folder_name;
 	gboolean success = FALSE;
-	GError *local_error = NULL;
 
 	store = camel_folder_get_parent_store (source);
 	folder_name = camel_folder_get_full_name (source);
@@ -1274,27 +1175,10 @@ imapx_transfer_messages_to_sync (CamelFolder *source,
 
 	success = camel_imapx_server_copy_message (
 		imapx_server, src_mailbox, dst_mailbox, uids,
-		delete_originals, cancellable, &local_error);
+		delete_originals, cancellable, error);
 
 	camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
 
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, FALSE, cancellable, &local_error);
-		if (imapx_server) {
-			success = camel_imapx_server_copy_message (
-				imapx_server, src_mailbox, dst_mailbox, uids,
-				delete_originals, cancellable, &local_error);
-
-			camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
-		}
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
-
 	/* Update destination folder only if it's not frozen,
 	 * to avoid updating for each "move" action on a single
 	 * message while filtering. */
@@ -1426,11 +1310,6 @@ camel_imapx_folder_init (CamelIMAPXFolder *imapx_folder)
 	g_mutex_init (&imapx_folder->priv->move_to_hash_table_lock);
 	imapx_folder->priv->move_to_real_junk_uids = move_to_real_junk_uids;
 	imapx_folder->priv->move_to_real_trash_uids = move_to_real_trash_uids;
-
-	g_mutex_init (&imapx_folder->search_lock);
-	g_mutex_init (&imapx_folder->stream_lock);
-
-	g_weak_ref_init (&imapx_folder->priv->mailbox, NULL);
 }
 
 CamelFolder *
@@ -1496,17 +1375,14 @@ camel_imapx_folder_new (CamelStore *store,
 		return NULL;
 	}
 
-	/* Ensure cache will never expire, otherwise
-	 * it causes redownload of messages. */
-	camel_data_cache_set_expire_age (imapx_folder->cache, -1);
-	camel_data_cache_set_expire_access (imapx_folder->cache, -1);
-
 	state_file = g_build_filename (folder_dir, "cmeta", NULL);
 	camel_object_set_state_filename (CAMEL_OBJECT (folder), state_file);
 	g_free (state_file);
 	camel_object_state_read (CAMEL_OBJECT (folder));
 
-	imapx_folder->search = camel_imapx_search_new (CAMEL_IMAPX_STORE (store));
+	imapx_folder->search = camel_imapx_search_new ();
+	g_mutex_init (&imapx_folder->search_lock);
+	g_mutex_init (&imapx_folder->stream_lock);
 
 	if (filter_all)
 		folder->folder_flags |= CAMEL_FOLDER_FILTER_RECENT;
@@ -1624,7 +1500,6 @@ camel_imapx_folder_list_mailbox (CamelIMAPXFolder *folder,
 	gchar *mailbox_name = NULL;
 	gchar *pattern;
 	gboolean success;
-	GError *local_error = NULL;
 
 	g_return_val_if_fail (CAMEL_IS_IMAPX_FOLDER (folder), FALSE);
 
@@ -1677,20 +1552,8 @@ camel_imapx_folder_list_mailbox (CamelIMAPXFolder *folder,
 	pattern = camel_utf8_utf7 (mailbox_name);
 
 	/* This creates a mailbox instance from the LIST response. */
-	success = camel_imapx_server_list (server, pattern, 0, cancellable, &local_error);
-
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&server);
-
-		server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-		if (server) {
-			success = camel_imapx_server_list (server, pattern, 0, cancellable, &local_error);
-		}
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
+	success = camel_imapx_server_list (
+		server, pattern, 0, cancellable, error);
 
 	g_free (pattern);
 
