@@ -1,17 +1,17 @@
 /*
  * camel-imapx-input-stream.h
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -27,7 +27,6 @@
 
 #include <camel/camel.h>
 
-#include "camel-imapx-server.h"
 #include "camel-imapx-utils.h"
 
 #define CAMEL_IMAPX_INPUT_STREAM_GET_PRIVATE(obj) \
@@ -89,7 +88,7 @@ imapx_input_stream_fill (CamelIMAPXInputStream *is,
 		 * accordingly */
 		if (!left)
 			g_set_error (
-				error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT,
+				error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
 				_("Source stream returned no data"));
 		return -1;
 	}
@@ -368,58 +367,54 @@ camel_imapx_input_stream_astring (CamelIMAPXInputStream *is,
 	p = is->priv->ptr;
 	e = is->priv->end;
 
-	if (is->priv->unget) {
+	/* skip whitespace/prefill buffer */
+	do {
+		while (p >= e ) {
+			is->priv->ptr = p;
+			if (imapx_input_stream_fill (is, cancellable, error) == IMAPX_TOK_ERROR)
+				return FALSE;
+			p = is->priv->ptr;
+			e = is->priv->end;
+		}
+		c = *p++;
+	} while (c == ' ' || c == '\r');
+
+	if (c == '\"' || c == '{') {
 		tok = camel_imapx_input_stream_token (is, data, &len, cancellable, error);
 	} else {
-		/* skip whitespace/prefill buffer */
-		do {
-			while (p >= e ) {
-				is->priv->ptr = p;
-				if (imapx_input_stream_fill (is, cancellable, error) == IMAPX_TOK_ERROR)
-					return FALSE;
-				p = is->priv->ptr;
-				e = is->priv->end;
-			}
-			c = *p++;
-		} while (c == ' ' || c == '\r');
+		guchar *o, *oe;
 
-		if (c == '\"' || c == '{') {
-			tok = camel_imapx_input_stream_token (is, data, &len, cancellable, error);
-		} else {
-			guchar *o, *oe;
+		tok = IMAPX_TOK_STRING;
 
-			tok = IMAPX_TOK_STRING;
-
-			/* <any %x01-7F except "(){ " / %x00-1F / %x7F > */
-			o = is->priv->tokenbuf;
-			oe = is->priv->tokenbuf + is->priv->bufsize - 1;
-			*o++ = c;
-			while (1) {
-				while (p < e) {
-					c = *p++;
-					if (c <= 0x1f || c == 0x7f || c == '(' || c == ')' || c == '{' || c == ' ') {
-						if (c == ' ' || c == '\r')
-							is->priv->ptr = p;
-						else
-							is->priv->ptr = p - 1;
-						*o = 0;
-						*data = is->priv->tokenbuf;
-						return TRUE;
-					}
-
-					if (o >= oe) {
-						camel_imapx_input_stream_grow (is, 0, &p, &o);
-						oe = is->priv->tokenbuf + is->priv->bufsize - 1;
-						e = is->priv->end;
-					}
-					*o++ = c;
+		/* <any %x01-7F except "(){ " / %x00-1F / %x7F > */
+		o = is->priv->tokenbuf;
+		oe = is->priv->tokenbuf + is->priv->bufsize - 1;
+		*o++ = c;
+		while (1) {
+			while (p < e) {
+				c = *p++;
+				if (c <= 0x1f || c == 0x7f || c == '(' || c == ')' || c == '{' || c == ' ') {
+					if (c == ' ' || c == '\r')
+						is->priv->ptr = p;
+					else
+						is->priv->ptr = p - 1;
+					*o = 0;
+					*data = is->priv->tokenbuf;
+					return TRUE;
 				}
-				is->priv->ptr = p;
-				if (imapx_input_stream_fill (is, cancellable, error) == IMAPX_TOK_ERROR)
-					return FALSE;
-				p = is->priv->ptr;
-				e = is->priv->end;
+
+				if (o >= oe) {
+					camel_imapx_input_stream_grow (is, 0, &p, &o);
+					oe = is->priv->tokenbuf + is->priv->bufsize - 1;
+					e = is->priv->end;
+				}
+				*o++ = c;
 			}
+			is->priv->ptr = p;
+			if (imapx_input_stream_fill (is, cancellable, error) == IMAPX_TOK_ERROR)
+				return FALSE;
+			p = is->priv->ptr;
+			e = is->priv->end;
 		}
 	}
 
