@@ -1,17 +1,17 @@
 /*
  * camel-imapx-job.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -417,33 +417,3 @@ camel_imapx_job_take_error (CamelIMAPXJob *job,
 	real_job->error = error;  /* takes ownership */
 }
 
-/**
- * camel_imapx_job_set_error_if_failed:
- * @job: a #CamelIMAPXJob
- * @error: a location for a #GError
- *
- * Sets @error to a new GError instance and returns TRUE, if the job has set
- * an error or when it was cancelled.
- *
- * Returns: Whether the job failed.
- *
- * Since: 3.12.4
- **/
-gboolean
-camel_imapx_job_set_error_if_failed (CamelIMAPXJob *job,
-				     GError **error)
-{
-	CamelIMAPXRealJob *real_job;
-
-	g_return_val_if_fail (CAMEL_IS_IMAPX_JOB (job), TRUE);
-	g_return_val_if_fail (error != NULL, TRUE);
-
-	real_job = (CamelIMAPXRealJob *) job;
-
-	if (real_job->error) {
-		g_propagate_error (error, g_error_copy (real_job->error));
-		return TRUE;
-	}
-
-	return g_cancellable_set_error_if_cancelled (real_job->cancellable, error);
-}
