@@ -1,17 +1,17 @@
 /*
  * camel-imapx-job.h
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -50,7 +50,7 @@ struct _CamelIMAPXJob {
 	guint noreply:1;	/* dont wait for reply */
 	guint32 type;		/* operation type */
 	gint pri;		/* the command priority */
-	volatile gint commands;	/* counts how many commands are outstanding */
+	gshort commands;	/* counts how many commands are outstanding */
 };
 
 CamelIMAPXJob *	camel_imapx_job_new		(GCancellable *cancellable);
@@ -80,9 +80,6 @@ void		camel_imapx_job_set_mailbox	(CamelIMAPXJob *job,
 GCancellable *	camel_imapx_job_get_cancellable	(CamelIMAPXJob *job);
 void		camel_imapx_job_take_error	(CamelIMAPXJob *job,
 						 GError *error);
-gboolean	camel_imapx_job_set_error_if_failed
-						(CamelIMAPXJob *job,
-						 GError **error);
 
 G_END_DECLS
 
