@@ -1,17 +1,17 @@
 /*
  * camel-imapx-namespace-response.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -323,57 +323,6 @@ camel_imapx_namespace_response_list (CamelIMAPXNamespaceResponse *response)
 	return g_list_copy_deep (head, (GCopyFunc) g_object_ref, NULL);
 }
 
-/**
- * camel_imapx_namespace_response_remove:
- * @response: a #CamelIMAPXNamespaceResponse
- * @namespace: a #CamelIMAPXNamespace to add
- *
- * Adds a @namespace into the list of namespaces. It adds its own
- * reference on the @namespace.
- *
- * Since: 3.12.9
- **/
-void
-camel_imapx_namespace_response_add (CamelIMAPXNamespaceResponse *response,
-				    CamelIMAPXNamespace *namespace)
-{
-	g_return_if_fail (CAMEL_IS_IMAPX_NAMESPACE_RESPONSE (response));
-	g_return_if_fail (CAMEL_IS_IMAPX_NAMESPACE (namespace));
-
-	g_queue_push_tail (&response->priv->namespaces, g_object_ref (namespace));
-}
-
-/**
- * camel_imapx_namespace_response_remove:
- * @response: a #CamelIMAPXNamespaceResponse
- * @namespace: a #CamelIMAPXNamespace to remove
- *
- * Removes @namespace from the list of namespaces in the @response.
- * If no such namespace exists then does nothing.
- *
- * Since: 3.12.9
- **/
-void
-camel_imapx_namespace_response_remove (CamelIMAPXNamespaceResponse *response,
-				       CamelIMAPXNamespace *namespace)
-{
-	GList *link;
-
-	g_return_if_fail (CAMEL_IS_IMAPX_NAMESPACE_RESPONSE (response));
-	g_return_if_fail (CAMEL_IS_IMAPX_NAMESPACE (namespace));
-
-	for (link = g_queue_peek_head_link (&response->priv->namespaces);
-	     link; link = g_list_next (link)) {
-		CamelIMAPXNamespace *ns = link->data;
-
-		if (camel_imapx_namespace_equal (namespace, ns)) {
-			g_queue_remove (&response->priv->namespaces, ns);
-			g_object_unref (ns);
-			break;
-		}
-	}
-}
-
 /**
  * camel_imapx_namespace_response_lookup:
  * @response: a #CamelIMAPXNamespaceResponse
@@ -551,10 +500,7 @@ camel_imapx_namespace_response_lookup_for_path (CamelIMAPXNamespaceResponse *res
 
 		/* Special handling when searching for an empty prefix. */
 		if (find_empty_prefix) {
-			if (*prefix == '\0' ||
-			    g_ascii_strcasecmp (prefix, "INBOX") == 0 ||
-			    (g_ascii_strncasecmp (prefix, "INBOX", 5) == 0 &&
-			     prefix[5] == separator && !prefix[6])) {
+			if (*prefix == '\0') {
 				g_queue_push_tail (&candidates, namespace);
 				break;
 			}
@@ -577,11 +523,6 @@ camel_imapx_namespace_response_lookup_for_path (CamelIMAPXNamespaceResponse *res
 
 	/* First candidate is the preferred namespace. */
 	match = g_queue_pop_head (&candidates);
-
-	/* Fallback to the first known namespace when none suitable for the given path found */
-	if (!match && head && head->data)
-		match = head->data;
-
 	if (match != NULL)
 		g_object_ref (match);
 
