@@ -1,17 +1,17 @@
 /*
  * camel-imapx-search.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -27,16 +27,13 @@
 	((obj), CAMEL_TYPE_IMAPX_SEARCH, CamelIMAPXSearchPrivate))
 
 struct _CamelIMAPXSearchPrivate {
-	GWeakRef imapx_store;
+	GWeakRef server;
 	gint *local_data_search; /* not NULL, if testing whether all used headers are all locally available */
-
-	GCancellable *cancellable; /* not referenced */
-	GError **error; /* not referenced */
 };
 
 enum {
 	PROP_0,
-	PROP_STORE
+	PROP_SERVER
 };
 
 G_DEFINE_TYPE (
@@ -51,8 +48,8 @@ imapx_search_set_property (GObject *object,
                            GParamSpec *pspec)
 {
 	switch (property_id) {
-		case PROP_STORE:
-			camel_imapx_search_set_store (
+		case PROP_SERVER:
+			camel_imapx_search_set_server (
 				CAMEL_IMAPX_SEARCH (object),
 				g_value_get_object (value));
 			return;
@@ -68,10 +65,10 @@ imapx_search_get_property (GObject *object,
                            GParamSpec *pspec)
 {
 	switch (property_id) {
-		case PROP_STORE:
+		case PROP_SERVER:
 			g_value_take_object (
 				value,
-				camel_imapx_search_ref_store (
+				camel_imapx_search_ref_server (
 				CAMEL_IMAPX_SEARCH (object)));
 			return;
 	}
@@ -86,25 +83,12 @@ imapx_search_dispose (GObject *object)
 
 	priv = CAMEL_IMAPX_SEARCH_GET_PRIVATE (object);
 
-	g_weak_ref_set (&priv->imapx_store, NULL);
+	g_weak_ref_set (&priv->server, NULL);
 
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (camel_imapx_search_parent_class)->dispose (object);
 }
 
-static void
-imapx_search_finalize (GObject *object)
-{
-	CamelIMAPXSearchPrivate *priv;
-
-	priv = CAMEL_IMAPX_SEARCH_GET_PRIVATE (object);
-
-	g_weak_ref_clear (&priv->imapx_store);
-
-	/* Chain up to parent's finalize() method. */
-	G_OBJECT_CLASS (camel_imapx_search_parent_class)->finalize (object);
-}
-
 static CamelSExpResult *
 imapx_search_result_match_all (CamelSExp *sexp,
                                CamelFolderSearch *search)
@@ -153,67 +137,43 @@ imapx_search_result_match_none (CamelSExp *sexp,
 static CamelSExpResult *
 imapx_search_process_criteria (CamelSExp *sexp,
                                CamelFolderSearch *search,
-                               CamelIMAPXStore *imapx_store,
+                               CamelIMAPXServer *server,
                                const GString *criteria,
                                const gchar *from_function)
 {
 	CamelSExpResult *result;
-	CamelIMAPXSearch *imapx_search = CAMEL_IMAPX_SEARCH (search);
 	CamelIMAPXMailbox *mailbox;
 	GPtrArray *uids = NULL;
-	GError *local_error = NULL;
+	GError *error = NULL;
 
 	mailbox = camel_imapx_folder_list_mailbox (
-		CAMEL_IMAPX_FOLDER (search->folder), imapx_search->priv->cancellable, &local_error);
+		CAMEL_IMAPX_FOLDER (search->folder), NULL, &error);
 
 	/* Sanity check. */
 	g_return_val_if_fail (
-		((mailbox != NULL) && (local_error == NULL)) ||
-		((mailbox == NULL) && (local_error != NULL)), NULL);
+		((mailbox != NULL) && (error == NULL)) ||
+		((mailbox == NULL) && (error != NULL)), NULL);
 
 	if (mailbox != NULL) {
-		CamelIMAPXStore *imapx_store;
-		CamelIMAPXServer *imapx_server;
-		const gchar *folder_name;
-
-		imapx_store = camel_imapx_search_ref_store (imapx_search);
-
-		/* there should always be one, held by one of the callers of this function */
-		g_warn_if_fail (imapx_store != NULL);
-
-		folder_name = camel_folder_get_full_name (search->folder);
-		imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, TRUE, imapx_search->priv->cancellable, &local_error);
-		if (imapx_server) {
-			uids = camel_imapx_server_uid_search (imapx_server, mailbox, criteria->str, imapx_search->priv->cancellable, &local_error);
-			camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
-
-			while (!uids && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-				g_clear_error (&local_error);
-				g_clear_object (&imapx_server);
-
-				imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, TRUE, imapx_search->priv->cancellable, &local_error);
-				if (imapx_server) {
-					uids = camel_imapx_server_uid_search (imapx_server, mailbox, criteria->str, imapx_search->priv->cancellable, &local_error);
-					camel_imapx_store_folder_op_done (imapx_store, imapx_server, folder_name);
-				}
-			}
-		}
-
-		g_clear_object (&imapx_server);
-		g_clear_object (&imapx_store);
+		uids = camel_imapx_server_uid_search (
+			server, mailbox, criteria->str, NULL, &error);
 		g_object_unref (mailbox);
 	}
 
 	/* Sanity check. */
 	g_return_val_if_fail (
-		((uids != NULL) && (local_error == NULL)) ||
-		((uids == NULL) && (local_error != NULL)), NULL);
+		((uids != NULL) && (error == NULL)) ||
+		((uids == NULL) && (error != NULL)), NULL);
 
-	if (local_error != NULL) {
-		g_propagate_error (imapx_search->priv->error, local_error);
-
-		/* Make like we've got an empty result */
+	/* XXX No allowance for errors in CamelSExp callbacks!
+	 *     Dump the error to the console and make like we
+	 *     got an empty result. */
+	if (error != NULL) {
+		g_warning (
+			"%s: (UID SEARCH %s): %s",
+			from_function, criteria->str, error->message);
 		uids = g_ptr_array_new ();
+		g_error_free (error);
 	}
 
 	if (search->current != NULL) {
@@ -236,7 +196,7 @@ imapx_search_match_all (CamelSExp *sexp,
                         CamelFolderSearch *search)
 {
 	CamelIMAPXSearch *imapx_search = CAMEL_IMAPX_SEARCH (search);
-	CamelIMAPXStore *imapx_store;
+	CamelIMAPXServer *server;
 	CamelSExpResult *result;
 	GPtrArray *summary;
 	gint local_data_search = 0, *prev_local_data_search, ii;
@@ -244,9 +204,9 @@ imapx_search_match_all (CamelSExp *sexp,
 	if (argc != 1)
 		return imapx_search_result_match_none (sexp, search);
 
-	imapx_store = camel_imapx_search_ref_store (CAMEL_IMAPX_SEARCH (search));
-	if (!imapx_store || search->current || !search->summary) {
-		g_clear_object (&imapx_store);
+	server = camel_imapx_search_ref_server (CAMEL_IMAPX_SEARCH (search));
+	if (!server || search->current || !search->summary) {
+		g_clear_object (&server);
 
 		/* Chain up to parent's method. */
 		return CAMEL_FOLDER_SEARCH_CLASS (camel_imapx_search_parent_class)->
@@ -277,7 +237,7 @@ imapx_search_match_all (CamelSExp *sexp,
 	imapx_search->priv->local_data_search = prev_local_data_search;
 
 	if (local_data_search >= 0) {
-		g_clear_object (&imapx_store);
+		g_clear_object (&server);
 
 		/* Chain up to parent's method. */
 		return CAMEL_FOLDER_SEARCH_CLASS (camel_imapx_search_parent_class)->
@@ -288,7 +248,7 @@ imapx_search_match_all (CamelSExp *sexp,
 	 * but here is expected GPtrArray of matched UIDs */
 	result = camel_sexp_term_eval (sexp, argv[0]);
 
-	g_object_unref (imapx_store);
+	g_object_unref (server);
 
 	g_return_val_if_fail (result != NULL, result);
 	g_return_val_if_fail (result->type == CAMEL_SEXP_RES_ARRAY_PTR, result);
@@ -303,7 +263,7 @@ imapx_search_body_contains (CamelSExp *sexp,
                             CamelFolderSearch *search)
 {
 	CamelIMAPXSearch *imapx_search = CAMEL_IMAPX_SEARCH (search);
-	CamelIMAPXStore *imapx_store;
+	CamelIMAPXServer *server;
 	CamelSExpResult *result;
 	GString *criteria;
 	gint ii, jj;
@@ -322,10 +282,10 @@ imapx_search_body_contains (CamelSExp *sexp,
 	if (argc == 0 || search->summary->len == 0)
 		return imapx_search_result_match_none (sexp, search);
 
-	imapx_store = camel_imapx_search_ref_store (CAMEL_IMAPX_SEARCH (search));
+	server = camel_imapx_search_ref_server (CAMEL_IMAPX_SEARCH (search));
 
-	/* This will be NULL if we're offline. Search from cache. */
-	if (imapx_store == NULL) {
+	/* This will be NULL if we're offline.  Search from cache. */
+	if (server == NULL) {
 		/* Chain up to parent's method. */
 		return CAMEL_FOLDER_SEARCH_CLASS (camel_imapx_search_parent_class)->
 			body_contains (sexp, argc, argv, search);
@@ -373,10 +333,10 @@ imapx_search_body_contains (CamelSExp *sexp,
 		}
 	}
 
-	result = imapx_search_process_criteria (sexp, search, imapx_store, criteria, G_STRFUNC);
+	result = imapx_search_process_criteria (sexp, search, server, criteria, G_STRFUNC);
 
 	g_string_free (criteria, TRUE);
-	g_object_unref (imapx_store);
+	g_object_unref (server);
 
 	return result;
 }
@@ -397,7 +357,7 @@ imapx_search_header_contains (CamelSExp *sexp,
                               CamelFolderSearch *search)
 {
 	CamelIMAPXSearch *imapx_search = CAMEL_IMAPX_SEARCH (search);
-	CamelIMAPXStore *imapx_store;
+	CamelIMAPXServer *server;
 	CamelSExpResult *result;
 	const gchar *headername, *command = NULL;
 	GString *criteria;
@@ -426,10 +386,10 @@ imapx_search_header_contains (CamelSExp *sexp,
 		return imapx_search_result_match_none (sexp, search);
 	}
 
-	imapx_store = camel_imapx_search_ref_store (CAMEL_IMAPX_SEARCH (search));
+	server = camel_imapx_search_ref_server (CAMEL_IMAPX_SEARCH (search));
 
-	/* This will be NULL if we're offline. Search from cache. */
-	if (imapx_store == NULL) {
+	/* This will be NULL if we're offline.  Search from cache. */
+	if (server == NULL) {
 		/* Chain up to parent's method. */
 		return CAMEL_FOLDER_SEARCH_CLASS (camel_imapx_search_parent_class)->
 			header_contains (sexp, argc, argv, search);
@@ -493,10 +453,10 @@ imapx_search_header_contains (CamelSExp *sexp,
 		}
 	}
 
-	result = imapx_search_process_criteria (sexp, search, imapx_store, criteria, G_STRFUNC);
+	result = imapx_search_process_criteria (sexp, search, server, criteria, G_STRFUNC);
 
 	g_string_free (criteria, TRUE);
-	g_object_unref (imapx_store);
+	g_object_unref (server);
 
 	return result;
 }
@@ -508,7 +468,7 @@ imapx_search_header_exists (CamelSExp *sexp,
                             CamelFolderSearch *search)
 {
 	CamelIMAPXSearch *imapx_search = CAMEL_IMAPX_SEARCH (search);
-	CamelIMAPXStore *imapx_store;
+	CamelIMAPXServer *server;
 	CamelSExpResult *result;
 	GString *criteria;
 	gint ii;
@@ -543,10 +503,10 @@ imapx_search_header_exists (CamelSExp *sexp,
 		return imapx_search_result_match_none (sexp, search);
 	}
 
-	imapx_store = camel_imapx_search_ref_store (CAMEL_IMAPX_SEARCH (search));
+	server = camel_imapx_search_ref_server (CAMEL_IMAPX_SEARCH (search));
 
-	/* This will be NULL if we're offline. Search from cache. */
-	if (imapx_store == NULL) {
+	/* This will be NULL if we're offline.  Search from cache. */
+	if (server == NULL) {
 		/* Chain up to parent's method. */
 		return CAMEL_FOLDER_SEARCH_CLASS (camel_imapx_search_parent_class)->
 			header_exists (sexp, argc, argv, search);
@@ -578,10 +538,10 @@ imapx_search_header_exists (CamelSExp *sexp,
 		g_string_append_printf (criteria, "HEADER \"%s\" \"\"", headername);
 	}
 
-	result = imapx_search_process_criteria (sexp, search, imapx_store, criteria, G_STRFUNC);
+	result = imapx_search_process_criteria (sexp, search, server, criteria, G_STRFUNC);
 
 	g_string_free (criteria, TRUE);
-	g_object_unref (imapx_store);
+	g_object_unref (server);
 
 	return result;
 }
@@ -598,7 +558,6 @@ camel_imapx_search_class_init (CamelIMAPXSearchClass *class)
 	object_class->set_property = imapx_search_set_property;
 	object_class->get_property = imapx_search_get_property;
 	object_class->dispose = imapx_search_dispose;
-	object_class->finalize = imapx_search_finalize;
 
 	search_class = CAMEL_FOLDER_SEARCH_CLASS (class);
 	search_class->match_all = imapx_search_match_all;
@@ -608,12 +567,12 @@ camel_imapx_search_class_init (CamelIMAPXSearchClass *class)
 
 	g_object_class_install_property (
 		object_class,
-		PROP_STORE,
+		PROP_SERVER,
 		g_param_spec_object (
-			"store",
-			"IMAPX Store",
-			"IMAPX Store for server-side searches",
-			CAMEL_TYPE_IMAPX_STORE,
+			"server",
+			"Server",
+			"Server proxy for server-side searches",
+			CAMEL_TYPE_IMAPX_SERVER,
 			G_PARAM_READWRITE |
 			G_PARAM_STATIC_STRINGS));
 }
@@ -623,111 +582,71 @@ camel_imapx_search_init (CamelIMAPXSearch *search)
 {
 	search->priv = CAMEL_IMAPX_SEARCH_GET_PRIVATE (search);
 	search->priv->local_data_search = NULL;
-
-	g_weak_ref_init (&search->priv->imapx_store, NULL);
 }
 
 /**
  * camel_imapx_search_new:
- * imapx_store: a #CamelIMAPXStore to which the search belongs
  *
  * Returns a new #CamelIMAPXSearch instance.
  *
+ * The #CamelIMAPXSearch must be given a #CamelIMAPXSearch:server before
+ * it can issue server-side search requests.  Otherwise it will fallback
+ * to the default #CamelFolderSearch behavior.
+ *
  * Returns: a new #CamelIMAPXSearch
  *
  * Since: 3.8
  **/
 CamelFolderSearch *
-camel_imapx_search_new (CamelIMAPXStore *imapx_store)
+camel_imapx_search_new (void)
 {
-	g_return_val_if_fail (CAMEL_IS_IMAPX_STORE (imapx_store), NULL);
-
-	return g_object_new (
-		CAMEL_TYPE_IMAPX_SEARCH,
-		"store", imapx_store,
-		NULL);
+	return g_object_new (CAMEL_TYPE_IMAPX_SEARCH, NULL);
 }
 
 /**
- * camel_imapx_search_ref_store:
+ * camel_imapx_search_ref_server:
  * @search: a #CamelIMAPXSearch
  *
- * Returns a #CamelIMAPXStore to use for server-side searches,
- * or %NULL when the store is offline.
+ * Returns a #CamelIMAPXServer to use for server-side searches,
+ * or %NULL when the corresponding #CamelIMAPXStore is offline.
  *
- * The returned #CamelIMAPXStore is referenced for thread-safety and
+ * The returned #CamelIMAPXSearch is referenced for thread-safety and
  * must be unreferenced with g_object_unref() when finished with it.
  *
- * Returns: a #CamelIMAPXStore, or %NULL
+ * Returns: a #CamelIMAPXServer, or %NULL
  *
  * Since: 3.8
  **/
-CamelIMAPXStore *
-camel_imapx_search_ref_store (CamelIMAPXSearch *search)
+CamelIMAPXServer *
+camel_imapx_search_ref_server (CamelIMAPXSearch *search)
 {
-	CamelIMAPXStore *imapx_store;
-
 	g_return_val_if_fail (CAMEL_IS_IMAPX_SEARCH (search), NULL);
 
-	imapx_store = g_weak_ref_get (&search->priv->imapx_store);
-
-	if (imapx_store && !camel_offline_store_get_online (CAMEL_OFFLINE_STORE (imapx_store)))
-		g_clear_object (&imapx_store);
-
-	return imapx_store;
+	return g_weak_ref_get (&search->priv->server);
 }
 
 /**
- * camel_imapx_search_set_store:
+ * camel_imapx_search_set_server:
  * @search: a #CamelIMAPXSearch
- * @imapx_server: a #CamelIMAPXStore, or %NULL
+ * @server: a #CamelIMAPXServer, or %NULL
  *
- * Sets a #CamelIMAPXStore to use for server-side searches. Generally
+ * Sets a #CamelIMAPXServer to use for server-side searches.  Generally
  * this is set for the duration of a single search when online, and then
  * reset to %NULL.
  *
  * Since: 3.8
  **/
 void
-camel_imapx_search_set_store (CamelIMAPXSearch *search,
-			      CamelIMAPXStore *imapx_store)
+camel_imapx_search_set_server (CamelIMAPXSearch *search,
+                               CamelIMAPXServer *server)
 {
 	g_return_if_fail (CAMEL_IS_IMAPX_SEARCH (search));
 
-	if (imapx_store != NULL)
-		g_return_if_fail (CAMEL_IS_IMAPX_STORE (imapx_store));
+	if (server != NULL)
+		g_return_if_fail (CAMEL_IS_IMAPX_SERVER (server));
 
-	g_weak_ref_set (&search->priv->imapx_store, imapx_store);
+	g_weak_ref_set (&search->priv->server, server);
 
-	g_object_notify (G_OBJECT (search), "store");
+	g_object_notify (G_OBJECT (search), "server");
 }
 
-/**
- * camel_imapx_search_set_cancellable_and_error:
- * @search: a #CamelIMAPXSearch
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Sets @cancellable and @error to use for server-side searches. This way
- * the search can return accurate errors and be eventually cancelled by
- * a user.
- *
- * Note: The caller is responsible to keep alive both @cancellable and @error
- * for the whole run of the search and reset them both to NULL after
- * the search is finished.
- *
- * Since: 3.14
- **/
-void
-camel_imapx_search_set_cancellable_and_error (CamelIMAPXSearch *search,
-					      GCancellable *cancellable,
-					      GError **error)
-{
-	g_return_if_fail (CAMEL_IS_IMAPX_SEARCH (search));
-
-	if (cancellable)
-		g_return_if_fail (G_IS_CANCELLABLE (cancellable));
-
-	search->priv->cancellable = cancellable;
-	search->priv->error = error;
-}
