@@ -1,17 +1,17 @@
 /*
  * camel-imapx-store-summary.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -109,8 +109,11 @@ imapx_store_summary_summary_header_load (CamelStoreSummary *summary,
 		return -1;
 
 	if (version < CAMEL_IMAPX_STORE_SUMMARY_VERSION) {
-		g_warning ("IMAPx: Unable to load store summary: Expected version (%d), got (%d)",
-			CAMEL_IMAPX_STORE_SUMMARY_VERSION, version);
+		g_warning (
+			"Unable to load store summary: "
+			"Expected version (%d), got (%d)",
+			CAMEL_IMAPX_STORE_SUMMARY_VERSION,
+			version);
 		return -1;
 	}
 
