@@ -1,21 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* camel-imap-store.c : class for a imap store */
-/*
- * Authors: Michael Zucchi <notzed@ximian.com>
+/* camel-imap-store.c : class for a imap store
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software; you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Michael Zucchi <notzed@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,7 +39,6 @@
 
 #include "camel-imapx-conn-manager.h"
 #include "camel-imapx-folder.h"
-#include "camel-imapx-job.h"
 #include "camel-imapx-server.h"
 #include "camel-imapx-settings.h"
 #include "camel-imapx-store.h"
@@ -180,18 +179,19 @@ imapx_store_settings_notify_cb (CamelSettings *settings,
                                 GParamSpec *pspec,
                                 CamelStore *store)
 {
-	gboolean folder_info_stale = g_str_equal (pspec->name, "use-subscriptions");
-
-	if (g_str_equal (pspec->name, "use-real-junk-path") ||
-	    g_str_equal (pspec->name, "use-real-trash-path") ||
-	    g_str_equal (pspec->name, "real-junk-path") ||
-	    g_str_equal (pspec->name, "real-trash-path")) {
+	if (g_str_equal (pspec->name, "use-real-junk-path")) {
 		imapx_store_update_store_flags (store);
-		folder_info_stale = TRUE;
+		camel_store_folder_info_stale (store);
 	}
 
-	if (folder_info_stale)
+	if (g_str_equal (pspec->name, "use-real-trash-path")) {
+		imapx_store_update_store_flags (store);
 		camel_store_folder_info_stale (store);
+	}
+
+	if (g_str_equal (pspec->name, "use-subscriptions")) {
+		camel_store_folder_info_stale (store);
+	}
 }
 
 static CamelFolderInfo *
@@ -327,7 +327,7 @@ imapx_store_rename_storage_path (CamelIMAPXStore *imapx_store,
 	new_storage_path =
 		imapx_path_to_physical (root_storage_path, new_mailbox);
 
-	if (g_rename (old_storage_path, new_storage_path) == -1 && errno != ENOENT) {
+	if (g_rename (old_storage_path, new_storage_path) == -1) {
 		g_warning (
 			"Could not rename message cache "
 			"'%s' to '%s: %s: cache reset",
@@ -370,8 +370,7 @@ imapx_store_mailbox_attributes_to_flags (CamelIMAPXMailbox *mailbox)
 	const gchar *attribute;
 
 	attribute = CAMEL_IMAPX_LIST_ATTR_NOSELECT;
-	if (camel_imapx_mailbox_has_attribute (mailbox, attribute) &&
-	    !camel_imapx_mailbox_is_inbox (camel_imapx_mailbox_get_name (mailbox)))
+	if (camel_imapx_mailbox_has_attribute (mailbox, attribute))
 		store_info_flags |= CAMEL_STORE_INFO_FOLDER_NOSELECT;
 
 	attribute = CAMEL_IMAPX_LIST_ATTR_NOINFERIORS;
@@ -413,7 +412,7 @@ imapx_store_process_mailbox_attributes (CamelIMAPXStore *store,
 	gboolean emit_folder_created_subscribed = FALSE;
 	gboolean emit_folder_unsubscribed_deleted = FALSE;
 	gboolean emit_folder_renamed = FALSE;
-	gchar *folder_path;
+	const gchar *folder_path;
 	const gchar *mailbox_name;
 	gchar separator;
 
@@ -441,8 +440,6 @@ imapx_store_process_mailbox_attributes (CamelIMAPXStore *store,
 
 	/* Summary retains ownership of the returned CamelStoreInfo. */
 	si = camel_imapx_store_summary_mailbox (store->summary, mailbox_name);
-	if (!si && oldname)
-		si = camel_imapx_store_summary_mailbox (store->summary, oldname);
 	if (si != NULL) {
 		mailbox_was_in_summary = TRUE;
 		if (si->info.flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED)
@@ -464,7 +461,8 @@ imapx_store_process_mailbox_attributes (CamelIMAPXStore *store,
 		camel_store_summary_touch (store->summary);
 	}
 
-	folder_path = camel_imapx_mailbox_to_folder_path (mailbox_name, separator);
+	folder_path = camel_store_info_path (
+		store->summary, (CamelStoreInfo *) si);
 	fi = imapx_store_build_folder_info (store, folder_path, flags);
 
 	/* Figure out which signals to emit, if any. */
@@ -500,14 +498,14 @@ imapx_store_process_mailbox_attributes (CamelIMAPXStore *store,
 		emit_folder_created_subscribed = FALSE;
 		emit_folder_unsubscribed_deleted = FALSE;
 		emit_folder_renamed = FALSE;
-	} else {
-		/* At most one signal emission flag should be set. */
-		g_warn_if_fail (
-			(emit_folder_created_subscribed ? 1 : 0) +
-			(emit_folder_unsubscribed_deleted ? 1 : 0) +
-			(emit_folder_renamed ? 1 : 0) <= 1);
 	}
 
+	/* At most one signal emission flag should be set. */
+	g_warn_if_fail (
+		(emit_folder_created_subscribed ? 1 : 0) +
+		(emit_folder_unsubscribed_deleted ? 1 : 0) +
+		(emit_folder_renamed ? 1 : 0) <= 1);
+
 	if (emit_folder_created_subscribed) {
 		camel_store_folder_created (
 			CAMEL_STORE (store), fi);
@@ -536,14 +534,14 @@ imapx_store_process_mailbox_attributes (CamelIMAPXStore *store,
 		imapx_store_rename_storage_path (
 			store, old_folder_path, new_folder_path);
 
-		camel_store_folder_renamed (CAMEL_STORE (store), old_folder_path, fi);
+		camel_store_folder_renamed (
+			CAMEL_STORE (store), old_folder_path, fi);
 
 		g_free (old_folder_path);
 		g_free (new_folder_path);
 	}
 
 	camel_folder_info_free (fi);
-	g_free (folder_path);
 }
 
 static void
@@ -796,7 +794,7 @@ imapx_disconnect_sync (CamelService *service,
 	priv = CAMEL_IMAPX_STORE_GET_PRIVATE (service);
 
 	if (priv->con_man != NULL)
-		camel_imapx_conn_manager_close_connections (priv->con_man, NULL);
+		camel_imapx_conn_manager_close_connections (priv->con_man);
 
 	g_mutex_lock (&priv->server_lock);
 
@@ -848,15 +846,11 @@ imapx_query_auth_types_sync (CamelService *service,
                              GError **error)
 {
 	CamelServiceAuthType *authtype;
-	CamelIMAPXStore *imapx_store;
 	GList *sasl_types = NULL;
 	GList *t, *next;
 	CamelIMAPXServer *server;
 
-	imapx_store = CAMEL_IMAPX_STORE (service);
-
-	server = camel_imapx_server_new (imapx_store);
-	server->tagprefix = 'Z';
+	server = camel_imapx_server_new (CAMEL_IMAPX_STORE (service));
 
 	if (!imapx_connect_to_server (server, cancellable, error))
 		goto exit;
@@ -1152,39 +1146,24 @@ fetch_folder_info_for_pattern (CamelIMAPXServer *server,
 	GError *local_error = NULL;
 	gboolean success;
 
-	g_object_ref (server);
-
-	imapx_store = camel_imapx_server_ref_store (server);
-
-	success = camel_imapx_server_list (server, pattern, flags, cancellable, &local_error);
-
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&server);
-
-		server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-		if (server)
-			success = camel_imapx_server_list (server, pattern, flags, cancellable, &local_error);
-	}
-
-	g_clear_object (&server);
-
+	success = camel_imapx_server_list (
+		server, pattern, flags, cancellable, &local_error);
 	if (!success) {
-		g_clear_object (&imapx_store);
-
 		if (!g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_CANCELLED) &&
 		    camel_imapx_namespace_get_category (namespace) != CAMEL_IMAPX_NAMESPACE_PERSONAL) {
 			/* Ignore errors for non-personal namespaces; one such error can be:
 			   "NO LIST failed: wildcards not permitted in username" */
 			g_clear_error (&local_error);
 			return TRUE;
-		} else if (local_error) {
+		} else {
 			g_propagate_error (error, local_error);
 		}
 
 		return FALSE;
 	}
 
+	imapx_store = camel_imapx_server_ref_store (server);
+
 	list = camel_imapx_store_list_mailboxes (imapx_store, namespace, pattern);
 
 	for (link = list; link != NULL; link = g_list_next (link)) {
@@ -1210,40 +1189,25 @@ fetch_folder_info_for_inbox (CamelIMAPXServer *server,
                              GCancellable *cancellable,
                              GError **error)
 {
-	CamelIMAPXStore *imapx_store;
-	GError *local_error = NULL;
 	gboolean success;
 
-	g_object_ref (server);
-	imapx_store = camel_imapx_server_ref_store (server);
-
-	success = camel_imapx_server_list (server, "INBOX", flags, cancellable, &local_error);
-
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&server);
-
-		server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-		if (server)
-			success = camel_imapx_server_list (server, "INBOX", flags, cancellable, &local_error);
-	}
-
-	g_clear_object (&server);
-
-	if (local_error)
-		g_propagate_error (error, local_error);
+	success = camel_imapx_server_list (
+		server, "INBOX", flags, cancellable, error);
 
 	if (success) {
+		CamelIMAPXStore *imapx_store;
 		CamelIMAPXMailbox *mailbox;
 
+		imapx_store = camel_imapx_server_ref_store (server);
+
 		mailbox = camel_imapx_store_ref_mailbox (imapx_store, "INBOX");
 		g_return_val_if_fail (mailbox != NULL, FALSE);
 
 		collect_folder_info_for_list (
 			imapx_store, mailbox, folder_info_results);
-	}
 
-	g_object_unref (imapx_store);
+		g_object_unref (imapx_store);
+	}
 
 	return success;
 }
@@ -1511,21 +1475,8 @@ discover_inbox (CamelIMAPXStore *imapx_store,
 
 	attribute = CAMEL_IMAPX_LIST_ATTR_SUBSCRIBED;
 	if (!camel_imapx_mailbox_has_attribute (mailbox, attribute)) {
-		GError *local_error = NULL;
-		gboolean success;
-
-		success = camel_imapx_server_subscribe_mailbox (imapx_server, mailbox, cancellable, &local_error);
-
-		while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-			g_clear_error (&local_error);
-			g_clear_object (&imapx_server);
-
-			imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-			if (imapx_server)
-				success = camel_imapx_server_subscribe_mailbox (imapx_server, mailbox, cancellable, &local_error);
-		}
-
-		g_clear_error (&local_error);
+		camel_imapx_server_subscribe_mailbox (
+			imapx_server, mailbox, cancellable, NULL);
 	}
 
 exit:
@@ -1857,7 +1808,6 @@ imapx_store_create_folder_sync (CamelStore *store,
 	gchar *mailbox_name = NULL;
 	gchar separator;
 	gboolean success;
-	GError *local_error = NULL;
 
 	imapx_store = CAMEL_IMAPX_STORE (store);
 	imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, error);
@@ -1934,19 +1884,8 @@ check_separator:
 	/* This also LISTs the mailbox after creating it, which
 	 * triggers the CamelIMAPXStore::mailbox-created signal
 	 * and all the local processing that goes along with it. */
-	success = camel_imapx_server_create_mailbox (imapx_server, mailbox_name, cancellable, &local_error);
-
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-		if (imapx_server)
-			success = camel_imapx_server_create_mailbox (imapx_server, mailbox_name, cancellable, &local_error);
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
+	success = camel_imapx_server_create_mailbox (
+		imapx_server, mailbox_name, cancellable, error);
 
 	if (success) {
 		fi = imapx_store_build_folder_info (
@@ -1973,7 +1912,6 @@ imapx_store_delete_folder_sync (CamelStore *store,
 	CamelIMAPXServer *imapx_server;
 	CamelIMAPXMailbox *mailbox = NULL;
 	gboolean success = FALSE;
-	GError *local_error = NULL;
 
 	folder = camel_store_get_folder_sync (
 		store, folder_name, 0, cancellable, error);
@@ -1992,19 +1930,8 @@ imapx_store_delete_folder_sync (CamelStore *store,
 	if (mailbox == NULL)
 		goto exit;
 
-	success = camel_imapx_server_delete_mailbox (imapx_server, mailbox, cancellable, &local_error);
-
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-		if (imapx_server)
-			success = camel_imapx_server_delete_mailbox (imapx_server, mailbox, cancellable, &local_error);
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
+	success = camel_imapx_server_delete_mailbox (
+		imapx_server, mailbox, cancellable, error);
 
 	if (success)
 		imapx_delete_folder_from_cache (imapx_store, folder_name);
@@ -2035,7 +1962,6 @@ imapx_store_rename_folder_sync (CamelStore *store,
 	gchar separator;
 	gboolean use_subscriptions;
 	gboolean success = FALSE;
-	GError *local_error = NULL;
 
 	service = CAMEL_SERVICE (store);
 	imapx_store = CAMEL_IMAPX_STORE (store);
@@ -2047,10 +1973,6 @@ imapx_store_rename_folder_sync (CamelStore *store,
 
 	g_object_unref (settings);
 
-	/* This suppresses CamelStore signal emissions
-	 * in imapx_store_process_mailbox_attributes(). */
-	g_atomic_int_inc (&imapx_store->priv->syncing_folders);
-
 	imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, error);
 
 	if (imapx_server == NULL)
@@ -2074,53 +1996,16 @@ imapx_store_rename_folder_sync (CamelStore *store,
 	separator = camel_imapx_mailbox_get_separator (mailbox);
 	new_mailbox_name = camel_imapx_folder_path_to_mailbox (new, separator);
 
-	if (use_subscriptions) {
-		success = camel_imapx_server_unsubscribe_mailbox (imapx_server, mailbox, cancellable, &local_error);
+	if (use_subscriptions)
+		camel_imapx_server_unsubscribe_mailbox (
+			imapx_server, mailbox, cancellable, NULL);
 
-		while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-			g_clear_error (&local_error);
-			g_clear_object (&imapx_server);
-
-			imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-			if (imapx_server)
-				success = camel_imapx_server_unsubscribe_mailbox (imapx_server, mailbox, cancellable, &local_error);
-		}
-
-		g_clear_error (&local_error);
-	}
-
-	success = camel_imapx_server_rename_mailbox (imapx_server, mailbox, new_mailbox_name, cancellable, &local_error);
-
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-		if (imapx_server)
-			success = camel_imapx_server_rename_mailbox (imapx_server, mailbox, new_mailbox_name, cancellable, &local_error);
-	}
+	success = camel_imapx_server_rename_mailbox (
+		imapx_server, mailbox, new_mailbox_name, cancellable, error);
 
 	if (!success) {
-		if (local_error)
-			g_propagate_error (error, local_error);
-		local_error = NULL;
-
-		if (use_subscriptions) {
-			gboolean success_2;
-
-			success_2 = camel_imapx_server_subscribe_mailbox (imapx_server, mailbox, cancellable, &local_error);
-
-			while (!success_2 && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-				g_clear_error (&local_error);
-				g_clear_object (&imapx_server);
-
-				imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-				if (imapx_server)
-					success_2 = camel_imapx_server_subscribe_mailbox (imapx_server, mailbox, cancellable, &local_error);
-			}
-
-			g_clear_error (&local_error);
-		}
+		camel_imapx_server_subscribe_mailbox (
+			imapx_server, mailbox, cancellable, NULL);
 		goto exit;
 	}
 
@@ -2134,21 +2019,9 @@ imapx_store_rename_folder_sync (CamelStore *store,
 	camel_imapx_folder_set_mailbox (
 		CAMEL_IMAPX_FOLDER (folder), cloned_mailbox);
 
-	if (use_subscriptions) {
-		success = camel_imapx_server_subscribe_mailbox (imapx_server, cloned_mailbox, cancellable, &local_error);
-
-		while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-			g_clear_error (&local_error);
-			g_clear_object (&imapx_server);
-
-			imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-			if (imapx_server)
-				success = camel_imapx_server_subscribe_mailbox (imapx_server, cloned_mailbox, cancellable, &local_error);
-		}
-
-		if (local_error)
-			g_propagate_error (error, local_error);
-	}
+	if (use_subscriptions)
+		success = camel_imapx_server_subscribe_mailbox (
+			imapx_server, cloned_mailbox, cancellable, error);
 
 	g_clear_object (&cloned_mailbox);
 
@@ -2158,10 +2031,6 @@ exit:
 	g_clear_object (&mailbox);
 	g_clear_object (&imapx_server);
 
-	/* This enabled CamelStore signal emissions
-	 * in imapx_store_process_mailbox_attributes() again. */
-	g_atomic_int_dec_and_test (&imapx_store->priv->syncing_folders);
-
 	return success;
 }
 
@@ -2188,7 +2057,7 @@ imapx_migrate_to_user_cache_dir (CamelService *service)
 		g_mkdir_with_parents (parent_dir, S_IRWXU);
 		g_free (parent_dir);
 
-		if (g_rename (user_data_dir, user_cache_dir) == -1 && errno != ENOENT)
+		if (g_rename (user_data_dir, user_cache_dir) == -1)
 			g_debug ("%s: Failed to migrate '%s' to '%s': %s", G_STRFUNC, user_data_dir, user_cache_dir, g_strerror (errno));
 	}
 }
@@ -2223,10 +2092,7 @@ imapx_store_initable_init (GInitable *initable,
 
 	summary = g_build_filename (user_cache_dir, ".ev-store-summary", NULL);
 	camel_store_summary_set_filename (imapx_store->summary, summary);
-	if (camel_store_summary_load (imapx_store->summary) == -1) {
-		camel_store_summary_touch (imapx_store->summary);
-		camel_store_summary_save (imapx_store->summary);
-	}
+	camel_store_summary_load (imapx_store->summary);
 
 	g_free (summary);
 
@@ -2350,7 +2216,6 @@ imapx_store_subscribe_folder_sync (CamelSubscribable *subscribable,
 	CamelIMAPXServer *imapx_server;
 	CamelIMAPXMailbox *mailbox = NULL;
 	gboolean success = FALSE;
-	GError *local_error = NULL;
 
 	imapx_store = CAMEL_IMAPX_STORE (subscribable);
 	imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, error);
@@ -2371,19 +2236,8 @@ imapx_store_subscribe_folder_sync (CamelSubscribable *subscribable,
 	if (mailbox == NULL)
 		goto exit;
 
-	success = camel_imapx_server_subscribe_mailbox (imapx_server, mailbox, cancellable, &local_error);
-
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-		if (imapx_server)
-			success = camel_imapx_server_subscribe_mailbox (imapx_server, mailbox, cancellable, &local_error);
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
+	success = camel_imapx_server_subscribe_mailbox (
+		imapx_server, mailbox, cancellable, error);
 
 	if (success) {
 		CamelFolderInfo *fi;
@@ -2415,7 +2269,6 @@ imapx_store_unsubscribe_folder_sync (CamelSubscribable *subscribable,
 	CamelIMAPXServer *imapx_server;
 	CamelIMAPXMailbox *mailbox = NULL;
 	gboolean success = FALSE;
-	GError *local_error = NULL;
 
 	imapx_store = CAMEL_IMAPX_STORE (subscribable);
 	imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, error);
@@ -2436,19 +2289,8 @@ imapx_store_unsubscribe_folder_sync (CamelSubscribable *subscribable,
 	if (mailbox == NULL)
 		goto exit;
 
-	success = camel_imapx_server_unsubscribe_mailbox (imapx_server, mailbox, cancellable, &local_error);
-
-	while (!success && g_error_matches (local_error, CAMEL_IMAPX_SERVER_ERROR, CAMEL_IMAPX_SERVER_ERROR_TRY_RECONNECT)) {
-		g_clear_error (&local_error);
-		g_clear_object (&imapx_server);
-
-		imapx_server = camel_imapx_store_ref_server (imapx_store, NULL, FALSE, cancellable, &local_error);
-		if (imapx_server)
-			success = camel_imapx_server_unsubscribe_mailbox (imapx_server, mailbox, cancellable, &local_error);
-	}
-
-	if (local_error)
-		g_propagate_error (error, local_error);
+	success = camel_imapx_server_unsubscribe_mailbox (
+		imapx_server, mailbox, cancellable, error);
 
 	if (success) {
 		CamelFolderInfo *fi;
@@ -2678,35 +2520,20 @@ camel_imapx_store_ref_server (CamelIMAPXStore *store,
                               GError **error)
 {
 	CamelIMAPXServer *server = NULL;
-	CamelSession *session;
-	GError *local_error = NULL;
 
 	g_return_val_if_fail (CAMEL_IS_IMAPX_STORE (store), NULL);
 
-	session = camel_service_ref_session (CAMEL_SERVICE (store));
+ 	server = camel_imapx_conn_manager_get_connection (
+		store->priv->con_man, folder_name, for_expensive_job, cancellable, error);
 
-	if (camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store)) &&
-	    camel_session_get_online (session))
-		server = camel_imapx_conn_manager_get_connection (
-			store->priv->con_man, folder_name, for_expensive_job, cancellable, &local_error);
-
-	g_clear_object (&session);
-
-	if (!server && (!local_error || local_error->domain == G_RESOLVER_ERROR)) {
-		if (!local_error) {
-			g_set_error (
-				&local_error, CAMEL_SERVICE_ERROR,
-				CAMEL_SERVICE_ERROR_UNAVAILABLE,
-				_("You must be working online to complete this operation"));
-		} else {
-			local_error->domain = CAMEL_SERVICE_ERROR;
-			local_error->code = CAMEL_SERVICE_ERROR_UNAVAILABLE;
-		}
+	if (!server) {
+		g_set_error (
+			error, CAMEL_SERVICE_ERROR,
+			CAMEL_SERVICE_ERROR_UNAVAILABLE,
+			_("You must be working online "
+			"to complete this operation"));
 	}
 
-	if (local_error)
-		g_propagate_error (error, local_error);
-
 	return server;
 }
 
@@ -2775,7 +2602,7 @@ camel_imapx_store_folder_op_done (CamelIMAPXStore *store,
  *
  * Returns: a #CamelIMAPXNamespaceResponse
  *
- * Since: 3.12.2
+ * Since: 3.14
  **/
 CamelIMAPXNamespaceResponse *
 camel_imapx_store_ref_namespaces (CamelIMAPXStore *imapx_store)
@@ -3051,7 +2878,7 @@ imapx_store_rename_mailbox_unlocked (CamelIMAPXStore *imapx_store,
  *
  * Returns: a #CamelIMAPXMailbox, or %NULL
  *
- * Since: 3.12.2
+ * Since: 3.14
  **/
 CamelIMAPXMailbox *
 camel_imapx_store_ref_mailbox (CamelIMAPXStore *imapx_store,
@@ -3094,7 +2921,7 @@ camel_imapx_store_ref_mailbox (CamelIMAPXStore *imapx_store,
  *
  * Returns: a list of #CamelIMAPXMailbox instances
  *
- * Since: 3.12.2
+ * Since: 3.14
  **/
 GList *
 camel_imapx_store_list_mailboxes (CamelIMAPXStore *imapx_store,
@@ -3301,41 +3128,3 @@ camel_imapx_store_set_quota_info (CamelIMAPXStore *store,
 	g_mutex_unlock (&store->priv->quota_info_lock);
 }
 
-/* Tries to find matching job among all active connections.
-   See camel_imapx_server_ref_job() for more information on parameters
-   and return values.
-*/
-CamelIMAPXJob *
-camel_imapx_store_ref_job (CamelIMAPXStore *imapx_store,
-			   CamelIMAPXMailbox *mailbox,
-			   guint32 job_type,
-			   const gchar *uid)
-{
-	GList *servers, *siter;
-	CamelIMAPXJob *job = NULL;
-
-	g_return_val_if_fail (CAMEL_IS_IMAPX_STORE (imapx_store), NULL);
-
-	servers = camel_imapx_conn_manager_get_connections (imapx_store->priv->con_man);
-
-	for (siter = servers; siter; siter = g_list_next (siter)) {
-		CamelIMAPXServer *imapx_server = siter->data;
-
-		job = camel_imapx_server_ref_job (imapx_server, mailbox, job_type, uid);
-		if (job)
-			break;
-	}
-
-	g_list_free_full (servers, g_object_unref);
-
-	return job;
-}
-
-/* for debugging purposes only */
-void
-camel_imapx_store_dump_queue_status (CamelIMAPXStore *imapx_store)
-{
-	g_return_if_fail (CAMEL_IS_IMAPX_STORE (imapx_store));
-
-	camel_imapx_conn_manager_dump_queue_status (imapx_store->priv->con_man);
-}
