@@ -1,22 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* camel-imap-store.h : class for an imap store */
-
-/*
- * Authors: Michael Zucchi <notzed@ximian.com>
+/* camel-imap-store.h : class for an imap store
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software; you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Michael Zucchi <notzed@ximian.com>
  */
 
 #ifndef CAMEL_IMAPX_STORE_H
@@ -47,9 +46,6 @@
 
 G_BEGIN_DECLS
 
-/* Avoid a circular reference. */
-struct _CamelIMAPXJob;
-
 typedef struct _CamelIMAPXStore CamelIMAPXStore;
 typedef struct _CamelIMAPXStoreClass CamelIMAPXStoreClass;
 typedef struct _CamelIMAPXStorePrivate CamelIMAPXStorePrivate;
@@ -127,15 +123,7 @@ void		camel_imapx_store_set_quota_info
 						(CamelIMAPXStore *store,
 						 const gchar *quota_root_name,
 						 const CamelFolderQuotaInfo *info);
-struct _CamelIMAPXJob *
-		camel_imapx_store_ref_job	(CamelIMAPXStore *imapx_store,
-						 CamelIMAPXMailbox *mailbox,
-						 guint32 job_type,
-						 const gchar *uid);
 
-/* for debugging purposes only */
-void		camel_imapx_store_dump_queue_status
-						(CamelIMAPXStore *imapx_store);
 G_END_DECLS
 
 #endif /* CAMEL_IMAPX_STORE_H */
