@@ -1,17 +1,17 @@
 /*
  * e-authentication-session.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -134,7 +134,7 @@ authentication_session_msg (EAuthenticationSession *session,
 	g_string_append_vprintf (buffer, format, args);
 	va_end (args);
 
-	e_source_registry_debug_print ("%s\n", buffer->str);
+	g_print ("%s\n", buffer->str);
 
 	g_string_free (buffer, TRUE);
 }
@@ -322,7 +322,8 @@ authentication_session_constructed (GObject *object)
 	session = E_AUTHENTICATION_SESSION (object);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_authentication_session_parent_class)->constructed (object);
+	G_OBJECT_CLASS (e_authentication_session_parent_class)->
+		constructed (object);
 
 	/* If the server knows about the data source UID we've been
 	 * given, then we can auto-configure our own prompt strings. */
@@ -389,7 +390,7 @@ authentication_session_execute_sync (EAuthenticationSession *session,
 	ESourceRegistryServer *server;
 	ESource *source = NULL;
 	GcrPrompt *prompt;
-	GString *password_string = NULL;
+	GString *password_string;
 	const gchar *label;
 	const gchar *source_uid;
 	const gchar *prompt_password;
@@ -397,7 +398,6 @@ authentication_session_execute_sync (EAuthenticationSession *session,
 	gboolean success;
 	gboolean allow_auth_prompt = TRUE;
 	gboolean remember_password = TRUE;
-	gboolean first_prompt = TRUE;
 	GError *local_error = NULL;
 
 	/* XXX I moved the execute() operation into a class method thinking
@@ -504,6 +504,20 @@ authentication_session_execute_sync (EAuthenticationSession *session,
 
 	g_warn_if_fail (auth_result == E_SOURCE_AUTHENTICATION_REJECTED);
 
+	/* The stored password is bad so delete it from the keyring.
+	 * Failure here does not affect the outcome of this operation,
+	 * but leave a breadcrumb as evidence that something went wrong. */
+
+	if (source != NULL) {
+		e_source_delete_password_sync (
+			source, cancellable, &local_error);
+
+		if (local_error != NULL) {
+			g_warning ("%s: %s", G_STRFUNC, local_error->message);
+			g_clear_error (&local_error);
+		}
+	}
+
 	/* Check if we're allowed to interrupt the user for a password.
 	 * If not, we have no choice but to dismiss the authentication
 	 * request. */
@@ -514,8 +528,6 @@ authentication_session_execute_sync (EAuthenticationSession *session,
 
 	/* Configure a system prompt. */
 
- try_again:
-
 	prompt = gcr_system_prompt_open (
 		SYSTEM_PROMPT_TIMEOUT, cancellable, error);
 
@@ -543,10 +555,7 @@ authentication_session_execute_sync (EAuthenticationSession *session,
 	gcr_prompt_set_choice_label (prompt, label);
 	gcr_prompt_set_choice_chosen (prompt, remember_password);
 
-	if (!first_prompt)
-		gcr_prompt_set_warning (prompt, _("Password was incorrect"));
-	else
-		first_prompt = FALSE;
+try_again:
 
 	/* Prompt the user for a password. */
 
@@ -566,29 +575,6 @@ authentication_session_execute_sync (EAuthenticationSession *session,
 		goto close_prompt;
 	}
 
-	if (password_string)
-		g_string_free (password_string, TRUE);
-	password_string = g_string_new (prompt_password);
-	prompt_password = NULL;
-
-	remember_password = gcr_prompt_get_choice_chosen (prompt);
-
-	/* Failure here does not affect the outcome of this
-	 * operation, but leave a breadcrumb as evidence that
-	 * something went wrong. */
-
-	gcr_system_prompt_close (
-		GCR_SYSTEM_PROMPT (prompt),
-		cancellable, &local_error);
-
-	if (local_error != NULL) {
-		g_warning ("%s: %s", G_STRFUNC, local_error->message);
-		g_clear_error (&local_error);
-	}
-
-	g_object_unref (prompt);
-	prompt = NULL;
-
 	if (source != NULL) {
 		ESourceExtension *extension;
 		const gchar *extension_name;
@@ -598,33 +584,59 @@ authentication_session_execute_sync (EAuthenticationSession *session,
 
 		e_source_authentication_set_remember_password (
 			E_SOURCE_AUTHENTICATION (extension),
-			remember_password);
+			gcr_prompt_get_choice_chosen (prompt));
 	}
 
 	/* Attempt authentication with the provided password. */
 
+	password_string = g_string_new (prompt_password);
+
 	auth_result = e_source_authenticator_try_password_sync (
 		authenticator, password_string, cancellable, error);
 
+	g_string_free (password_string, TRUE);
+	password_string = NULL;
+
 	if (auth_result == E_SOURCE_AUTHENTICATION_ERROR) {
 		session_result = E_AUTHENTICATION_SESSION_ERROR;
-		goto exit;
+		goto close_prompt;
 	}
 
 	if (auth_result == E_SOURCE_AUTHENTICATION_ACCEPTED) {
+		gboolean permanently;
 		gchar *password_copy;
 
+		permanently = gcr_prompt_get_choice_chosen (prompt);
 		session_result = E_AUTHENTICATION_SESSION_SUCCESS;
 
+		/* Close our prompt before storing the password in
+		 * the keyring.  If the keyring is locked, it will
+		 * need to prompt the user for a keyring password,
+		 * but it can't do that if our password prompt is
+		 * still open since both prompts are system-modal.
+		 * Not sure what would happen next; probably the
+		 * store operation would either fail or deadlock. */
+
 		/* XXX Not sure if it's safe to use the prompt's
 		 *     password string after closing the prompt,
 		 *     so make a copy here just to be safe. */
-		password_copy = gcr_secure_memory_strdup (password_string->str);
+		password_copy = gcr_secure_memory_strdup (prompt_password);
 
 		/* Failure here does not affect the outcome of this
 		 * operation, but leave a breadcrumb as evidence that
 		 * something went wrong. */
 
+		gcr_system_prompt_close (
+			GCR_SYSTEM_PROMPT (prompt),
+			cancellable, &local_error);
+
+		if (local_error != NULL) {
+			g_warning ("%s: %s", G_STRFUNC, local_error->message);
+			g_clear_error (&local_error);
+		}
+
+		g_object_unref (prompt);
+
 		/* Create a phony "scratch" source if necessary. */
 		if (source == NULL) {
 			source = e_source_new_with_uid (
@@ -633,7 +645,7 @@ authentication_session_execute_sync (EAuthenticationSession *session,
 
 		if (source != NULL) {
 			e_source_store_password_sync (
-				source, password_copy, remember_password,
+				source, password_copy, permanently,
 				cancellable, &local_error);
 		}
 
@@ -649,6 +661,8 @@ authentication_session_execute_sync (EAuthenticationSession *session,
 
 	g_warn_if_fail (auth_result == E_SOURCE_AUTHENTICATION_REJECTED);
 
+	gcr_prompt_set_warning (prompt, _("Password was incorrect"));
+
 	goto try_again;
 
 close_prompt:
@@ -694,11 +708,6 @@ exit:
 
 	g_clear_object (&source);
 
-	if (password_string) {
-		g_string_free (password_string, TRUE);
-		password_string = NULL;
-	}
-
 	return session_result;
 }
 
