@@ -1,17 +1,17 @@
 /*
  * e-backend.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -126,16 +126,11 @@ backend_network_monitor_can_reach_cb (GObject *source_object,
 }
 
 static gboolean
-backend_update_online_state_timeout_cb (gpointer user_data)
+backend_update_online_state_idle_cb (gpointer user_data)
 {
 	EBackend *backend;
 	GSocketConnectable *connectable;
 	GCancellable *cancellable;
-	GSource *current_source;
-
-	current_source = g_main_current_source ();
-	if (current_source && g_source_is_destroyed (current_source))
-		return FALSE;
 
 	backend = E_BACKEND (user_data);
 	connectable = e_backend_ref_connectable (backend);
@@ -191,36 +186,29 @@ backend_update_online_state_timeout_cb (gpointer user_data)
 static void
 backend_update_online_state (EBackend *backend)
 {
-	GMainContext *main_context;
-	GSource *timeout_source;
-
 	g_mutex_lock (&backend->priv->update_online_state_lock);
 
-	/* Reference the backend before destroying any already scheduled GSource,
-	   in case the backend's last reference is held by that GSource. */
-	g_object_ref (backend);
+	if (backend->priv->update_online_state == NULL) {
+		GMainContext *main_context;
+		GSource *idle_source;
 
-	if (backend->priv->update_online_state) {
-		g_source_destroy (backend->priv->update_online_state);
-		g_source_unref (backend->priv->update_online_state);
-		backend->priv->update_online_state = NULL;
+		main_context = e_backend_ref_main_context (backend);
+
+		idle_source = g_idle_source_new ();
+		g_source_set_priority (idle_source, G_PRIORITY_LOW);
+		g_source_set_callback (
+			idle_source,
+			backend_update_online_state_idle_cb,
+			g_object_ref (backend),
+			(GDestroyNotify) g_object_unref);
+		g_source_attach (idle_source, main_context);
+		backend->priv->update_online_state =
+			g_source_ref (idle_source);
+		g_source_unref (idle_source);
+
+		g_main_context_unref (main_context);
 	}
 
-	main_context = e_backend_ref_main_context (backend);
-
-	timeout_source = g_timeout_source_new_seconds (5);
-	g_source_set_priority (timeout_source, G_PRIORITY_LOW);
-	g_source_set_callback (
-		timeout_source,
-		backend_update_online_state_timeout_cb,
-		backend, (GDestroyNotify) g_object_unref);
-	g_source_attach (timeout_source, main_context);
-	backend->priv->update_online_state =
-		g_source_ref (timeout_source);
-	g_source_unref (timeout_source);
-
-	g_main_context_unref (main_context);
-
 	g_mutex_unlock (&backend->priv->update_online_state_lock);
 }
 
@@ -531,6 +519,7 @@ e_backend_class_init (EBackendClass *class)
 			"Whether the backend is online",
 			TRUE,
 			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT |
 			G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (
@@ -566,7 +555,6 @@ e_backend_init (EBackend *backend)
 	backend->priv = E_BACKEND_GET_PRIVATE (backend);
 	backend->priv->prompter = e_user_prompter_new ();
 	backend->priv->main_context = g_main_context_ref_thread_default ();
-	backend->priv->online = TRUE;
 
 	g_mutex_init (&backend->priv->property_lock);
 	g_mutex_init (&backend->priv->update_online_state_lock);
