@@ -1,17 +1,17 @@
 /*
  * e-collection-backend.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -71,7 +71,6 @@ struct _ECollectionBackendPrivate {
 
 	gulong source_added_handler_id;
 	gulong source_removed_handler_id;
-	gulong notify_enabled_handler_id;
 };
 
 enum {
@@ -479,28 +478,6 @@ collection_backend_source_removed_cb (ESourceRegistryServer *server,
 	g_object_unref (parent_source);
 }
 
-static void
-collection_backend_source_enabled_cb (ESource *source,
-				      GParamSpec *spec,
-				      EBackend *backend)
-{
-	ESource *collection_source;
-	GObject *collection;
-
-	g_return_if_fail (E_IS_COLLECTION_BACKEND (backend));
-
-	collection_source = e_backend_get_source (E_BACKEND (backend));
-	collection = e_source_get_extension (collection_source, E_SOURCE_EXTENSION_COLLECTION);
-
-	/* Some child sources depend on both sub-part enabled and the main
-	   ESource::enabled state, thus if the main's ESource::enabled
-	   changes, then also notify the change of the sub-parts, thus
-	   child's enabled property is properly recalculated. */
-	g_object_notify (collection, "calendar-enabled");
-	g_object_notify (collection, "contacts-enabled");
-	g_object_notify (collection, "mail-enabled");
-}
-
 static gboolean
 collection_backend_populate_idle_cb (gpointer user_data)
 {
@@ -653,15 +630,6 @@ collection_backend_dispose (GObject *object)
 		g_object_unref (server);
 	}
 
-	if (priv->notify_enabled_handler_id) {
-		ESource *source = e_backend_get_source (E_BACKEND (object));
-
-		if (source)
-			g_signal_handler_disconnect (source, priv->notify_enabled_handler_id);
-
-		priv->notify_enabled_handler_id = 0;
-	}
-
 	g_mutex_lock (&priv->children_lock);
 	g_hash_table_remove_all (priv->children);
 	g_mutex_unlock (&priv->children_lock);
@@ -692,8 +660,6 @@ collection_backend_finalize (GObject *object)
 	g_hash_table_destroy (priv->unclaimed_resources);
 	g_mutex_clear (&priv->unclaimed_resources_lock);
 
-	g_weak_ref_clear (&priv->server);
-
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (e_collection_backend_parent_class)->finalize (object);
 }
@@ -712,7 +678,8 @@ collection_backend_constructed (GObject *object)
 	backend = E_COLLECTION_BACKEND (object);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_collection_backend_parent_class)->constructed (object);
+	G_OBJECT_CLASS (e_collection_backend_parent_class)->
+		constructed (object);
 
 	server = e_collection_backend_ref_server (backend);
 	source = e_backend_get_source (E_BACKEND (backend));
@@ -774,9 +741,6 @@ collection_backend_constructed (GObject *object)
 
 	g_object_unref (server);
 
-	backend->priv->notify_enabled_handler_id = g_signal_connect (source, "notify::enabled",
-		G_CALLBACK (collection_backend_source_enabled_cb), backend);
-
 	/* Populate the newly-added collection from an idle callback
 	 * so persistent child sources have a chance to be added first. */
 
@@ -1134,7 +1098,6 @@ e_collection_backend_init (ECollectionBackend *backend)
 	g_mutex_init (&backend->priv->property_lock);
 	backend->priv->unclaimed_resources = unclaimed_resources;
 	g_mutex_init (&backend->priv->unclaimed_resources_lock);
-	g_weak_ref_init (&backend->priv->server, NULL);
 }
 
 /**
@@ -1180,7 +1143,7 @@ e_collection_backend_new_child (ECollectionBackend *backend,
 
 	collection_source = e_backend_get_source (E_BACKEND (backend));
 
-	e_source_registry_debug_print (
+	g_print (
 		"%s: Pairing %s with resource %s\n",
 		e_source_get_display_name (collection_source),
 		e_source_get_uid (child_source), resource_id);
