@@ -1,17 +1,17 @@
 /*
  * e-server-side-source.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -149,10 +149,7 @@ server_side_source_print_diff (ESource *source,
 	guint new_length = 0;
 	guint ii;
 
-	if (!e_source_registry_debug_enabled ())
-		return;
-
-	e_source_registry_debug_print ("Saving %s\n", e_source_get_uid (source));
+	g_print ("Saving %s\n", e_source_get_uid (source));
 
 	if (old_data != NULL) {
 		old_strv = g_strsplit (old_data, "\n", 0);
@@ -166,18 +163,18 @@ server_side_source_print_diff (ESource *source,
 
 	for (ii = 0; ii < MIN (old_length, new_length); ii++) {
 		if (g_strcmp0 (old_strv[ii], new_strv[ii]) != 0) {
-			e_source_registry_debug_print (" - : %s\n", old_strv[ii]);
-			e_source_registry_debug_print (" + : %s\n", new_strv[ii]);
+			g_print (" - : %s\n", old_strv[ii]);
+			g_print (" + : %s\n", new_strv[ii]);
 		} else {
-			e_source_registry_debug_print ("   : %s\n", old_strv[ii]);
+			g_print ("   : %s\n", old_strv[ii]);
 		}
 	}
 
 	for (; ii < old_length; ii++)
-		e_source_registry_debug_print (" - : %s\n", old_strv[ii]);
+		g_print (" - : %s\n", old_strv[ii]);
 
 	for (; ii < new_length; ii++)
-		e_source_registry_debug_print (" + : %s\n", new_strv[ii]);
+		g_print (" + : %s\n", new_strv[ii]);
 
 	g_strfreev (old_strv);
 	g_strfreev (new_strv);
@@ -708,8 +705,6 @@ server_side_source_finalize (GObject *object)
 	g_free (priv->file_contents);
 	g_free (priv->write_directory);
 
-	g_weak_ref_clear (&priv->oauth2_support);
-
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (e_server_side_source_parent_class)->finalize (object);
 }
@@ -1351,8 +1346,6 @@ e_server_side_source_init (EServerSideSource *source)
 	source->priv->write_directory = g_strdup (user_dir);
 
 	source->priv->auth_session_type = E_TYPE_AUTHENTICATION_SESSION;
-
-	g_weak_ref_init (&source->priv->oauth2_support, NULL);
 }
 
 /**
