@@ -1,17 +1,17 @@
 /*
  * e-user-prompter-server.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -326,7 +326,8 @@ static void
 user_prompter_server_constructed (GObject *object)
 {
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_user_prompter_server_parent_class)->constructed (object);
+	G_OBJECT_CLASS (e_user_prompter_server_parent_class)->
+		constructed (object);
 
 	e_extensible_load_extensions (E_EXTENSIBLE (object));
 }
@@ -576,7 +577,7 @@ e_user_prompter_server_register (EUserPrompterServer *server,
 		return FALSE;
 	}
 
-	e_source_registry_debug_print (
+	g_print (
 		"Registering %s for dialog '%s'\n",
 		G_OBJECT_TYPE_NAME (extension), dialog_name);
 	g_hash_table_insert (
