@@ -3,21 +3,20 @@
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  * Copyright (C) 2012 Intel Corporation
  *
- * This library is free software; you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
- * Authors:
- *    Rodrigo Moya <rodrigo@ximian.com>
- *    Tristan Van Berkom <tristanvb@openismus.com>
+ * Authors: Rodrigo Moya <rodrigo@ximian.com>
+ *          Tristan Van Berkom <tristanvb@openismus.com>
  */
 
 #if !defined (__LIBEDATASERVER_H_INSIDE__) && !defined (LIBEDATASERVER_COMPILATION)
@@ -212,10 +211,6 @@ void		e_data_server_util_set_dbus_call_timeout
 
 #endif /* EDS_DISABLE_DEPRECATED */
 
-gboolean	e_source_registry_debug_enabled	(void);
-void		e_source_registry_debug_print	(const gchar *format,
-						 ...) G_GNUC_PRINTF (1, 2);
-
 G_END_DECLS
 
 #endif /* E_DATA_SERVER_UTIL_H */
