@@ -1,23 +1,20 @@
 /*
- * This library is free software you can redistribute it and/or modify it
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
- *
- *
- * Authors:
- *		Jeffrey Stedfast <fejj@ximian.com>
- *		Veerapuram Varadhan <vvaradhan@novell.com>
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
+ * Authors: Jeffrey Stedfast <fejj@ximian.com>
+ *          Veerapuram Varadhan <vvaradhan@novell.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,7 +26,6 @@
 
 #ifdef _WIN32
 #include <winsock2.h>
-#include <ws2tcpip.h>
 #ifndef IN6_ARE_ADDR_EQUAL
 #define IN6_ARE_ADDR_EQUAL(a, b) \
     (memcmp ((gpointer)(a), (gpointer)(b), sizeof (struct in6_addr)) == 0)
@@ -450,11 +446,9 @@ ep_manipulate_ipv4 (ProxyHostAddr *host_addr,
 
 		if (*endptr != '\0' || width < 0 || width > 32) {
 			has_error = TRUE;
-			mask->s_addr = 0xFFFFFFFF;
-		} else {
-			mask->s_addr = htonl (~0 << width);
-			addr->s_addr &= mask->s_addr;
 		}
+		mask->s_addr = htonl (~0 << width);
+		addr->s_addr &= mask->s_addr;
 	} else {
 		mask->s_addr = 0xFFFFFFFF;
 	}
