@@ -1,17 +1,17 @@
 /*
  * e-source-extension.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -104,19 +104,6 @@ source_extension_dispose (GObject *object)
 	G_OBJECT_CLASS (e_source_extension_parent_class)->dispose (object);
 }
 
-static void
-source_extension_finalize (GObject *object)
-{
-	ESourceExtensionPrivate *priv;
-
-	priv = E_SOURCE_EXTENSION_GET_PRIVATE (object);
-
-	g_weak_ref_clear (&priv->source);
-
-	/* Chain up to parent's finalize() method. */
-	G_OBJECT_CLASS (e_source_extension_parent_class)->finalize (object);
-}
-
 static void
 source_extension_notify (GObject *object,
                          GParamSpec *pspec)
@@ -145,7 +132,6 @@ e_source_extension_class_init (ESourceExtensionClass *class)
 	object_class->set_property = source_extension_set_property;
 	object_class->get_property = source_extension_get_property;
 	object_class->dispose = source_extension_dispose;
-	object_class->finalize = source_extension_finalize;
 	object_class->notify = source_extension_notify;
 
 	g_object_class_install_property (
@@ -165,7 +151,6 @@ static void
 e_source_extension_init (ESourceExtension *extension)
 {
 	extension->priv = E_SOURCE_EXTENSION_GET_PRIVATE (extension);
-	g_weak_ref_init (&extension->priv->source, NULL);
 }
 
 /**
