@@ -1,17 +1,17 @@
 /*
  * e-source-mail-signature.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -169,7 +169,8 @@ source_mail_signature_constructed (GObject *object)
 	priv = E_SOURCE_MAIL_SIGNATURE_GET_PRIVATE (object);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_source_mail_signature_parent_class)->constructed (object);
+	G_OBJECT_CLASS (e_source_mail_signature_parent_class)->
+		constructed (object);
 
 	extension = E_SOURCE_EXTENSION (object);
 	source = e_source_extension_ref_source (extension);
@@ -376,8 +377,8 @@ source_mail_signature_load_thread (GSimpleAsyncResult *simple,
 /**
  * e_source_mail_signature_load_sync:
  * @source: an #ESource
- * @contents: (out): return location for the signature content
- * @length: (allow-none) (out): return location for the length of the signature
+ * @contents: return location for the signature content
+ * @length: (allow-none): return location for the length of the signature
  *          content, or %NULL if the length is not needed
  * @cancellable: (allow-none): optional #GCancellable object, or %NULL
  * @error: return location for a #GError, or %NULL
@@ -620,8 +621,8 @@ e_source_mail_signature_load (ESource *source,
  * e_source_mail_signature_load_finish:
  * @source: an #ESource
  * @result: a #GAsyncResult
- * @contents: (out): return location for the signature content
- * @length: (allow-none) (out): return location for the length of the signature
+ * @contents: return location for the signature content
+ * @length: (allow-none): return location for the length of the signature
  *          content, or %NULL if the length is not needed
  * @error: return location for a #GError, or %NULL
  *
