@@ -1,17 +1,17 @@
 /*
  * e-source.h
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -178,6 +178,7 @@ const gchar *	e_source_get_display_name	(ESource *source);
 gchar *		e_source_dup_display_name	(ESource *source);
 void		e_source_set_display_name	(ESource *source,
 						 const gchar *display_name);
+gchar *		e_source_dup_secret_label	(ESource *source);
 gint		e_source_compare_by_display_name
 						(ESource *source1,
 						 ESource *source2);
@@ -244,6 +245,44 @@ gboolean	e_source_get_oauth2_access_token_finish
 						 gint *out_expires_in,
 						 GError **error);
 
+/* Password Management */
+gboolean	e_source_store_password_sync	(ESource *source,
+						 const gchar *password,
+						 gboolean permanently,
+						 GCancellable *cancellable,
+						 GError **error);
+void		e_source_store_password		(ESource *source,
+						 const gchar *password,
+						 gboolean permanently,
+						 GCancellable *cancellable,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+gboolean	e_source_store_password_finish	(ESource *source,
+						 GAsyncResult *result,
+						 GError **error);
+gboolean	e_source_lookup_password_sync	(ESource *source,
+						 GCancellable *cancellable,
+						 gchar **out_password,
+						 GError **error);
+void		e_source_lookup_password	(ESource *source,
+						 GCancellable *cancellable,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+gboolean	e_source_lookup_password_finish	(ESource *source,
+						 GAsyncResult *result,
+						 gchar **out_password,
+						 GError **error);
+gboolean	e_source_delete_password_sync	(ESource *source,
+						 GCancellable *cancellable,
+						 GError **error);
+void		e_source_delete_password	(ESource *source,
+						 GCancellable *cancellable,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+gboolean	e_source_delete_password_finish	(ESource *source,
+						 GAsyncResult *result,
+						 GError **error);
+
 G_END_DECLS
 
 #endif /* E_SOURCE_H */
