@@ -1,17 +1,17 @@
 /*
  * module-google-backend.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -20,16 +20,6 @@
 
 #include <libebackend/libebackend.h>
 
-#ifdef HAVE_GOOGLE
-#include <gdata/gdata.h>
-#endif
-
-/* This macro was introduced in libgdata 0.11,
- * but we currently only require libgdata 0.10. */
-#ifndef GDATA_CHECK_VERSION
-#define GDATA_CHECK_VERSION(major,minor,micro) 0
-#endif
-
 /* Standard GObject macros */
 #define E_TYPE_GOOGLE_BACKEND \
 	(e_google_backend_get_type ())
@@ -69,10 +59,6 @@
 #define GOOGLE_CONTACTS_HOST		"www.google.com"
 #define GOOGLE_CONTACTS_RESOURCE_ID	"Contacts"
 
-/* Tasks Configuration Details */
-#define GOOGLE_TASKS_BACKEND_NAME	"gtasks"
-#define GOOGLE_TASKS_RESOURCE_ID	"Tasks List"
-
 typedef struct _EGoogleBackend EGoogleBackend;
 typedef struct _EGoogleBackendClass EGoogleBackendClass;
 
@@ -255,65 +241,6 @@ google_backend_add_calendar (ECollectionBackend *backend)
 	g_object_unref (source);
 }
 
-#if GDATA_CHECK_VERSION(0,15,1)
-static void
-google_backend_add_tasks (ECollectionBackend *backend)
-{
-	ESource *source;
-	ESource *collection_source;
-	ESourceRegistryServer *server;
-	ESourceExtension *extension;
-	ESourceCollection *collection_extension;
-	const gchar *backend_name;
-	const gchar *extension_name;
-	const gchar *resource_id;
-
-	/* FIXME As a future enhancement, we should query Google
-	 *       for a list of user calendars and add them to the
-	 *       collection with matching display names and colors. */
-
-	collection_source = e_backend_get_source (E_BACKEND (backend));
-
-	resource_id = GOOGLE_TASKS_RESOURCE_ID;
-	source = e_collection_backend_new_child (backend, resource_id);
-	e_source_set_display_name (source, _("Tasks"));
-
-	collection_extension = e_source_get_extension (
-		collection_source, E_SOURCE_EXTENSION_COLLECTION);
-
-	/* Configure the calendar source. */
-
-	backend_name = GOOGLE_TASKS_BACKEND_NAME;
-
-	extension_name = E_SOURCE_EXTENSION_TASK_LIST;
-	extension = e_source_get_extension (source, extension_name);
-
-	e_source_backend_set_backend_name (
-		E_SOURCE_BACKEND (extension), backend_name);
-
-	extension_name = E_SOURCE_EXTENSION_AUTHENTICATION;
-	extension = e_source_get_extension (source, extension_name);
-
-	e_source_authentication_set_host (E_SOURCE_AUTHENTICATION (extension), "www.google.com");
-	e_source_authentication_set_method (E_SOURCE_AUTHENTICATION (extension), "OAuth2");
-
-	g_object_bind_property (
-		collection_extension, "identity",
-		extension, "user",
-		G_BINDING_SYNC_CREATE);
-
-	extension_name = E_SOURCE_EXTENSION_ALARMS;
-	extension = e_source_get_extension (source, extension_name);
-	e_source_alarms_set_include_me (E_SOURCE_ALARMS (extension), FALSE);
-
-	server = e_collection_backend_ref_server (backend);
-	e_source_registry_server_add_source (server, source);
-	g_object_unref (server);
-
-	g_object_unref (source);
-}
-#endif /* GDATA_CHECK_VERSION(0,15,1) */
-
 static void
 google_backend_add_contacts (ECollectionBackend *backend)
 {
@@ -368,28 +295,12 @@ google_backend_add_contacts (ECollectionBackend *backend)
 static void
 google_backend_populate (ECollectionBackend *backend)
 {
-	GList *list, *link;
-	gboolean have_calendar = FALSE, have_tasks = FALSE;
+	GList *list;
 
 	list = e_collection_backend_list_calendar_sources (backend);
-	for (link = list; link; link = g_list_next (link)) {
-		ESource *source = link->data;
-
-		have_calendar = have_calendar || e_source_has_extension (source, E_SOURCE_EXTENSION_CALENDAR);
-		have_tasks = have_tasks || e_source_has_extension (source, E_SOURCE_EXTENSION_TASK_LIST);
-
-		if (have_calendar && have_tasks)
-			break;
-	}
-	g_list_free_full (list, (GDestroyNotify) g_object_unref);
-
-	if (!have_calendar)
+	if (list == NULL)
 		google_backend_add_calendar (backend);
-
-#if GDATA_CHECK_VERSION(0,15,1)
-	if (!have_tasks)
-		google_backend_add_tasks (backend);
-#endif
+	g_list_free_full (list, (GDestroyNotify) g_object_unref);
 
 	list = e_collection_backend_list_contacts_sources (backend);
 	if (list == NULL)
@@ -414,10 +325,6 @@ google_backend_dup_resource_id (ECollectionBackend *backend,
 	if (e_source_has_extension (child_source, extension_name))
 		return g_strdup (GOOGLE_CALENDAR_RESOURCE_ID);
 
-	extension_name = E_SOURCE_EXTENSION_TASK_LIST;
-	if (e_source_has_extension (child_source, extension_name))
-		return g_strdup (GOOGLE_TASKS_RESOURCE_ID);
-
 	extension_name = E_SOURCE_EXTENSION_ADDRESS_BOOK;
 	if (e_source_has_extension (child_source, extension_name))
 		return g_strdup (GOOGLE_CONTACTS_RESOURCE_ID);
