@@ -1,17 +1,17 @@
 /*
  * module-ubuntu-online-accounts.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -891,16 +891,16 @@ ubuntu_online_accounts_constructed (GObject *object)
 	extensible = e_extension_get_extensible (extension);
 
 	/* Wait for the registry service to acquire its well-known
-	 * bus name so we don't do anything destructive beforehand.
-	 * Run last so that all the sources get loaded first. */
+	 * bus name so we don't do anything destructive beforehand. */
 
-	g_signal_connect_after (
+	g_signal_connect (
 		extensible, "bus-acquired",
 		G_CALLBACK (ubuntu_online_accounts_bus_acquired_cb),
 		extension);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_ubuntu_online_accounts_parent_class)->constructed (object);
+	G_OBJECT_CLASS (e_ubuntu_online_accounts_parent_class)->
+		constructed (object);
 }
 
 static gboolean
