@@ -1,17 +1,17 @@
 /*
  * module-yahoo-backend.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -336,25 +336,11 @@ yahoo_backend_child_added (ECollectionBackend *backend,
 		child_added (backend, child_source);
 }
 
-static void
-yahoo_backend_finalize (GObject *object)
-{
-	EYahooBackend *backend = E_YAHOO_BACKEND (object);
-
-	g_weak_ref_clear (&backend->mail_identity_source);
-
-	G_OBJECT_CLASS (e_yahoo_backend_parent_class)->finalize (object);
-}
-
 static void
 e_yahoo_backend_class_init (EYahooBackendClass *class)
 {
-	GObjectClass *object_class;
 	ECollectionBackendClass *backend_class;
 
-	object_class = G_OBJECT_CLASS (class);
-	object_class->finalize = yahoo_backend_finalize;
-
 	backend_class = E_COLLECTION_BACKEND_CLASS (class);
 	backend_class->populate = yahoo_backend_populate;
 	backend_class->dup_resource_id = yahoo_backend_dup_resource_id;
@@ -369,7 +355,6 @@ e_yahoo_backend_class_finalize (EYahooBackendClass *class)
 static void
 e_yahoo_backend_init (EYahooBackend *backend)
 {
-	g_weak_ref_init (&backend->mail_identity_source, NULL);
 }
 
 static void
