@@ -1,17 +1,17 @@
 /*
  * evolution-source-registry-migrate-basedir.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -38,7 +38,7 @@ migrate_rename (const gchar *old_filename,
 	if (!old_filename_exists)
 		return TRUE;
 
-	e_source_registry_debug_print ("  mv %s %s\n", old_filename, new_filename);
+	g_print ("  mv %s %s\n", old_filename, new_filename);
 
 	/* It's safe to go ahead and move directories because rename()
 	 * will fail if the new directory already exists with content.
@@ -64,7 +64,7 @@ migrate_rmdir (const gchar *dirname)
 	gboolean success = TRUE;
 
 	if (g_file_test (dirname, G_FILE_TEST_IS_DIR)) {
-		e_source_registry_debug_print ("  rmdir %s\n", dirname);
+		g_print ("  rmdir %s\n", dirname);
 		if (g_rmdir (dirname) < 0) {
 			g_printerr ("  FAILED: %s", g_strerror (errno));
 			if (errno == ENOTEMPTY) {
@@ -82,7 +82,7 @@ migrate_rmdir (const gchar *dirname)
 
 		/* Align the filenames beneath the error message. */
 		while ((basename = g_dir_read_name (dir)) != NULL)
-			e_source_registry_debug_print ("          %s\n", basename);
+			g_print ("          %s\n", basename);
 
 		g_dir_close (dir);
 	}
@@ -281,7 +281,7 @@ migrate_to_user_cache_dir (const gchar *old_base_dir)
 	old_cache_dir = g_build_filename (old_base_dir, "cache", NULL);
 	new_cache_dir = e_get_user_cache_dir ();
 
-	e_source_registry_debug_print ("Migrating cached backend data\n");
+	g_print ("Migrating cached backend data\n");
 
 	/* We don't want to move the source directory directly because the
 	 * destination directory may already exist with content.  Instead
@@ -354,7 +354,7 @@ migrate_to_user_data_dir (const gchar *old_base_dir)
 
 	new_data_dir = e_get_user_data_dir ();
 
-	e_source_registry_debug_print ("Migrating local backend data\n");
+	g_print ("Migrating local backend data\n");
 
 	/* We don't want to move the source directory directly because the
 	 * destination directory may already exist with content.  Instead
