@@ -2,19 +2,19 @@
 /*
  * Copyright (C) 2012,2013 Intel Corporation
  *
- * This program is free software; you can redistribute it and/or modify it
+ * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful, but
+ * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
- * Author: Mathias Hasselmann <mathias@openismus.com>
+ * Authors: Mathias Hasselmann <mathias@openismus.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,11 +30,6 @@
 #define CATEGORY LC_ADDRESS
 #else
 /* Mimic the fallback branch in EBookQuery. */
-#ifdef G_OS_WIN32
-#ifndef LC_MESSAGES
-#define LC_MESSAGES LC_CTYPE
-#endif
-#endif
 #define CATEGORY LC_MESSAGES
 #endif /* LC_ADDRESS */
 
