@@ -4,17 +4,17 @@
  *
  * Copyright (C) 2012 Intel Corporation
  *
- * This program is free software; you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  * Authors: Tristan Van Berkom <tristanvb@openismus.com>
  */
@@ -34,15 +34,9 @@
  * and e_test_server_utils_teardown() in thier fixture's setup and teardown routines.
  **/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "e-test-server-utils.h"
 
-#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
-#endif
 
 #define ADDRESS_BOOK_SOURCE_UID "test-address-book"
 #define CALENDAR_SOURCE_UID     "test-calendar"
@@ -280,12 +274,8 @@ delete_work_directory (void)
 					NULL, NULL, &exit_status, NULL);
 
 	g_assert (spawn_succeeded);
-	#ifndef G_OS_WIN32
 	g_assert (WIFEXITED (exit_status));
 	g_assert_cmpint (WEXITSTATUS (exit_status), ==, 0);
-	#else
-	g_assert_cmpint (exit_status, ==, 0);
-	#endif
 }
 
 static gboolean
